@@ -10,10 +10,8 @@
  *	redraw_all_views()		redraw all views
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <varargs.h>
 #include <Xm/Xm.h>
@@ -24,15 +22,21 @@
 #include <Xm/LabelP.h>
 #include <Xm/PushBP.h>
 #include <Xm/PushBG.h>
+#include <Xm/ToggleB.h>
 #include <Xm/Text.h>
 #include <Xm/Protocols.h>
 #include <X11/cursorfont.h>
 #include "cal.h"
 
-void create_view();
-static void filemenu_callback(), configmenu_callback(), search_callback(),
-	    delpast_callback(), view_callback(), help_pulldown(),
-	    list_by_user();
+void	    create_view		(int);
+static void filemenu_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void delpast_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void configmenu_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void language_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void search_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void view_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void help_pulldown	(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_by_user	(int);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -61,30 +65,34 @@ Widget			mainview;	/* area in main window below menubar */
 #define XM_VA_SEPARATOR XmVaSEPARATOR,
 #endif
 
+#define MAXLANGUAGES 20
+static char *language_name[MAXLANGUAGES];
+
 
 /*
  * create the main calendar window with the month view, including the menu
  * bar and all its pulldowns.
  */
 
-void create_cal_widgets(toplevel)
-	Widget			toplevel;
+void create_cal_widgets(
+	Widget		toplevel)
 {
-	Arg			args;
-	Widget			menu, fmenu, w;
-	XmString		s[20];
-	int			n;
+	Arg		args[4];
+	Widget		menu, fmenu, w;
+	XmString	s[MAXLANGUAGES+1];
+	int		n;
+	char		*p;
 
-	XtSetArg(args, XmNallowShellResize, TRUE);
+	XtSetArg(*args, XmNallowShellResize, TRUE);
 	mainwindow = XtCreateManagedWidget("mainwindow",
-			xmMainWindowWidgetClass, toplevel, &args, 1);
+			xmMainWindowWidgetClass, toplevel, args, 1);
 
 	/*------------------------------------- menu bar -------------------*/
-	s[0] = XmStringCreateSimple("File");
-	s[1] = XmStringCreateSimple("Config");
-	s[2] = XmStringCreateSimple("Search");
-	s[3] = XmStringCreateSimple("View");
-	s[4] = XmStringCreateSimple("Help");
+	s[0] = XmStringCreateSimple(_("File"));
+	s[1] = XmStringCreateSimple(_("Config"));
+	s[2] = XmStringCreateSimple(_("Search"));
+	s[3] = XmStringCreateSimple(_("View"));
+	s[4] = XmStringCreateSimple(_("Help"));
 	menubar = XmVaCreateSimpleMenuBar(mainwindow, "menubar",
 			FIX_MENUBAR
 			XmVaCASCADEBUTTON, s[0], 'F',
@@ -98,17 +106,17 @@ void create_cal_widgets(toplevel)
 	for (n=0; n < 5; n++)
 		XmStringFree(s[n]);
 
-	s[0] = XmStringCreateSimple("File list...");
-	s[1] = XmStringCreateSimple("Reread files");
-	s[2] = XmStringCreateSimple("Delete past entries");
-	s[3] = XmStringCreateSimple("Print...");
-	s[4] = XmStringCreateSimple("About...");
-	s[5] = XmStringCreateSimple("Quit");
+	s[0] = XmStringCreateSimple(_("File list..."));
+	s[1] = XmStringCreateSimple(_("Reread files"));
+	s[2] = XmStringCreateSimple(_("Delete past entries"));
+	s[3] = XmStringCreateSimple(_("Print..."));
+	s[4] = XmStringCreateSimple(_("About..."));
+	s[5] = XmStringCreateSimple(_("Quit"));
 	s[6] = XmStringCreateSimple("Ctrl-L");
 	s[7] = XmStringCreateSimple("Ctrl-P");
 	s[8] = XmStringCreateSimple("Ctrl-Q");
 	fmenu = XmVaCreateSimplePulldownMenu(menubar, "file", 0,
-			filemenu_callback,
+			(XtCallbackProc)filemenu_callback,
 			FIX_MENUBAR
 			XmVaPUSHBUTTON,    s[0], 'F', "Ctrl<Key>L", s[6],
 			XmVaPUSHBUTTON,    s[1], 'R', NULL, NULL,
@@ -117,18 +125,18 @@ void create_cal_widgets(toplevel)
 			XmVaPUSHBUTTON,    s[4], 'A', NULL, NULL,
 			XmVaPUSHBUTTON,    s[5], 'Q', "Ctrl<Key>Q", s[8],
 			NULL);
-	XtAddCallback(fmenu, XmNhelpCallback,
-					help_callback, (XtPointer)"pd_file");
+	XtAddCallback(fmenu, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"pd_file");
 	for (n=0; n < 9; n++)
 		XmStringFree(s[n]);
 
-	s[0] = XmStringCreateSimple("older than one day");
-	s[1] = XmStringCreateSimple("older than one week");
-	s[2] = XmStringCreateSimple("older than one month");
-	s[3] = XmStringCreateSimple("older than 90 days");
-	s[4] = XmStringCreateSimple("older than one year");
+	s[0] = XmStringCreateSimple(_("older than one day"));
+	s[1] = XmStringCreateSimple(_("older than one week"));
+	s[2] = XmStringCreateSimple(_("older than one month"));
+	s[3] = XmStringCreateSimple(_("older than 90 days"));
+	s[4] = XmStringCreateSimple(_("older than one year"));
 	fmenu = XmVaCreateSimplePulldownMenu(fmenu, "delpast", 2,
-			delpast_callback,
+			(XtCallbackProc)delpast_callback,
 			FIX_MENUBAR
 			XmVaPUSHBUTTON,    s[0], 'd',  NULL, NULL,
 			XmVaPUSHBUTTON,    s[1], 'w',  NULL, NULL,
@@ -136,44 +144,58 @@ void create_cal_widgets(toplevel)
 			XmVaPUSHBUTTON,    s[3], '9',  NULL, NULL,
 			XmVaPUSHBUTTON,    s[4], 'y',  NULL, NULL,
 			NULL);
-	XtAddCallback(fmenu, XmNhelpCallback,
-					help_callback, (XtPointer)"pd_file");
-	for (n=0; n < 4; n++)
-		XmStringFree(s[n]);
-
-	s[0] = XmStringCreateSimple("Calendar views...");
-	s[1] = XmStringCreateSimple("Adjust time...");
-	s[2] = XmStringCreateSimple("Alarm options...");
-	s[3] = XmStringCreateSimple("Define holidays...");
-	s[4] = XmStringCreateSimple("Ctrl-C");
-	menu = XmVaCreateSimplePulldownMenu(menubar, "config", 1,
-			configmenu_callback,
-			FIX_MENUBAR
-			XmVaPUSHBUTTON, s[0],  'C', "Ctrl<Key>C", s[4],
-			XmVaPUSHBUTTON, s[1],  't', NULL, NULL,
-			XmVaPUSHBUTTON, s[2],  'o', NULL, NULL,
-			XmVaPUSHBUTTON, s[3],  'D', NULL, NULL,
-			NULL);
-	XtAddCallback(menu, XmNhelpCallback,
-					help_callback, (XtPointer)"pd_config");
+	XtAddCallback(fmenu, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"pd_file");
 	for (n=0; n < 5; n++)
 		XmStringFree(s[n]);
 
-	s[ 0] = XmStringCreateSimple("Today");
-	s[ 1] = XmStringCreateSimple("Tomorrow");
-	s[ 2] = XmStringCreateSimple("This week");
-	s[ 3] = XmStringCreateSimple("Next week");
-	s[ 4] = XmStringCreateSimple("This month");
-	s[ 5] = XmStringCreateSimple("All");
-	s[ 6] = XmStringCreateSimple("Private");
-	s[ 7] = XmStringCreateSimple("One file...");
-	s[ 8] = XmStringCreateSimple("Search keywords...");
+	s[0] = XmStringCreateSimple(_("Calendar views..."));
+	s[1] = XmStringCreateSimple(_("Adjust time..."));
+	s[2] = XmStringCreateSimple(_("Alarm options..."));
+	s[3] = XmStringCreateSimple(_("Define holidays..."));
+	s[4] = XmStringCreateSimple(_("Language"));
+	s[5] = XmStringCreateSimple("Ctrl-C");
+	menu = XmVaCreateSimplePulldownMenu(menubar, "config", 1,
+			(XtCallbackProc)configmenu_callback,
+			FIX_MENUBAR
+			XmVaPUSHBUTTON,    s[0], 'C', "Ctrl<Key>C", s[5],
+			XmVaPUSHBUTTON,    s[1], 't', NULL, NULL,
+			XmVaPUSHBUTTON,    s[2], 'o', NULL, NULL,
+			XmVaPUSHBUTTON,    s[3], 'D', NULL, NULL,
+			XmVaCASCADEBUTTON, s[4], 'L',
+			NULL);
+	XtAddCallback(menu, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"pd_config");
+	for (n=0; n < 6; n++)
+		XmStringFree(s[n]);
+
+	menu = XmVaCreateSimplePulldownMenu(menu, "langpd", 4,
+			(XtCallbackProc)language_callback, FIX_MENUBAR NULL);
+	XtAddCallback(menu, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"pd_lang");
+	for (n=0; n < MAXLANGUAGES; n++) {
+		if (!(language_name[n] = mystrdup(p = get_language_name(n))))
+			break;
+		w = XtCreateManagedWidget(p, xmPushButtonWidgetClass,menu,0,0);
+		XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			(XtCallbackProc)language_callback, (XtPointer)n);
+	}
+
+	s[ 0] = XmStringCreateSimple(_("Today"));
+	s[ 1] = XmStringCreateSimple(_("Tomorrow"));
+	s[ 2] = XmStringCreateSimple(_("This week"));
+	s[ 3] = XmStringCreateSimple(_("Next week"));
+	s[ 4] = XmStringCreateSimple(_("This month"));
+	s[ 5] = XmStringCreateSimple(_("All"));
+	s[ 6] = XmStringCreateSimple(_("Private"));
+	s[ 7] = XmStringCreateSimple(_("One file..."));
+	s[ 8] = XmStringCreateSimple(_("Search keywords..."));
 	s[ 9] = XmStringCreateSimple("Ctrl-E");
 	s[10] = XmStringCreateSimple("Ctrl-I");
 	s[11] = XmStringCreateSimple("Ctrl-J");
 	s[12] = XmStringCreateSimple("Ctrl-S");
 	menu = XmVaCreateSimplePulldownMenu(menubar, "search", 2,
-			search_callback,
+			(XtCallbackProc)search_callback,
 			FIX_MENUBAR
 			XmVaPUSHBUTTON, s[0], 'T', "Ctrl<Key>E", s[9],
 			XmVaPUSHBUTTON, s[1], 'o', "Ctrl<Key>I", s[10],
@@ -185,19 +207,19 @@ void create_cal_widgets(toplevel)
 			XmVaPUSHBUTTON, s[7], 'f', NULL, NULL,
 			XmVaPUSHBUTTON, s[8], 'S', "Ctrl<Key>S", s[12],
 			NULL);
-	XtAddCallback(menu, XmNhelpCallback,
-					help_callback, (XtPointer)"pd_search");
+	XtAddCallback(menu, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"pd_search");
 	for (n=0; n < 13; n++)
 		XmStringFree(s[n]);
 
-	s[ 0] = XmStringCreateSimple("Day");
-	s[ 1] = XmStringCreateSimple("Week");
-	s[ 2] = XmStringCreateSimple("Small Month");
-	s[ 3] = XmStringCreateSimple("Large Month");
-	s[ 4] = XmStringCreateSimple("Year");
-	s[ 5] = XmStringCreateSimple("Year Overview");
-	s[ 6] = XmStringCreateSimple("Goto today");
-	s[ 7] = XmStringCreateSimple("Goto...");
+	s[ 0] = XmStringCreateSimple(_("Day"));
+	s[ 1] = XmStringCreateSimple(_("Week"));
+	s[ 2] = XmStringCreateSimple(_("Small Month"));
+	s[ 3] = XmStringCreateSimple(_("Large Month"));
+	s[ 4] = XmStringCreateSimple(_("Year"));
+	s[ 5] = XmStringCreateSimple(_("Year Overview"));
+	s[ 6] = XmStringCreateSimple(_("Goto today"));
+	s[ 7] = XmStringCreateSimple(_("Goto..."));
 	s[ 8] = XmStringCreateSimple("Ctrl-D");
 	s[ 9] = XmStringCreateSimple("Ctrl-W");
 	s[10] = XmStringCreateSimple("Ctrl-N");
@@ -207,7 +229,7 @@ void create_cal_widgets(toplevel)
 	s[14] = XmStringCreateSimple("Ctrl-T");
 	s[15] = XmStringCreateSimple("Ctrl-G");
 	menu = XmVaCreateSimplePulldownMenu(menubar, "view", 3,
-			view_callback,
+			(XtCallbackProc)view_callback,
 			FIX_MENUBAR
 			XmVaPUSHBUTTON, s[0], 'D', "Ctrl<Key>D", s[8],
 			XmVaPUSHBUTTON, s[1], 'W', "Ctrl<Key>W", s[9],
@@ -219,24 +241,25 @@ void create_cal_widgets(toplevel)
 			XmVaPUSHBUTTON, s[6], 't', "Ctrl<Key>T", s[14],
 			XmVaPUSHBUTTON, s[7], 'G', "Ctrl<Key>G", s[15],
 			NULL);
-	XtAddCallback(menu, XmNhelpCallback,
-					help_callback, (XtPointer)"pd_view");
+	XtAddCallback(menu, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"pd_view");
 	for (n=0; n < 16; n++)
 		XmStringFree(s[n]);
 
-	s[0] = XmStringCreateSimple("On context");
-	s[1] = XmStringCreateSimple("Introduction");
-	s[2] = XmStringCreateSimple("Getting help");
-	s[3] = XmStringCreateSimple("Troubleshooting");
-	s[4] = XmStringCreateSimple("Files and programs");
-	s[5] = XmStringCreateSimple("Networking");
-	s[6] = XmStringCreateSimple("Database access");
-	s[7] = XmStringCreateSimple("X resources");
-	s[8] = XmStringCreateSimple("Ctrl-H");
+	s[0] = XmStringCreateSimple(_("On context"));
+	s[1] = XmStringCreateSimple(_("Introduction"));
+	s[2] = XmStringCreateSimple(_("Getting help"));
+	s[3] = XmStringCreateSimple(_("Troubleshooting"));
+	s[4] = XmStringCreateSimple(_("Files and programs"));
+	s[5] = XmStringCreateSimple(_("Networking"));
+	s[6] = XmStringCreateSimple(_("Database access"));
+	s[7] = XmStringCreateSimple(_("X resources"));
+	s[8] = XmStringCreateSimple(_("Languages"));
+	s[9] = XmStringCreateSimple("Ctrl-H");
 	(void)XmVaCreateSimplePulldownMenu(menubar, "help", 4,
-			help_pulldown,
+			(XtCallbackProc)help_pulldown,
 			FIX_MENUBAR
-			XmVaPUSHBUTTON, s[0], 'c', "Ctrl<Key>H", s[8],
+			XmVaPUSHBUTTON, s[0], 'c', "Ctrl<Key>H", s[9],
 			XM_VA_SEPARATOR
 			XmVaPUSHBUTTON, s[1], 'I', NULL, NULL,
 			XmVaPUSHBUTTON, s[2], 'G', NULL, NULL,
@@ -245,6 +268,7 @@ void create_cal_widgets(toplevel)
 			XmVaPUSHBUTTON, s[5], 'N', NULL, NULL,
 			XmVaPUSHBUTTON, s[6], 'D', NULL, NULL,
 			XmVaPUSHBUTTON, s[7], 'X', NULL, NULL,
+			XmVaPUSHBUTTON, s[8], 'L', NULL, NULL,
 			NULL);
 
 	for (n=0; n < 9; n++)
@@ -267,8 +291,8 @@ void create_cal_widgets(toplevel)
  * to set up windows, shells, and a toplevel form.
  */
 
-void create_view(view)
-	int		view;		/* m, w, y, o, d */
+void create_view(
+	int		view)		/* m, w, y, o, d */
 {
 	static int	lastview = 'm';	/* previous view to destroy first */
 
@@ -308,14 +332,14 @@ void create_view(view)
  * exists and it's sufficient to redraw.
  */
 
-Widget create_view_form(shell, parent, view, xs, ys, name)
-	Widget		*shell;		/* if shell exists, widget, else &0 */
-	Widget		parent;		/* parent widget (mainview) if share */
-	int		view;		/* m, w, y, o, d */
-	int		xs, ys;		/* requested form size */
-	char		*name;		/* window name */
+Widget create_view_form(
+	Widget		*shell,		/* if shell exists, widget, else &0 */
+	Widget		parent,		/* parent widget (mainview) if share */
+	int		view,		/* m, w, y, o, d */
+	int		xs,		/* requested form width */
+	int		ys,		/* requested form height */
+	char		*name)		/* window name */
 {
-	static Dimension dx, dy;	/* window size minus usable form size*/
 	Widget		form;		/* form to create to draw view into */
 	Dimension	x, y;
 	Arg		args[4];
@@ -377,11 +401,11 @@ static Dimension	shell_dy[10];	/* buttons etc) and the window (menu */
 static Dimension	window_dx[10];	/* bar) in addition to the scrolling */
 static Dimension	window_dy[10];	/* area. Set up when first used. */
 
-resize_window(shell, scroll, form, view)
-	Widget		shell;		/* window shell to resize */
-	Widget		scroll;		/* scrolling area, will fit form */
-	Widget		form;		/* form inside scrolling area */
-	int		view;		/* m, w, y, o, d */
+resize_window(
+	Widget		shell,		/* window shell to resize */
+	Widget		scroll,		/* scrolling area, will fit form */
+	Widget		form,		/* form inside scrolling area */
+	int		view)		/* m, w, y, o, d */
 {
 	int		i;		/* shell/window_dx/y index */
 	Widget		window, scrollp;
@@ -445,12 +469,14 @@ resize_window(shell, scroll, form, view)
 /*
  * resize the main window. When this is called for the first time, just
  * record the window size. Any future call applies the change to the size
- * of the calendar to the window based on the original size.
+ * of the calendar to the window based on the original size. Not used.
  */
 
-static void resize_mainwindow(win, xs, ys)
-	Widget		 win;		/* mainwindow */
-	Dimension	 xs, ys;	/* space needed for calendar */
+#if 0
+static void resize_mainwindow(
+	Widget		 win,		/* mainwindow */
+	Dimension	 xs,		/* space needed for calendar */
+	Dimension	 ys)
 {
 	Arg		 args[2];
 	Dimension	 win_xs,  win_ys;
@@ -467,6 +493,7 @@ static void resize_mainwindow(win, xs, ys)
 	last_xs = xs;
 	last_ys = ys;
 }
+#endif
 
 
 /*
@@ -474,7 +501,7 @@ static void resize_mainwindow(win, xs, ys)
  * the changed data. It's easier to do it all in one place.
  */
 
-void redraw_all_views()
+void redraw_all_views(void)
 {
 	build_day(FALSE, FALSE);
 	build_week(FALSE, FALSE);
@@ -491,9 +518,10 @@ void redraw_all_views()
  * get and set widget sizes
  */
 
-void get_widget_size(w, xs, ys)
-	Widget		w;
-	Dimension	*xs, *ys;
+void get_widget_size(
+	Widget		w,
+	Dimension	*xs,
+	Dimension	*ys)
 {
 	Arg		args[2];
 
@@ -503,9 +531,10 @@ void get_widget_size(w, xs, ys)
 }
 
 
-void set_widget_size(w, xs, ys)
-	Widget		w;
-	Dimension	xs, ys;
+void set_widget_size(
+	Widget		w,
+	Dimension	xs,
+	Dimension	ys)
 {
 	Arg		args[2];
 
@@ -522,23 +551,26 @@ void set_widget_size(w, xs, ys)
  */
 
 /*ARGSUSED*/
-static void filemenu_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void filemenu_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	switch (item) {
 	  case 0:						/* file list */
 		create_user_popup();
 		break;
 
-	  case 1:						/* reread */
+	  case 1: {						/* reread */
+		char *errmsg;
+		if (errmsg = parse_holidays(curr_year, FALSE))
+			create_error_popup(mainmenu.cal, 0, errmsg);
 		if (can_edit_appts()) {
 			read_mainlist();
 			update_all_listmenus();
 			redraw_all_views();
 		}
-		break;
+		break; }
 
 	  case 3:						/* print */
 		if (can_edit_appts())
@@ -556,10 +588,10 @@ static void filemenu_callback(widget, item, data)
 
 static int period[5] = {1, 7, 31, 90, 366};
 /*ARGSUSED*/
-static void delpast_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void delpast_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (can_edit_appts())
 		if (item < 5 && recycle_all(mainlist, TRUE, period[item])) {
@@ -569,10 +601,10 @@ static void delpast_callback(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void configmenu_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void configmenu_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (!can_edit_appts())
 		return;
@@ -593,10 +625,25 @@ static void configmenu_callback(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void search_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void language_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
+{
+	if (config.language)
+		free(config.language);
+	config.language = !strcmp(language_name[item], "english") ? 0 :
+		mystrdup(language_name[item]);
+	mainlist->modified = TRUE;
+	write_mainlist();
+	new_language_popup(widget);
+}
+
+/*ARGSUSED*/
+static void search_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	time_t				now;		/* curr date, 0:00 */
 	struct tm			*tm;
@@ -648,7 +695,7 @@ static void search_callback(widget, item, data)
 		break;
 
 	  case 7:						/* One file */
-		create_user_sel_popup(menubar, 0, list_by_user);
+		create_user_sel_popup(menubar, 0, (BOOL (*)())list_by_user);
 		break;
 
 	  case 8:						/* Search */
@@ -658,8 +705,8 @@ static void search_callback(widget, item, data)
 }
 
 
-static void list_by_user(u)
-	int		u;		/* user index to list */
+static void list_by_user(
+	int		u)		/* user index to list */
 {
 	create_list_popup(mainlist, (time_t)0,
 			(time_t)0, (char *)0, (struct entry *)0, u+1, 0);
@@ -667,10 +714,10 @@ static void list_by_user(u)
 
 
 /*ARGSUSED*/
-static void view_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void view_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	time_t time = get_time();
 	struct tm *tm = time_to_tm(time);
@@ -716,11 +763,12 @@ static void view_callback(widget, item, data)
 	}
 }
 
+
 /*ARGSUSED*/
-static void help_pulldown(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void help_pulldown(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	Cursor				cursor;
 	Widget				w;
@@ -762,5 +810,9 @@ static void help_pulldown(widget, item, data)
 	  case 7:						/* widgets */
 		help_callback(mainwindow, "widgets");
 		break;
+
+	  case 8:						/* languages */
+		help_callback(mainwindow, "languages");
+		break;
 	}
 }
