@@ -25,9 +25,15 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void		done_callback(), wkday_callback(), day_callback(),
-			nth_callback(), every_callback(), every_text_callback(),
-			yearly_callback(), last_callback(),last_text_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void wkday_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void nth_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void day_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void every_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void every_text_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void yearly_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void last_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void last_text_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -52,7 +58,7 @@ static Widget		yearly_toggle;	/* every year togge button */
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_recycle_popup()
+void destroy_recycle_popup(void)
 {
 	char			*string;	/* contents of text widget */
 
@@ -90,10 +96,10 @@ void destroy_recycle_popup()
  * initialized with data from edit.entry.
  */
 
-static char *nth_name[] = { "every...", "first...", "second...", "third...",
-			    "fourth...", "fifth...", "last..." };
+static char *nth_name[] = { "every...", "first...", "second...",
+			    "third...", "fourth...", "fifth...", "last..." };
 
-void create_recycle_popup()
+void create_recycle_popup(void)
 {
 	Widget			frame, frame2, form, form2, rowcol, w;
 	int			day;		/* weekdays and month days */
@@ -108,7 +114,7 @@ void create_recycle_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Schedule Recycler",
+	shell = XtCreatePopupShell(_("Schedule Recycler"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -117,8 +123,8 @@ void create_recycle_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("cycform1", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"cyc");
-
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc"); 
 							/*-- buttons --*/
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -127,11 +133,12 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftOffset,	32);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"cyc_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"cyc_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -140,11 +147,12 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, help_callback, (XtPointer)"cyc");
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)"cyc");
-
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"cyc"); 
 							/*-- last on --*/
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_WIDGET);	n++;
@@ -159,9 +167,8 @@ void create_recycle_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cycform2", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-					help_callback, (XtPointer)"cyc_last");
-
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc_last"); 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -170,11 +177,11 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		ep->rep_last != 0);	n++;
-	last_toggle = XtCreateManagedWidget("Last day: stop repeating on",
+	last_toggle = XtCreateManagedWidget(_("Last day: stop repeating on"),
 			xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(last_toggle, XmNvalueChangedCallback,
-						last_callback, (XtPointer)0);
+	XtAddCallback(last_toggle, XmNvalueChangedCallback, (XtCallbackProc)
+			last_callback, (XtPointer)0);
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -191,8 +198,8 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	last = XtCreateManagedWidget("", xmTextWidgetClass,
 			form2, args, n);
-	XtAddCallback(last, XmNactivateCallback,
-					last_text_callback, (XtPointer)NULL);
+	XtAddCallback(last, XmNactivateCallback, (XtCallbackProc)
+			last_text_callback, (XtPointer)NULL);
 
 							/*-- repeat every --*/
 	n = 0;
@@ -208,8 +215,8 @@ void create_recycle_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cycform3", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-					help_callback, (XtPointer)"cyc_every");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc_every");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
@@ -219,11 +226,11 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		ep->rep_every != 0);	n++;
-	every_toggle = XtCreateManagedWidget("Repeat every",
+	every_toggle = XtCreateManagedWidget(_("Repeat every"),
 			xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(every_toggle, XmNvalueChangedCallback,
-						every_callback, (XtPointer)0);
+	XtAddCallback(every_toggle, XmNvalueChangedCallback, (XtCallbackProc)
+			every_callback, (XtPointer)0);
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -240,8 +247,8 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	every = XtCreateManagedWidget("", xmTextWidgetClass,
 			form2, args, n);
-	XtAddCallback(every, XmNactivateCallback,
-					every_text_callback, (XtPointer)NULL);
+	XtAddCallback(every, XmNactivateCallback, (XtCallbackProc)
+			every_text_callback, (XtPointer)NULL);
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -250,7 +257,7 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNleftWidget,	every);			n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
-	w = XtCreateManagedWidget("days", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("days"), xmLabelWidgetClass,
 			form2, args, n);
 
 							/*-- yearly --*/
@@ -263,13 +270,13 @@ void create_recycle_popup()
 	XtSetArg(args[n], XmNleftOffset,	40);			n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		ep->rep_yearly);	n++;
-	yearly_toggle = XtCreateManagedWidget("Repeat every year",
+	yearly_toggle = XtCreateManagedWidget(_("Repeat every year"),
 			xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(yearly_toggle, XmNvalueChangedCallback,
-				yearly_callback, (XtPointer)0);
-	XtAddCallback(yearly_toggle, XmNhelpCallback,
-				help_callback, (XtPointer)"cyc_yearly");
+	XtAddCallback(yearly_toggle, XmNvalueChangedCallback, (XtCallbackProc)
+			yearly_callback, (XtPointer)0);
+	XtAddCallback(yearly_toggle, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc_yearly");
 
 							/*-- weekdays --*/
 	n = 0;
@@ -285,15 +292,15 @@ void create_recycle_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cycform4", xmFormWidgetClass,
 			frame2, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-				help_callback, (XtPointer)"cyc_weekdays");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc_weekdays");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w = XtCreateManagedWidget("Repeat on", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Repeat on"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -311,11 +318,11 @@ void create_recycle_popup()
 	   XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	   XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	   XtSetArg(args[n], XmNset,		on);			n++;
-	   nth_widget[day] = XtCreateManagedWidget(nth_name[day],
+	   nth_widget[day] = XtCreateManagedWidget(_(nth_name[day]),
 	  		xmToggleButtonWidgetClass,
 			rowcol, args, n);
 	   XtAddCallback(nth_widget[day], XmNvalueChangedCallback,
-						 nth_callback, (XtPointer)day);
+			(XtCallbackProc)nth_callback, (XtPointer)day);
 	}
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -333,11 +340,11 @@ void create_recycle_popup()
 	   XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	   XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	   XtSetArg(args[n], XmNset,		on);			n++;
-	   w = XtCreateManagedWidget(weekday_name[(d+6)%7],
+	   w = XtCreateManagedWidget(_(weekday_name[(d+6)%7]),
 	  		xmToggleButtonWidgetClass,
 			rowcol, args, n);
-	   XtAddCallback(w, XmNvalueChangedCallback,
-						 wkday_callback, (XtPointer)d);
+	   XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			wkday_callback, (XtPointer)d);
 	}
 
 							/*-- month days --*/
@@ -357,15 +364,15 @@ void create_recycle_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cycform5", xmFormWidgetClass,
 			frame2, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-					help_callback, (XtPointer)"cyc_days");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"cyc_days");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w = XtCreateManagedWidget("Repeat on the", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Repeat on the"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -380,26 +387,26 @@ void create_recycle_popup()
 	for (day=1; day <= 32; day++) {
 	   BOOL on = (ep->rep_days & (1<<(day&31))) != 0;
 	   if (day == 32)
-		strcpy(buf, "Last");
+		strcpy(buf, _("Last"));
 	   else
-		sprintf(buf, "%d%s", day, (day%10)==1 && day!=11 ? "st" :
-					  (day%10)==2 && day!=12 ? "nd" :
-					  (day%10)==3 && day!=13 ? "rd" :
-					 			   "th");
+		sprintf(buf, "%d%s", day, (day%10)==1 && day!=11 ? _("st") :
+					  (day%10)==2 && day!=12 ? _("nd") :
+					  (day%10)==3 && day!=13 ? _("rd") :
+					 			   _("th"));
 	   n = 0;
 	   XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	   XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	   XtSetArg(args[n], XmNset,		on);			n++;
 	   w = XtCreateManagedWidget(buf, xmToggleButtonWidgetClass,
 			rowcol, args, n);
-	   XtAddCallback(w, XmNvalueChangedCallback,
-	  					 day_callback, (XtPointer)day);
+	   XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+	  		day_callback, (XtPointer)day);
 	}
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 
 	if (ep->rep_last) {
 		char *space, *text = mkdatestring(ep->rep_last);
@@ -419,20 +426,20 @@ void create_recycle_popup()
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_recycle_popup();
 }
 
 
 /*ARGSUSED*/
-static void wkday_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void wkday_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set)
 		edit.entry.rep_weekdays |= 1 << item;
@@ -444,10 +451,10 @@ static void wkday_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void nth_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void nth_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	register struct entry		*ep = &edit.entry;
 	int				i;
@@ -471,10 +478,10 @@ static void nth_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void day_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void day_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set)
 		edit.entry.rep_days |= 1 << (item&31);
@@ -486,10 +493,10 @@ static void day_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void every_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void every_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set) {
 		XmProcessTraversal(every, XmTRAVERSE_CURRENT);
@@ -505,10 +512,10 @@ static void every_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void every_text_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void every_text_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextGetString(widget);
 	Arg				args;
@@ -523,10 +530,10 @@ static void every_text_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void yearly_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void yearly_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.rep_yearly = data->set;
 	edit.changed = TRUE;
@@ -535,10 +542,10 @@ static void yearly_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void last_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void last_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set) {
 		char *p, date[40];
@@ -558,10 +565,10 @@ static void last_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void last_text_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void last_text_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextGetString(widget);
 	Arg				args;
@@ -572,8 +579,9 @@ static void last_text_callback(widget, item, data)
 		strcpy(date, mkdatestring(edit.entry.time));
 		p = strchr(date, ' ');
 		print_text_button(last, p ? p+1 : date);
-		create_error_popup(widget, 0, "The new last-trigger date is before the\n"
-					      "first-trigger date, %s. Ignored.", date);
+		create_error_popup(widget, 0,
+			_("The new last-trigger date is before the\n"\
+			  "first-trigger date, %s. Ignored."), date);
 		edit.entry.rep_last = edit.entry.time;
 	}
 	XtSetArg(args, XmNset, edit.entry.rep_last > 0);
