@@ -14,15 +14,18 @@
  * Author: thomas@bitrot.in-berlin.de (Thomas Driemeyer)
  */
 
-typedef void *Widget;	/* dummies for prototype declarations in config.h */
-typedef unsigned long XtInputId;
+			/* dummies for prototype declarations in config.h */
+typedef void		*Widget;
+typedef void		*XtPointer;
+typedef void		*XPoint;
+typedef unsigned long	XtInputId;
+typedef unsigned short	Dimension;
+typedef int		Region;
 
-#ifndef MIPS
-#include <unistd.h>
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <errno.h>
+#include <unistd.h>
 #ifdef VARARGS
 #include <varargs.h>
 #else
@@ -30,15 +33,19 @@ typedef unsigned long XtInputId;
 #endif
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <sys/stat.h>
 #include <fcntl.h>
 #include <signal.h>
 #include <time.h>
 #include <string.h>
-#include "config.h"
-#include "proto.h"
+#include "cal.h"
 #include "version.h"
 #include <pwd.h>
+#ifdef __EMX__
+#include <io.h>
+#else
 #include <utmp.h>
+#endif
 #ifdef AIXV3
 struct utmp *getutent();
 #endif
@@ -46,6 +53,7 @@ struct utmp *getutent();
 #include <limits.h>
 #endif
 
+
 #ifndef SIGCHLD			/* for BSD systems */
 #define SIGCHLD SIGCLD
 #endif
@@ -71,11 +79,26 @@ extern struct utmp *getutent();
 void *toplevel = 0;		/* dummy for formfile.c */
 #endif
 
-static void popup_window(), send_mail(), write_script(), exec_program();
-static char *get_subject(), *get_subtitle(), *get_icontitle();
-#ifdef MIPS
-extern char *getenv(), *malloc(), *realloc();
+static void popup_window	(int, struct entry *);
+static void send_mail		(int, struct entry *);
+static void reaper		(int);
+static void exec_program	(struct entry *, char *, BOOL);
+static void write_script	(char *, char *);
+#ifdef JAPAN
+static int chkctype		(unsigned char, int);
+static unsigned short e2j	(unsigned short);
+static unsigned short sj2j	(unsigned short);
+static unsigned char *mimeencode(unsigned char *, unsigned short *,
+							unsigned short *);
+static void sprintmime		(unsigned char *, unsigned char *);
 #endif
+static char *get_subject	(int, struct entry *, BOOL);
+static char *get_subtitle	(struct entry *);
+static char *get_icontitle	(int, struct entry *);
+static void sighand		(int);
+static void usage		(void);
+static void alert		(struct entry *, int);
+void create_error_popup		(void *, int, char *, ...);
 
 char			*progname;	/* argv[0] */
 extern char		lockpath[];	/* lockfile path (from lock.c) */
@@ -86,18 +109,18 @@ static BOOL		reread;		/* caught SIGHUP, re-read mainlist */
 static BOOL		debug;		/* print debugging information */
 static BOOL		opt_t;		/* TRUE if -t (tty) */
 extern int		errno;		/* system error */
-static void sighand(), alert(), usage();
 
-int write_one_entry() {return(0);}	/* never used, for network.o */
-int curr_year;				/* dummy for DST calculating routines*/
-Widget mainwindow;			/* dummy for error popup in network.c*/
-XtInputId register_X_input(){return(0);}/* more dummies */
-void unregister_X_input() {}
+int			curr_year;	/* dummy for DST calculating routines*/
+Widget			mainwindow;	/* dummy for error popup in network.c*/
+					/* dummy functions, never used: */
+int	  write_one_entry    (int (*a)(), struct entry *e) {return(0);}
+XtInputId register_X_input   (int a)			   {return(0);}
+void	  unregister_X_input (XtInputId a)		   {}
 
 
-main(argc, argv)
-	char			**argv;
-	int			argc;
+int main(
+	int			argc,
+	char			**argv)
 {
 	PID_T			pid;		/* pid in lockfile */
 	int			reason;		/* what triggers next? */
@@ -138,8 +161,8 @@ main(argc, argv)
 			usage();
 
 	if ((opt_l || opt_s) && !(pw = getpwuid(getuid())))
-		fprintf(stderr, "%s: WARNING: can't read user name.\n%s",
-				progname, "Try running with -L option.\n");
+		fprintf(stderr, _("%s: WARNING: can't read user name.\n%s"),
+				progname, _("Try running with -L option.\n"));
 	if (!debug) {
 		(void)umask(0077);
 		setuid(getuid());
@@ -149,7 +172,8 @@ main(argc, argv)
 			exit(0);
 		}
 		if (pid == -1)
-			fprintf(stderr,"%s: Warning: cannot fork\n", progname);
+			fprintf(stderr, _("%s: Warning: cannot fork\n"),
+								progname);
 		else
 			ORPHANIZE;
 	}
@@ -164,13 +188,16 @@ main(argc, argv)
 #ifdef ITIMER
 	signal(SIGALRM, sighand);
 #endif
-	if (!startup_lock(LOCK_PATH, opt_k || opt_K))
+	if (!startup_lock(resolve_tilde(PLANDLOCK), opt_k || opt_K))
 		if (opt_k || opt_K)
-			fatal("cannot kill existing %s daemon", progname);
+			fatal(_("cannot kill existing %s daemon"), progname);
 		else
-			fatal("another daemon exists, use %s -k", progname);
-	if (opt_K)
+			fatal(_("another daemon exists, use %s -k"), progname);
+	if (opt_K) {
+		(void)unlink(lockpath);
 		exit(0);
+	}
+
 
 	/*
 	 * main loop
@@ -190,7 +217,7 @@ main(argc, argv)
 	for (;;) {
 	    if (reread) {
 		if (debug)
-		    printf("%s: re-reading database\n", progname);
+		    printf(_("%s: re-reading database\n"), progname);
 		destroy_list(&mainlist);
 		create_list(&mainlist);
 		read_mainlist();
@@ -217,7 +244,7 @@ main(argc, argv)
 	    while (total_wait && !reread) {
 		twait = total_wait>1*60 ? 1*60 : total_wait;
 		if (debug)
-		    printf("%s: sleeping for %d:%02d:%02d\n", progname,
+		    printf(_("%s: sleeping for %d:%02d:%02d\n"), progname,
 			   (int)twait/3600, (int)(twait/60)%60, (int)twait%60);
 #ifdef ITIMER
 		itv.it_value.tv_sec = twait;
@@ -230,7 +257,7 @@ main(argc, argv)
 #else
 		sleep(twait);
 #endif
-		refresh_lock(LOCK_PATH);
+		refresh_lock(resolve_tilde(PLANDLOCK));
 		logged_in = FALSE;
 		if (pw) {
 #if defined(SUN) || defined(BSD) || defined(__FreeBSD__)
@@ -253,6 +280,9 @@ main(argc, argv)
 			}
 			close(fd);
 		    }
+#elif defined(ULTRIX)
+		    short pid = getpid();
+		    logged_in = TRUE;
 #else
 		    short pid = getpid();
 		    setutent();
@@ -266,17 +296,18 @@ main(argc, argv)
 #endif
 		}
 		if (got_login && !logged_in && !opt_s) {
-		    printf("%s: you have logged out, exiting (try -L?)\n",
+		    printf(_("%s: you have logged out, exiting (try -L?)\n"),
 							    progname);
+		    (void)unlink(lockpath);
 		    exit(0);
 		}
 		if (logged_in) {
 		    got_login = TRUE;
 		    if (debug)
-			printf("%s: utmp works, watching for logout",
+			printf(_("%s: utmp works, watching for logout"),
 							    progname);
 		} else if (opt_s && debug)
-			printf("%s: logged out, keeping quiet", progname);
+			printf(_("%s: logged out, keeping quiet"), progname);
 		total_wait -= twait;
 	    }
 	}
@@ -287,12 +318,13 @@ main(argc, argv)
 /*
  * An entry triggered, because its early-warn time, late-warn time, or alarm
  * time was reached (reason is 1, 2, or 3, respectively). Do whatever was
- * requested. Don't exec scripts that came from a server, too insecure.
+ * requested. Don't exec scripts that came from a server unless explicitly
+ * allowed, too insecure.
  */
 
-static void alert(entry, reason)
-	register struct entry	*entry;		/* entry that triggered */
-	int			reason;		/* why: 1=early,2=late,3=time*/
+static void alert(
+	register struct entry	*entry,		/* entry that triggered */
+	int			reason)		/* why: 1=early,2=late,3=time*/
 {
 	char			cmd[4096];	/* command to execute */
 
@@ -333,10 +365,12 @@ static void alert(entry, reason)
 			exec_program(entry, cmd, FALSE);
 		}
 		if (entry->script)
-			if (!entry->user || !entry->id)
+			if (!config.insecure_script &&
+						(!entry->user || !entry->id))
 				exec_program(entry, entry->script, TRUE);
 			else
-				fprintf(stderr, "%s: ignoring insecure script",
+				fprintf(stderr,
+					_("%s: ignoring insecure script"),
 								progname);
 	}
 }
@@ -349,9 +383,9 @@ static void alert(entry, reason)
  * argument determines the color of the popup.
  */
 
-static void popup_window(reason, entry)
-	int			reason;		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry;		/* entry that triggered */
+static void popup_window(
+	int			reason,		/* why: 1=early,2=late,3=time*/
+	register struct entry	*entry)		/* entry that triggered */
 {
 	char			prog[1024];	/* path of notifier program */
 	char			cmd[2048];	/* command string */
@@ -362,7 +396,7 @@ static void popup_window(reason, entry)
 		return;
 	}
 	if (!find_file(prog, ALARM_FN, TRUE)) {
-		fprintf(stderr, "%s: %s: not found\n", progname, ALARM_FN);
+		fprintf(stderr, _("%s: %s: not found\n"), progname, ALARM_FN);
 		return;
 	}
 	if (config.wintimeout > 59)
@@ -388,15 +422,15 @@ static void popup_window(reason, entry)
  * send mail because that would be a security hole.
  */
 
-static void send_mail(reason, entry)
-	int			reason;		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry;		/* entry that triggered */
+static void send_mail(
+	int			reason,		/* why: 1=early,2=late,3=time*/
+	register struct entry	*entry)		/* entry that triggered */
 {
 	char			cmd[2048];	/* command string */
 	char			subject[512];	/* quoted subject */
 
 	if (!config.mailer || !*config.mailer) {
-		fprintf(stderr, "%s: no mailer defined\n", progname);
+		fprintf(stderr, _("%s: no mailer defined\n"), progname);
 		return;
 	}
 	strcpy(subject+1, get_subject(reason, entry, TRUE));
@@ -419,8 +453,8 @@ static void send_mail(reason, entry)
  */
 
 /*ARGSUSED*/
-static void reaper(sig)				/* lay dead children to rest */
-	int sig;
+static void reaper(
+	int			sig)
 {
 	char			path[40];	/* script to delete */
 #if (defined BSD && !defined OSF && !defined __FreeBSD__)
@@ -430,16 +464,16 @@ static void reaper(sig)				/* lay dead children to rest */
 #endif
 	sprintf(path, "/tmp/pland%d", wait(&dummy));
 	if (debug)
-		printf("%s: deleting script \"%s\"\n", progname, path);
+		printf(_("%s: deleting script \"%s\"\n"), progname, path);
 	(void)unlink(path);
 	signal(SIGCHLD, reaper);
 }
 
 
-static void exec_program(entry, program, script)
-	register struct entry	*entry;		/* entry that triggered */
-	char			*program;	/* program or script to exec */
-	BOOL			script;		/* run program in a subshell */
+static void exec_program(
+	register struct entry	*entry,		/* entry that triggered */
+	char			*program,	/* program or script to exec */
+	BOOL			script)		/* run program in a subshell */
 {
 	int			fd[2];		/* pipe to child process */
 	PID_T			pid;		/* child process id */
@@ -494,7 +528,7 @@ static void exec_program(entry, program, script)
 		if (!find_file(progpath, argv[0], TRUE)) {
 			FILE *err;
 			if (err = fopen("/dev/console", "w")) {
-				fprintf(err, "%s: %s: not found\n",
+				fprintf(err, _("%s: %s: not found\n"),
 							progname, argv[0]);
 				fclose(err);
 			}
@@ -502,7 +536,8 @@ static void exec_program(entry, program, script)
 		}
 		if (debug) {
 			int i;
-			printf("%s: running \"%s\", args", progname, progpath);
+			printf(_("%s: running \"%s\", args"), progname,
+								progpath);
 			for (i=0; i < argc; i++)
 				printf(" \"%s\"", argv[i]);
 			printf("\n");
@@ -567,19 +602,21 @@ static void exec_program(entry, program, script)
  * If the first line does not begin with "#!", "#!/bin/sh\n" is inserted.
  */
 
-static void write_script(scriptname, program)
-	char			*scriptname;	/* script name buffer */
-	char			*program;	/* script text */
+static void write_script(
+	char			*scriptname,	/* script name buffer */
+	char			*program)	/* script text */
 {
 	int			len;		/* size of program */
 	int			fd;		/* script file */
 
 	sprintf(scriptname, "/tmp/pland%d", getpid());
 	if (debug)
-		printf("%s: generating script \"%s\"\n", progname, scriptname);
+		printf(_("%s: generating script \"%s\"\n"), progname,
+								scriptname);
 	if ((fd = open(scriptname, O_WRONLY | O_CREAT | O_TRUNC, 0777)) < 0) {
 		int err = errno;
-		fprintf(stderr, "%s: can't create %s: ", progname, scriptname);
+		fprintf(stderr, _("%s: can't create %s: "), progname,
+								scriptname);
 		errno = err;
 		perror("");
 		exit(1);
@@ -589,7 +626,8 @@ static void write_script(scriptname, program)
 	    write(fd, "#!/bin/sh\n", 10) != 10 ||
 	    write(fd, program, len) != len) {
 		int err = errno;
-		fprintf(stderr, "%s: can't write to %s: ",progname,scriptname);
+		fprintf(stderr, _("%s: can't write to %s: "), progname,
+								scriptname);
 		errno = err;
 		perror("");
 		close(fd);
@@ -641,9 +679,9 @@ static unsigned char base64[] = {
  * Ogura Yoshito changed chkctype().
  */
 
-static int chkctype(ch, stat)
-	unsigned char	ch;
-	int		stat;
+static int chkctype(
+	unsigned char	ch,
+	int		stat)
 {
 	switch (stat) {
 	  case CT_ASC:
@@ -689,10 +727,10 @@ static int chkctype(ch, stat)
 }
 
 
-static unsigned short e2j(wc)
-	unsigned short wc;
+static unsigned short e2j(
+	unsigned short	wc)
 {
-	return (wc & 0x7F7F);
+	return(wc & 0x7F7F);
 }
 
 
@@ -702,8 +740,8 @@ static unsigned short e2j(wc)
  * AUTHOR: Itaru ICHIKAWA (ichikawa@flab.fujitsu.co.jp)
  */
 
-static unsigned short sj2j(wc)
-	unsigned short wc;
+static unsigned short sj2j(
+	unsigned short	wc)
 {
 	return (((((wc >> 8) << 1) - (((wc >> 8) > 0x9f) << 7) - 0xe1) << 8) +
 		((wc & 0x00ff) >= 0x9f ? (wc & 0x00ff) - 0x7e | 0x100
@@ -712,9 +750,10 @@ static unsigned short sj2j(wc)
 }
 
 
-static unsigned char *mimeencode(p, jis, end)
-	unsigned char	*p;
-	unsigned short	*jis, *end;
+static unsigned char *mimeencode(
+	unsigned char	*p,
+	unsigned short	*jis,
+	unsigned short	*end)
 {
 	unsigned char	*tmp, *begin, buf[80];
 	int		i;
@@ -759,8 +798,9 @@ static unsigned char *mimeencode(p, jis, end)
 }
 
 
-static void sprintmime(dptr, sptr)
-	unsigned char	*dptr, *sptr;
+static void sprintmime(
+	unsigned char	*dptr,
+	unsigned char	*sptr)
 {
 	unsigned char	*p = sptr;
 	unsigned short	*wcp, wc, buf[40];	/* works for a 2-byte char */
@@ -823,10 +863,10 @@ static void sprintmime(dptr, sptr)
  * to tell the user what is happening. At most 79 characters are returned.
  */
 
-static char *get_subject(reason, entry, withnote)
-	int			reason;		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry;		/* entry that triggered */
-	BOOL			withnote;	/* append note string too */
+static char *get_subject(
+	int			reason,		/* why: 1=early,2=late,3=time*/
+	register struct entry	*entry,		/* entry that triggered */
+	BOOL			withnote)	/* append note string too */
 {
 	static char		msg[512];
 	time_t			time = (entry->time % 86400) / 60;
@@ -838,8 +878,8 @@ static char *get_subject(reason, entry, withnote)
 		if (time < 60)
 			time = 12*60;
 	}
-	sprintf(msg, reason==1 || reason==2 ? "Warning: alarm at %d:%02d%c"
-					    : "ALARM at %d:%02d%c",
+	sprintf(msg, reason==1 || reason==2 ? _("Warning: alarm at %d:%02d%c")
+					    : _("ALARM at %d:%02d%c"),
 	 					       time/60, time%60, ampm);
 	if (withnote && entry->note != 0) {
 		int len = strlen(msg);
@@ -865,8 +905,8 @@ static char *get_subject(reason, entry, withnote)
  * Return a subtitle string with extra info for notifier window
  */
 
-static char *get_subtitle(entry)
-	register struct entry	*entry;		/* entry that triggered */
+static char *get_subtitle(
+	register struct entry	*entry)		/* entry that triggered */
 {
 	static char		msg[160];
 	time_t			time;
@@ -874,7 +914,7 @@ static char *get_subtitle(entry)
 
 	*msg = 0;
 	if (entry->user)
-		sprintf(msg, "user %s", entry->user);
+		sprintf(msg, _("user %s"), entry->user);
 
 	if (entry->length) {
 		time = ((entry->time + entry->length) % 86400) / 60;
@@ -886,7 +926,7 @@ static char *get_subtitle(entry)
 		}
 		if (*msg)
 			strcat(msg, ": ");
-		sprintf(msg+strlen(msg), "length %d:%02d, until %d:%02d%c",
+		sprintf(msg+strlen(msg), _("length %d:%02d, until %d:%02d%c"),
 				entry->length/3600, (entry->length/60)%60,
 				time/60, time%60, ampm);
 	}
@@ -905,9 +945,9 @@ static char *get_subtitle(entry)
  * contains the time of the trigger, and "early" or "late" flags.
  */
 
-static char *get_icontitle(reason, entry)
-	int			reason;		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry;		/* entry that triggered */
+static char *get_icontitle(
+	int			reason,		/* why: 1=early,2=late,3=time*/
+	register struct entry	*entry)		/* entry that triggered */
 {
 	static char		msg[20];
 	time_t			time = (entry->time % 86400) / 60;
@@ -935,8 +975,8 @@ static char *get_icontitle(reason, entry)
  * all others terminate the program and delete the lockfile.
  */
 
-static void sighand(sig)
-	int			sig;		/* signal type */
+static void sighand(
+	int			sig)		/* signal type */
 {
 #ifdef ITIMER
 	if (sig == SIGALRM)
@@ -948,7 +988,7 @@ static void sighand(sig)
 		reread = TRUE;
 	} else {					/* die */
 		(void)unlink(lockpath);
-		fprintf(stderr, "%s: killed with signal %d\n", progname, sig);
+		fprintf(stderr, _("%s: killed with signal %d\n"),progname,sig);
 		exit(0);
 	}
 }
@@ -960,14 +1000,21 @@ static void sighand(sig)
  */
 
 #ifndef VARARGS
-void create_error_popup(void *widget, int error, char *fmt, ...)
+void create_error_popup(
+	void		*widget,
+	int		error,
+	char		*fmt, ...)
 {
 	va_list		parm;
 #else
-void create_error_popup(widget, error, fmt, a, b, c, d)
-	void		*widget;
-	int		error, a, b, c, d;
-	char		*fmt;
+void create_error_popup(
+	void		*widget,
+	int		error,
+	char		*fmt,
+	int		a,
+	int		b,
+	int		c,
+	int		d)
 {
 #endif
 	fprintf(stderr, "%s: ", progname);
@@ -991,23 +1038,23 @@ void create_error_popup(widget, error, fmt, a, b, c, d)
  * usage message if incorrect options are given
  */
 
-static void usage()
+static void usage(void)
 {
-	fprintf(stderr, "%s: plan calendar daemon, version %s.\n",
-							progname, VERSION);
-	fprintf(stderr, "Usage: pland [-dkKlL]\n");
-	fprintf(stderr, "-d\tdebug: stay in foreground, print actions\n");
-	fprintf(stderr, "-k\tkill existing daemon, then continue\n");
-	fprintf(stderr, "-K\tkill existing daemon only\n");
-	fprintf(stderr, "-t\tdon't pop up notifier windows, print to stdout\n");
-	fprintf(stderr, "-s\twatch utmp and sleep while user is logged out\n");
-	fprintf(stderr, "-l\twatch utmp and exit when user logs out\n");
-	fprintf(stderr, "-L\tdon't watch utmp (utmp is often buggy)\n");
+	fprintf(stderr, _("%s: plan calendar daemon, version %s.\n"),
+					progname, VERSION JAPANVERSION);
+	fprintf(stderr, _("Usage: pland [-dkKtslL]\n"));
+	fprintf(stderr, _("-d\tdebug: stay in foreground, print actions\n"));
+	fprintf(stderr, _("-k\tkill existing daemon, then continue\n"));
+	fprintf(stderr, _("-K\tkill existing daemon only\n"));
+	fprintf(stderr, _("-t\tdon't pop up notifier windows, print to stdout\n"));
+	fprintf(stderr, _("-s\twatch utmp and sleep while user is logged out\n"));
+	fprintf(stderr, _("-l\twatch utmp and exit when user logs out\n"));
+	fprintf(stderr, _("-L\tdon't watch utmp (utmp is often buggy)\n"));
 	fprintf(stderr,
 #	ifdef RABBITS
-		"-L is the default. Try -l if you get too many pland's.\n");
+		_("-L is the default. Try -l if you get too many pland's.\n"));
 #	else
-		"-l is the default. Try -d or -L if pland exits early.\n");
+		_("-l is the default. Try -d or -L if pland exits early.\n"));
 #	endif
 	exit(1);
 }
