@@ -22,7 +22,10 @@
 #define BOUND(t,a,b)	((t)<(a) ? (a) : (t)>(b) ? (b) : (t));
 #define YPOS(t)		(((t) - c->day_minhour*3600) * c->day_hourheight/3600)
 
-static void gen_day(), draw_bar(), draw_octagon(), draw_boxtext();
+static void gen_day	(void);
+static void draw_bar	(struct weeknode *, int, int, int);
+static void draw_octagon(int, BOOL, int, int, int, int);
+static void draw_boxtext(int, int, int, int, char *, BOOL);
 
 #ifdef JAPAN
 extern int truncate_strpack();
@@ -41,9 +44,6 @@ extern struct plist	*mainlist;	/* list of all schedule entries */
 extern struct holiday	holiday[366];	/* info for each day, separate for */
 extern struct holiday	sm_holiday[366];/* full-line texts under, and small */
 
-extern char *weekday_name[];
-extern char *monthname[];
-
 
 /*
  * for a given position on the canvas, identify the entry there and return
@@ -61,14 +61,17 @@ extern char *monthname[];
  *   M_RIGHT	entry	time	trigg	pos/sz	near bottom edge, move length
  */
 
-MOUSE locate_in_day_calendar(epp, warn, time, trigger, xp,yp,xsp,ysp, xc,yc)
-	struct entry		**epp;		/* returned entry or 0 */
-	BOOL			*warn;		/* is *epp an n-days-ahead w?*/
-	time_t			*time;		/* if *epp=0, clicked where */
-	time_t			*trigger;	/* if *epp=0, entry trigger */
-	int			*xp,  *yp;	/* if M_INSIDE, rubber box */
-	int			*xsp, *ysp;	/* position and size */
-	int			xc, yc;		/* pixel pos clicked */
+MOUSE locate_in_day_calendar(
+	struct entry		**epp,		/* returned entry or 0 */
+	BOOL			*warn,		/* is *epp an n-days-ahead w?*/
+	time_t			*time,		/* if *epp=0, clicked where */
+	time_t			*trigger,	/* if *epp=0, entry trigger */
+	int			*xp,		/* if M_INSIDE, rubber box */
+	int			*yp,
+	int			*xsp,		/* position and size */
+	int			*ysp,
+	int			xc,		/* pixel pos clicked */
+	int			yc)
 {
 	register struct config	*c = &config;
 	struct weeknode		*vert, *horz;	/* yov node scan pointers */
@@ -160,8 +163,8 @@ MOUSE locate_in_day_calendar(epp, warn, time, trigger, xp,yp,xsp,ysp, xc,yc)
  * draw one day into the current window, in the specified region (all if null).
  */
 
-void draw_day_calendar(region)
-	Region region;
+void draw_day_calendar(
+	Region	region)
 {
 	if (!g_init_window(&day, region))
 		return;
@@ -176,9 +179,9 @@ void draw_day_calendar(region)
  * print PostScript day calendar to file fp.
  */
 
-void print_day_calendar(fp, landscape)
-	FILE	*fp;
-	BOOL	landscape;
+void print_day_calendar(
+	FILE	*fp,
+	BOOL	landscape)
 {
 	time_t time = get_time();
 	struct tm *tm = time_to_tm(time);
@@ -197,7 +200,7 @@ void print_day_calendar(fp, landscape)
  * draw the day, using low-level routines
  */
 
-static void gen_day()
+static void gen_day(void)
 {
 	register struct config	*c = &config;
 	time_t			today;		/* today's date */
@@ -208,7 +211,7 @@ static void gen_day()
 	int			dx, dy;		/* size inside day line box */
 	int			cy_h, cy_d;	/* character height */
 	struct weeknode		*vert, *horz;	/* day node scan pointers */
-	struct holiday		*hp, *shp;	/* to check for holidays */
+	struct holiday		*hp, *shp, *holp;/* to check for holidays */
 	struct tm		*tm;		/* today's date as m/d/y */
 #ifdef JAPAN
 	strpack			partialstr[MAXPARTIALSTRING];
@@ -249,6 +252,13 @@ static void gen_day()
 	hp  =    &holiday[tm->tm_yday];
 
 	for (d=0; d < c->day_ndays; d++, hp++, shp++) {		/* day loop */
+		tm = time_to_tm(curr_day + d*86400);
+		if (tm->tm_yday == 0) {				/* new year? */
+			if (p = parse_holidays(tm->tm_year, FALSE))
+				create_error_popup(mainmenu.cal, 0, p);
+			shp = &sm_holiday[0];
+			hp  =    &holiday[0];
+		}
 		if (!(dx = day.nlines[d] * xs))
 			continue;
 
@@ -264,20 +274,20 @@ static void gen_day()
 		truncate_string(p, dx, FONT_WHOUR);
 		g_drawtext(x0, y0-4-c->day_headline, p, strlen(p));
 								/* holiday */
-		if (p = hp->string ? hp->string : shp->string) {
-			g_setcolor(shp->stringcolor ? shp->stringcolor :
-				   shp->daycolor    ? shp->daycolor
+		if ((holp = hp->string ? hp : shp)->string) {
+			g_setcolor(holp->stringcolor ? holp->stringcolor :
+				   holp->daycolor    ? holp->daycolor
 						    : COL_WDAY);
 #ifdef JAPAN
 			partialstr->strptr = strpool;
-			if (mixedstrlen_in_pixels(shp->string,
+			if (mixedstrlen_in_pixels(holp->string,
 				      partialstr, FONT_WNOTE, FONT_JNOTE) > dx)
 				truncate_strpack(partialstr, dx, FONT_WNOTE);
 			g_draw_strpack(x0, y0-4, partialstr);
 #else
-			strncpy(buf, shp->string, sizeof(buf)-1);
+			strncpy(buf, holp->string, sizeof(buf)-1);
 			truncate_string(buf, dx, FONT_WDAY);
-			g_drawtext(x0, y0-4, p, strlen(p));
+			g_drawtext(x0, y0-4, buf, strlen(buf));
 #endif
 		}
 		g_setcolor(COL_WBOXBACK);			/* box bgnd */
@@ -309,10 +319,11 @@ static void gen_day()
  * draw one entry bar.
  */
 
-static void draw_bar(node, color, x, y)
-	struct weeknode		*node;		/* entry node to print */
-	int			color;		/* color, 0..7 */
-	int			x, y;		/* top left pos in canvas */
+static void draw_bar(
+	struct weeknode		*node,		/* entry node to print */
+	int			color,		/* color, 0..7 */
+	int			x,		/* top left pos in canvas */
+	int			y)
 {
 	register struct entry	*ep = node->entry;
 	register struct config	*c = &config;
@@ -351,10 +362,8 @@ static void draw_bar(node, color, x, y)
 			sprintf(msg+strlen(msg), "-%s", mktimestring(
 					node->trigger + ep->length, FALSE));
 		if (node->days_warn)
-			strcat(msg, " (warn)");
+			strcat(msg, _(" (warn)"));
 	}
-	if (ep->user && strcmp(ep->user, user[0].name))
-		sprintf(msg+strlen(msg), " (%s)", ep->user);
 	strcat(msg, " ");
 	strcat(msg, node->text);
 
@@ -371,12 +380,13 @@ static void draw_bar(node, color, x, y)
  * from the topmost vertex at the left edge (10-o'clock position)
  */
 
-static void draw_octagon(color, checker, x, y, ye, yend)
-	int	color;		/* color, 0..7 */
-	BOOL	checker;	/* add checkerboard pattern */
-	int	x, y;		/* top left XY pos in canvas */
-	int	ye;		/* Y bottom in canvas */
-	int	yend;		/* bottom Y clip limit */
+static void draw_octagon(
+	int	color,		/* color, 0..7 */
+	BOOL	checker,	/* add checkerboard pattern */
+	int	x,		/* top left XY pos in canvas */
+	int	y,
+	int	ye,		/* Y bottom in canvas */
+	int	yend)		/* bottom Y clip limit */
 {
 	XPoint	point[9];	/* polygon vertex list */
 
@@ -420,11 +430,13 @@ static void draw_octagon(color, checker, x, y, ye, yend)
 #define ISSPACE(c) ((c)==' ' || (c)=='\t')
 #define MAXSPLIT 6
 
-static void draw_boxtext(x, y, xs, ys, text, center)
-	int		x, y;		/* top left corner of free space */
-	int		xs, ys;		/* size of free space */
-	char		*text;		/* text to print */
-	BOOL		center;		/* center text? */
+static void draw_boxtext(
+	int		x,		/* top left corner of free space */
+	int		y,
+	int		xs,		/* size of free space */
+	int		ys,
+	char		*text,		/* text to print */
+	BOOL		center)		/* center text? */
 {
 	char		*beg, *p, *p_s;	/* soln, curr char, since last space */
 	int		len, len_s;	/* curr text length in pixels */
