@@ -33,9 +33,8 @@
  *	destroy_entry(entry)		Free all malloced strings of an entry.
  */
 
-#ifndef MIPS
+#include <stdio.h>
 #include <stdlib.h>
-#endif
 #include <time.h>
 #include <Xm/Xm.h>
 #include "cal.h"
@@ -55,8 +54,8 @@ time_t			cutoff;		/* no alarms before this time */
  * (shouldn't happen).
  */
 
-int name_to_user(name)
-	char		*name;		/* name to look up */
+int name_to_user(
+	char		*name)		/* name to look up */
 {
 	int		u;		/* index into user array */
 
@@ -75,12 +74,12 @@ int name_to_user(name)
  * are all filled, add_entry will allocate more. It's usually enough though.
  */
 
-void create_list(list)
-	struct plist		**list;		/* pointer to list pointer */
+void create_list(
+	struct plist	**list)		/* pointer to list pointer */
 {
 	if (!(*list = (struct plist *)malloc(sizeof(struct plist) +
 					    sizeof(struct entry) * CHUNK)))
-		fatal("no memory");
+		fatal(_("no memory"));
 	(*list)->modified  = FALSE;
 	(*list)->locked    = FALSE;
 	(*list)->nentries  = 0;
@@ -95,10 +94,10 @@ void create_list(list)
  * gets a HUP signal. Ignore the lint complaint.
  */
 
-void destroy_list(list)
-	struct plist		**list;		/* pointer to list pointer */
+void destroy_list(
+	struct plist	**list)		/* pointer to list pointer */
 {
-	register int		i;		/* entry counter */
+	register int	i;		/* entry counter */
 
 	if (!*list)
 		return;
@@ -117,10 +116,10 @@ void destroy_list(list)
  * modified index n.
  */
 
-static int sort_same_time(entry, list, n)
-	register struct entry	*entry;		/* changed entry */
-	struct plist		*list;		/* list to adjust */
-	int			n;		/* index to proposed new pos */
+static int sort_same_time(
+	register struct entry	*entry,		/* changed entry */
+	struct plist		*list,		/* list to adjust */
+	int			n)		/* index to proposed new pos */
 {
 	static int		seq;		/* ensures stable sort */
 
@@ -146,9 +145,9 @@ static int sort_same_time(entry, list, n)
  * trashing the chain.
  */
 
-int add_entry(list, entry)
-	struct plist		**list;		/* list to add to */
-	struct entry		*entry;		/* entry to add */
+int add_entry(
+	struct plist		**list,		/* list to add to */
+	struct entry		*entry)		/* entry to add */
 {
 	int			num = 0;	/* # of entries in old list */
 	int			size = 0;	/* size of allocated old list*/
@@ -167,7 +166,7 @@ int add_entry(list, entry)
 		size += CHUNK;
 		if (!(new = (struct plist *)malloc(sizeof(struct plist) +
 						  sizeof(struct entry) *size)))
-			fatal("no memory");
+			fatal(_("no memory"));
 		if (!*list)
 			new->nentries = 0;		/* start new list... */
 		else {
@@ -207,9 +206,9 @@ int add_entry(list, entry)
  * Call rebuild_repeat_chain() afterwards, this routine trashes the chain.
  */
 
-void delete_entry(list, n)
-	struct plist		*list;		/* list to delete from */
-	int			n;		/* index to entry to delete */
+void delete_entry(
+	struct plist		*list,		/* list to delete from */
+	int			n)		/* index to entry to delete */
 {
 	register struct entry	*q;		/* entry copy pointer */
 	register int		i;		/* entry copy counter */
@@ -237,10 +236,10 @@ void delete_entry(list, n)
  * Call rebuild_repeat_chain() afterwards, this routine trashes the chain.
  */
 
-void delete_entry_by_id(list, file, id)
-	struct plist		*list;		/* list to delete from */
-	unsigned int		file;		/* file ID from server */
-	int			id;		/* row ID from server */
+void delete_entry_by_id(
+	struct plist		*list,		/* list to delete from */
+	unsigned int		file,		/* file ID from server */
+	int			id)		/* row ID from server */
 {
 	register struct entry	*ep;		/* entry search pointer */
 	register int		n;		/* entry search counter */
@@ -262,9 +261,9 @@ void delete_entry_by_id(list, file, id)
  * Call rebuild_repeat_chain() afterwards, this routine trashes the chain.
  */
 
-int resort_entry(list, n)
-	struct plist		*list;		/* list to re-sort */
-	int			n;		/* index to changed entry */
+int resort_entry(
+	struct plist		*list,		/* list to re-sort */
+	int			n)		/* index to changed entry */
 {
 	struct lookup		lookup;		/* result of entry lookup */
 	register struct entry	*p;		/* entry copy pointer */
@@ -316,8 +315,8 @@ int resort_entry(list, n)
  * once at EOF, not every time an entry is added.
  */
 
-void rebuild_repeat_chain(list)
-	struct plist		*list;		/* list to delete from */
+void rebuild_repeat_chain(
+	struct plist		*list)		/* list to delete from */
 {
 	register int		*prev;		/* previous chain pointer */
 	register struct entry	*ep;		/* scan pointer */
@@ -357,16 +356,17 @@ void rebuild_repeat_chain(list)
  * Return FALSE if the lookup failed, and we fell off the end of the list.
  */
 
-static lookup_regular_entry(), lookup_repeating_entry();
-
-BOOL lookup_entry(lookup, list, time, exact, norep, which, usr)
-	register struct lookup	*lookup;	/* return struct */
-	register struct plist	*list;		/* list of entries */
-	time_t			time;		/* time to locate */
-	BOOL			exact;		/* need entry, not insert pt */
-	BOOL			norep;		/* ignore instances */
-	char			which;		/* 'mywod': mon,yr,wk,yov,day*/
-	int			usr;		/* user number or -1 */
+static int lookup_regular_entry  (struct plist *, time_t, BOOL, BOOL);
+static int lookup_repeating_entry(struct plist *, time_t, BOOL, time_t *,
+							char, int, BOOL *);
+BOOL lookup_entry(
+	register struct lookup	*lookup,	/* return struct */
+	register struct plist	*list,		/* list of entries */
+	time_t			time,		/* time to locate */
+	BOOL			exact,		/* need entry, not insert pt */
+	BOOL			norep,		/* ignore instances */
+	char			which,		/* 'mywod': mon,yr,wk,yov,day*/
+	int			usr)		/* user number or -1 */
 {
 	int			repindex, regindex;
 	time_t			reptime = -1, regtime = -1;
@@ -399,11 +399,11 @@ BOOL lookup_entry(lookup, list, time, exact, norep, which, usr)
 }
 
 
-static int lookup_regular_entry(list, time, exact, norep)
-	struct plist		*list;		/* list of entries */
-	time_t			time;		/* time to locate */
-	BOOL			exact;		/* need entry, not insert pt */
-	BOOL			norep;		/* treat repeaters as regular*/
+static int lookup_regular_entry(
+	struct plist		*list,		/* list of entries */
+	time_t			time,		/* time to locate */
+	BOOL			exact,		/* need entry, not insert pt */
+	BOOL			norep)		/* treat repeaters as regular*/
 {
 	register struct entry	*entry;		/* entry array */
 	register int		lo, hi, mid;	/* binary search indices */
@@ -434,14 +434,14 @@ static int lookup_regular_entry(list, time, exact, norep)
 }
 
 
-static int lookup_repeating_entry(list, time, exact, reptime, which, usr, warn)
-	struct plist		*list;		/* list of entries */
-	time_t			time;		/* time to locate */
-	BOOL			exact;		/* need entry, not insert pt */
-	time_t			*reptime;	/* returned repeat time */
-	char			which;		/* 'mywd': month,yr,week,day */
-	int			usr;		/* user number or -1 */
-	BOOL			*warn;		/* found a n-days-ahead warn?*/
+static int lookup_repeating_entry(
+	struct plist		*list,		/* list of entries */
+	time_t			time,		/* time to locate */
+	BOOL			exact,		/* need entry, not insert pt */
+	time_t			*reptime,	/* returned repeat time */
+	char			which,		/* 'mywd': month,yr,week,day */
+	int			usr,		/* user number or -1 */
+	BOOL			*warn)		/* found a n-days-ahead warn?*/
 {
 	register struct entry	*entry;		/* entry array */
 	register int		n, i;		/* next repeating entry */
@@ -506,8 +506,8 @@ static int lookup_repeating_entry(list, time, exact, reptime, which, usr, warn)
  * the next regular entry. Then pick the earlier of the two.
  */
 
-BOOL lookup_next_entry(lookup)
-	register struct lookup	*lookup;	/* previously found entry */
+BOOL lookup_next_entry(
+	register struct lookup	*lookup)	/* previously found entry */
 {
 	register struct entry	*entry;		/* entry array */
 	register int		n, i;		/* next repeating entry */
@@ -631,17 +631,17 @@ BOOL lookup_next_entry(lookup)
  * This routine is used by the daemon only. Ignore the lint complaint.
  */
 
-int find_next_trigger(list, time, entryp, wait_time)
-	struct plist		*list;		/* list of entries */
-	time_t			time;		/* time to locate */
-	struct entry		**entryp;	/* ret: entry that was found */
-	time_t			*wait_time;	/* ret: how long until triggr*/
+int find_next_trigger(
+	struct plist		*list,		/* list of entries */
+	time_t			time,		/* time to locate */
+	struct entry		**entryp,	/* ret: entry that was found */
+	time_t			*wait_time)	/* ret: how long until triggr*/
 {
 	BOOL			found;		/* TRUE if lookup succeeded */
 	struct lookup		lookup;		/* result of entry lookup */
 	register struct entry	*ep;		/* current entry */
 	time_t			trigger;	/* next trigger time of *ep */
-	time_t			dist;		/* time distance to event */
+	time_t			dist, t;	/* time distance to event */
 	time_t			mindist = MAXT;	/* smallest distance so far */
 	int			i;		/* for checking exceptions */
 	int			u;		/* user[] index */
@@ -650,8 +650,9 @@ int find_next_trigger(list, time, entryp, wait_time)
 	if (!list)
 		return(0);
 
-	for (found = lookup_entry(&lookup, list, time-3*3600, TRUE, FALSE,
-								'*', -1);
+	t = time % 86400;
+	t = t < 3*3600 ? time - t : time - 3*3600;
+	for (found = lookup_entry(&lookup, list, t, TRUE, FALSE, '*', -1);
 	     found;
 	     found = lookup_next_entry(&lookup)) {
 
@@ -716,9 +717,9 @@ int find_next_trigger(list, time, entryp, wait_time)
  * zeroed.
  */
 
-void clone_entry(new, old)
-	register struct entry	*new;		/* entry to fill in */
-	register struct entry	*old;		/* entry to clone, or 0 */
+void clone_entry(
+	register struct entry	*new,		/* entry to fill in */
+	register struct entry	*old)		/* entry to clone, or 0 */
 {
 	if (!old) {					/* zero new entry */
 		register int i;
@@ -743,8 +744,8 @@ void clone_entry(new, old)
  * the entry itself, it's probably some static buffer.
  */
 
-void destroy_entry(entry)
-	register struct entry	*entry;		/* entry to destroy */
+void destroy_entry(
+	register struct entry	*entry)		/* entry to destroy */
 {
 	if (entry->user)
 		free(entry->user);
