@@ -23,16 +23,14 @@ extern struct config	config;		/* global configuration data */
 extern Pixel		color[NCOLS];	/* colors: COL_* */
 extern struct user	*user;		/* user list (from file_r.c) */
 
-char *mkbuttonstring(), *mknotestring();
-
 
 /*
  * return TRUE if the appointment should show the PIC_EXCEPT icon in the
  * day button
  */
 
-BOOL show_except_pixmap(ep)
-	struct entry	*ep;
+BOOL show_except_pixmap(
+	struct entry	*ep)
 {
 	int		i;
 
@@ -55,8 +53,8 @@ BOOL show_except_pixmap(ep)
  * under the current last row that may have been drawn earlier.
  */
 
-void draw_list(w)
-	struct listmenu		*w;		/* draw into which menu */
+void draw_list(
+	struct listmenu		*w)		/* draw into which menu */
 {
 	register Widget		(*wp)[SC_N];	/* button widget pointer */
 	struct entry		**epp;		/* entry pointer pointer */
@@ -65,10 +63,9 @@ void draw_list(w)
 	int			u;		/* user number */
 	Arg			arg;		/* for toggle/user buttons */
 
+	create_entry_widgets(w, w->sublist ? w->sublist->nentries : 0);
 	wp = w->entry + 1;				/* [0] is header */
 	if (w->sublist) {				/* draw entries */
-	    create_entry_widgets(w, w->sublist->nentries);
-	    wp  = w->entry + 1;
 	    epp = w->sublist->entry;
 	    for (n=0; n <= w->sublist->nentries; n++, wp++, epp++) {
 		if (edit.editing && edit.menu == w && edit.y-1 == n)
@@ -99,12 +96,13 @@ void draw_list(w)
 		print_pixmap((*wp)[SC_RECYCLE], PIC_RECYCLE,
 					ep->rep_every  || ep->rep_days ||
 					ep->rep_yearly || ep->rep_weekdays);
-		print_pixmap((*wp)[SC_MESSAGE], PIC_MESSAGE, ep->message);
+		print_pixmap((*wp)[SC_MESSAGE], PIC_MESSAGE, !!ep->message);
 		print_pixmap((*wp)[SC_SCRIPT], PIC_SCRIPT,
 					!ep->notime && ep->script);
 		print_pixmap((*wp)[SC_EXCEPT], PIC_EXCEPT,
 					show_except_pixmap(ep));
 		print_pixmap((*wp)[SC_PRIVATE], PIC_PRIVATE, ep->private);
+		print_pixmap((*wp)[SC_TODO], PIC_TODO, ep->todo);
 	    }
 	}
 	for (; n < w->nentries; n++, wp++) {		/* draw blank rows */
@@ -125,6 +123,7 @@ void draw_list(w)
 		print_pixmap((*wp)[SC_SCRIPT],  PIC_BLANK, FALSE);
 		print_pixmap((*wp)[SC_EXCEPT],  PIC_BLANK, FALSE);
 		print_pixmap((*wp)[SC_PRIVATE], PIC_BLANK, FALSE);
+		print_pixmap((*wp)[SC_TODO],    PIC_BLANK, FALSE);
 	}
 }
 
@@ -134,9 +133,10 @@ void draw_list(w)
  * for pixmap labels.
  */
 
-char *mkbuttonstring(lw, x, y)
-	struct listmenu		*lw;		/* menu the button is in */
-	int			x, y;		/* column and row (y >= 1) */
+char *mkbuttonstring(
+	struct listmenu		*lw,		/* menu the button is in */
+	int			x,		/* column and row (y >= 1) */
+	int			y)
 {
 	static char		buf[40];	/* string representation */
 	register struct entry	*ep;		/* entry pointer */
@@ -187,7 +187,7 @@ char *mkbuttonstring(lw, x, y)
 		break;
 
 	  case SC_ADVDAYS:
-		sprintf(buf, "%d", ep->days_warn / 86400);
+		sprintf(buf, "%ld", (int)(ep->days_warn / 86400));
 		return(ep->days_warn > 0 ? buf : "");
 
 	  case SC_NOTE:
@@ -202,8 +202,8 @@ char *mkbuttonstring(lw, x, y)
  * because it is also used to print notes into the calendar day boxes.
  */
 
-char *mknotestring(ep)
-	register struct entry	*ep;		/* entry pointer */
+char *mknotestring(
+	register struct entry	*ep)		/* entry pointer */
 {
 	static char		buf[256];	/* string representation */
 	char			*note;		/* note to print */
