@@ -7,10 +7,8 @@
  *	create_except_popup()
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
@@ -27,10 +25,17 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void	done_callback(), text_callback(), clear_callback();
-static void	notime_callback(), acol_callback(), split_callback();
-static void	hide_m_callback(), hide_y_callback(), hide_w_callback();
-static void	hide_o_callback(), hide_d_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void text_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void clear_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void split_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void hide_m_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void hide_y_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void hide_w_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void hide_d_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void hide_o_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void notime_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void acol_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -54,7 +59,7 @@ static Widget		acol_sw[9];	/* choices in acol_w color popup */
  * is done whenever anything changes.
  */
 
-static void fillout_except_menu()
+static void fillout_except_menu(void)
 {
 	Arg			args[2];
 	int			i, col;
@@ -69,12 +74,12 @@ static void fillout_except_menu()
 	col = edit.entry.acolor ? COL_HBLACK + edit.entry.acolor-1 : COL_STD;
 #ifdef XmCSimpleOptionMenu
 	XtSetArg(args[0], XmNforeground, color[col]);
-	XtSetArg(args[1], XmNmenuHistory, acol_sw[edit.entry.acolor]);
+	XtSetArg(args[1], XmNmenuHistory, acol_sw[(int)edit.entry.acolor]);
 	XtSetValues(XmOptionButtonGadget(acol_w), args, 2);
 #else
 	XtSetArg(args[0], XmNforeground, color[col]);
 	XtSetValues(acol_w, args, 1);
-	print_button(acol_w, edit.entry.acolor ? "%d" : "default",
+	print_button(acol_w, edit.entry.acolor ? "%d" : _("default"),
 							edit.entry.acolor-1);
 #endif
 }
@@ -86,7 +91,7 @@ static void fillout_except_menu()
  * dates are eliminated.
  */
 
-static void readback_except_menu()
+static void readback_except_menu(void)
 {
 	char		*string, *p;	/* contents of text widget */
 	int		i, j=0;		/* exception counter */
@@ -108,7 +113,7 @@ static void readback_except_menu()
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_except_popup()
+void destroy_except_popup(void)
 {
 	if (have_shell) {
 		readback_except_menu();
@@ -128,9 +133,9 @@ void destroy_except_popup()
  * initialized with data from edit.entry.
  */
 
-void create_except_popup()
+void create_except_popup(void)
 {
-	Widget			form, frame, form2, line, popup, w, pw;
+	Widget			form, frame, form2, line, popup, w;
 	Arg			args[20];
 	int			n, i;
 	Atom			closewindow;
@@ -141,7 +146,7 @@ void create_except_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Exception Dates",
+	shell = XtCreatePopupShell(_("Exception Dates"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -150,7 +155,8 @@ void create_except_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("excform1", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback,help_callback,(XtPointer)"except");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"except");
 
 							/*--- exceptions ---*/
 	n = 0;
@@ -158,6 +164,14 @@ void create_except_popup()
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	w = XtCreateManagedWidget(_("Exception Dates:"),
+			xmLabelWidgetClass, form, args, n);
+	n = 0;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNshadowType,	XmSHADOW_ETCHED_IN);	n++;
@@ -165,7 +179,8 @@ void create_except_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("excform2", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2,XmNhelpCallback,help_callback,(XtPointer)"except");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"except");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	  XmATTACH_FORM);	n++;
@@ -182,7 +197,7 @@ void create_except_popup()
 	   XtSetArg(args[n], XmNtopAttachment,	   XmATTACH_FORM);	n++;
 	   XtSetArg(args[n], XmNbottomAttachment,  XmATTACH_FORM);	n++;
 	   XtSetArg(args[n], XmNleftAttachment,	   XmATTACH_FORM);	n++;
-	   w = XtCreateManagedWidget("No alarm on", xmLabelWidgetClass,
+	   w = XtCreateManagedWidget(_("No alarm on"), xmLabelWidgetClass,
 			line, args, n);
 	   n = 0;
 	   XtSetArg(args[n], XmNtopAttachment,	   XmATTACH_FORM);	n++;
@@ -197,8 +212,8 @@ void create_except_popup()
 	   XtSetArg(args[n], XmNbackground,	   color[COL_TEXTBACK]);n++;
 	   text_w[i] = XtCreateManagedWidget(" ", xmTextFieldWidgetClass,
 			line, args, n);
-	   XtAddCallback(text_w[i], XmNactivateCallback, text_callback,
-								(XtPointer)i);
+	   XtAddCallback(text_w[i], XmNactivateCallback, (XtCallbackProc)
+	   		text_callback, (XtPointer)i);
 	   n = 0;
 	   XtSetArg(args[n], XmNtopAttachment,	   XmATTACH_FORM);	n++;
 	   XtSetArg(args[n], XmNbottomAttachment,  XmATTACH_FORM);	n++;
@@ -206,11 +221,12 @@ void create_except_popup()
 	   XtSetArg(args[n], XmNleftWidget,	   text_w[i]);		n++;
 	   XtSetArg(args[n], XmNleftOffset,	   16);			n++;
 	   XtSetArg(args[n], XmNwidth,		   80);			n++;
-	   w = XtCreateManagedWidget("Split", xmPushButtonWidgetClass,
+	   w = XtCreateManagedWidget(_("Split"), xmPushButtonWidgetClass,
 			line, args, n);
-	   XtAddCallback(w, XmNactivateCallback, split_callback, (XtPointer)i);
-	   XtAddCallback(form2, XmNhelpCallback, help_callback,
-						(XtPointer)"exc_split");
+	   XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+	   		split_callback, (XtPointer)i);
+	   XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+	   		help_callback, (XtPointer)"exc_split");
 	   n = 0;
 	   XtSetArg(args[n], XmNtopAttachment,	   XmATTACH_FORM);	n++;
 	   XtSetArg(args[n], XmNbottomAttachment,  XmATTACH_FORM);	n++;
@@ -219,11 +235,12 @@ void create_except_popup()
 	   XtSetArg(args[n], XmNleftOffset,	   8);			n++;
 	   XtSetArg(args[n], XmNrightAttachment,   XmATTACH_FORM);	n++;
 	   XtSetArg(args[n], XmNwidth,		   80);			n++;
-	   w = XtCreateManagedWidget("Clear", xmPushButtonWidgetClass,
+	   w = XtCreateManagedWidget(_("Clear"), xmPushButtonWidgetClass,
 			line, args, n);
-	   XtAddCallback(w, XmNactivateCallback, clear_callback, (XtPointer)i);
-	   XtAddCallback(form2, XmNhelpCallback, help_callback,
-						(XtPointer)"exc_clear");
+	   XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+	   		clear_callback, (XtPointer)i);
+	   XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+	   		help_callback, (XtPointer)"exc_clear");
 
 	   n = 0;
 	   XtSetArg(args[n], XmNtopAttachment,	  XmATTACH_WIDGET);	n++;
@@ -241,6 +258,14 @@ void create_except_popup()
 	XtSetArg(args[n], XmNtopOffset,		8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
+	w = XtCreateManagedWidget(_("Options:"),
+			xmLabelWidgetClass, form, args, n);
+	n = 0;
+	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNtopWidget,		w);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNshadowType,	XmSHADOW_ETCHED_IN);	n++;
@@ -248,8 +273,8 @@ void create_except_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("excform3", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback, help_callback,
-						(XtPointer)"exc_flags");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"exc_flags");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -259,10 +284,10 @@ void create_except_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		edit.entry.hide_in_m);	n++;
-	w = XtCreateManagedWidget("Don't show appointment in month view",
+	w = XtCreateManagedWidget(_("Don't show appointment in month view"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-						hide_m_callback, (XtPointer)0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			hide_m_callback, (XtPointer)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -271,10 +296,10 @@ void create_except_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		edit.entry.hide_in_y);	n++;
-	w = XtCreateManagedWidget("Don't show appointment in year view",
+	w = XtCreateManagedWidget(_("Don't show appointment in year view"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-						hide_y_callback, (XtPointer)0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			hide_y_callback, (XtPointer)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -283,10 +308,10 @@ void create_except_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		edit.entry.hide_in_w);	n++;
-	w = XtCreateManagedWidget("Don't show appointment in week view",
+	w = XtCreateManagedWidget(_("Don't show appointment in week view"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-						hide_w_callback, (XtPointer)0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			hide_w_callback, (XtPointer)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -295,10 +320,10 @@ void create_except_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		edit.entry.hide_in_d);	n++;
-	w = XtCreateManagedWidget("Don't show appointment in day view",
+	w = XtCreateManagedWidget(_("Don't show appointment in day view"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-						hide_d_callback, (XtPointer)0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			hide_d_callback, (XtPointer)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -307,10 +332,10 @@ void create_except_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		edit.entry.hide_in_o);	n++;
-	w = XtCreateManagedWidget("Don't show appointment in year overview",
+	w = XtCreateManagedWidget(_("Don't show appointment in year overview"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-						hide_o_callback, (XtPointer)0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			hide_o_callback, (XtPointer)0);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -319,17 +344,17 @@ void create_except_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		edit.entry.notime);	n++;
-	w = XtCreateManagedWidget("Reminder only: no alarms, time not shown",
+	w = XtCreateManagedWidget(_("Reminder only: no alarms, time not shown"),
 			xmToggleButtonWidgetClass, form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-						notime_callback, (XtPointer)0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			notime_callback, (XtPointer)0);
 
 							/*-- appt colors --*/
 #ifdef XmCSimpleOptionMenu
 	popup = XmCreatePulldownMenu(form, "pulldown", NULL, 0);
 	for (i=0; i <= 8; i++) {
 		char name[10];
-		sprintf(name, i ? "%d" : "default", i-1);
+		sprintf(name, i ? "%d" : _("default"), i-1);
 		XtSetArg(args[0], XmNalignment, XmALIGNMENT_CENTER);
 		XtSetArg(args[1], XmNforeground,
 					color[i ? COL_HBLACK+i-1 : COL_STD]);
@@ -338,7 +363,7 @@ void create_except_popup()
 		XtAddCallback(acol_sw[i], XmNactivateCallback,
 				(XtCallbackProc)acol_callback, (XtPointer)i);
 	}
-	str = XmStringCreateSimple("Appointment text color:");
+	str = XmStringCreateSimple(_("Appointment text color:"));
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w);			n++;
@@ -355,8 +380,8 @@ void create_except_popup()
 	XtSetArg(args[n], XmNsubMenuId,		popup);			n++;
 	XtSetArg(args[n], XmNlabelString,	str);			n++;
 	acol_w = w = XmCreateOptionMenu(form2, "exc_acolor", args, n);
-	XtAddCallback(acol_w, XmNhelpCallback, help_callback,
-						(XtPointer)"exc_acolor");
+	XtAddCallback(acol_w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"exc_acolor");
 	XmStringFree(str);
 	XtManageChild(acol_w);
 #else
@@ -372,8 +397,8 @@ void create_except_popup()
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	line = XtCreateManagedWidget("excform4", xmFormWidgetClass,
 			form2, args, n);
-	XtAddCallback(line, XmNhelpCallback, help_callback,
-						(XtPointer)"exc_acolor");
+	XtAddCallback(line, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"exc_acolor");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -383,16 +408,17 @@ void create_except_popup()
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	acol_w = XtCreateManagedWidget(" ", xmPushButtonWidgetClass,
 			line, args, n);
-	XtAddCallback(acol_w, XmNactivateCallback, acol_callback,(XtPointer)0);
-	XtAddCallback(acol_w, XmNhelpCallback, help_callback,
-						(XtPointer)"exc_acolor");
+	XtAddCallback(acol_w, XmNactivateCallback, (XtCallbackProc)
+			acol_callback,(XtPointer)0);
+	XtAddCallback(acol_w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"exc_acolor");
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	acol_w);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("Appointment text color",
+	w = XtCreateManagedWidget(_("Appointment text color"),
 			xmLabelWidgetClass, line, args, n);
 #endif
 
@@ -406,10 +432,12 @@ void create_except_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"exc_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"exc_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -421,17 +449,19 @@ void create_except_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w,XmNactivateCallback,help_callback,(XtPointer)"except");
-	XtAddCallback(w,XmNhelpCallback,    help_callback,(XtPointer)"except");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback,(XtPointer)"except");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback,(XtPointer)"except");
 
 	XtPopup(shell, XtGrabNone);
 	fillout_except_menu();
 
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 	have_shell = TRUE;
 }
 
@@ -442,10 +472,10 @@ void create_except_popup()
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_except_popup();
 }
@@ -456,10 +486,10 @@ static void done_callback(widget, item, data)
  */
 
 /*ARGSUSED*/
-static void text_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void text_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	readback_except_menu();
 	fillout_except_menu();
@@ -467,10 +497,10 @@ static void text_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void clear_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void clear_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	print_text_button(text_w[item], "");
 	readback_except_menu();
@@ -479,10 +509,10 @@ static void clear_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void split_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void split_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char		*string, *p;	/* contents of text widget */
 	time_t		time;		/* exception time to make appt for */
@@ -525,10 +555,10 @@ static void split_callback(widget, item, data)
  */
 
 /*ARGSUSED*/
-static void hide_m_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void hide_m_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.hide_in_m ^= TRUE;
 	edit.changed = TRUE;
@@ -538,10 +568,10 @@ static void hide_m_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void hide_y_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void hide_y_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.hide_in_y ^= TRUE;
 	edit.changed = TRUE;
@@ -551,10 +581,10 @@ static void hide_y_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void hide_w_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void hide_w_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.hide_in_w ^= TRUE;
 	edit.changed = TRUE;
@@ -564,10 +594,10 @@ static void hide_w_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void hide_d_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void hide_d_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.hide_in_d ^= TRUE;
 	edit.changed = TRUE;
@@ -577,10 +607,10 @@ static void hide_d_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void hide_o_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void hide_o_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.hide_in_o ^= TRUE;
 	edit.changed = TRUE;
@@ -590,10 +620,10 @@ static void hide_o_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void notime_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void notime_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.notime ^= TRUE;
 	edit.changed = TRUE;
@@ -608,10 +638,10 @@ static void notime_callback(widget, item, data)
  */
 
 /*ARGSUSED*/
-static void acol_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void acol_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	edit.changed = TRUE;
 #ifdef XmCSimpleOptionMenu
