@@ -87,7 +87,10 @@ BOOL read_mainlist(void)
 		user = 0;
 	}
 	nusers = maxusers = 0;
-
+	if (config.java) {
+		free(config.java);
+		config.java = 0;
+	}
 	if (config.webplan) {				/*webplan: dummy user*/
 		make_default_user(resolve_tilde(DB_PUB_PATH));
 		obtain_netplan_users(config.webplan_host ? config.webplan_host
@@ -453,6 +456,17 @@ void parse_file_line(
 		*p = 0;
 		break;
 
+	  case 'j':
+		if (c->java) {
+			c->java = realloc(c->java, strlen(c->java) +
+						   strlen(line) + 1);
+			strcat(c->java, line);
+		} else {
+			c->java = malloc(strlen(line) + 1);
+			strcpy(c->java, line);
+		}
+		break;
+
 	  case '0':
 	  case '1':
 	  case '2':
