@@ -7,10 +7,8 @@
  *	create_holiday_popup()
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
@@ -24,10 +22,8 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void		done_callback(), cancel_callback();
-#ifdef MIPS
-extern char		*malloc();
-#endif
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void cancel_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -46,7 +42,7 @@ static Widget		text;		/* text widget */
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_holiday_popup()
+void destroy_holiday_popup(void)
 {
 	char		*string;	/* contents of text widget */
 	char		*errmsg;	/* holiday parser error */
@@ -78,7 +74,7 @@ void destroy_holiday_popup()
  * create a holiday popup as a separate application shell.
  */
 
-void create_holiday_popup()
+void create_holiday_popup(void)
 {
 	Widget			form, but, help;
 	Arg			args[20];
@@ -91,7 +87,7 @@ void create_holiday_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Holidays",
+	shell = XtCreatePopupShell(_("Holidays"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -100,8 +96,8 @@ void create_holiday_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("dayform", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback,
-							(XtPointer)"holiday");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"holiday");
 
 							/*-- buttons --*/
 	n = 0;
@@ -110,11 +106,12 @@ void create_holiday_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	but = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	but = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(but, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(but, XmNhelpCallback,     help_callback,
-						(XtPointer)"holiday_done");
+	XtAddCallback(but, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(but, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"holiday_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -123,12 +120,12 @@ void create_holiday_popup()
 	XtSetArg(args[n], XmNrightWidget,	but);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	help = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	help = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(help, XmNactivateCallback,
-					help_callback, (XtPointer)"holiday");
-	XtAddCallback(help, XmNhelpCallback,
-					help_callback, (XtPointer)"holiday");
+	XtAddCallback(help, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"holiday");
+	XtAddCallback(help, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"holiday");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -137,11 +134,12 @@ void create_holiday_popup()
 	XtSetArg(args[n], XmNrightWidget,	help);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	but = XtCreateManagedWidget("Cancel", xmPushButtonWidgetClass,
+	but = XtCreateManagedWidget(_("Cancel"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(but, XmNactivateCallback, cancel_callback,(XtPointer)0);
-	XtAddCallback(but, XmNhelpCallback,     help_callback,
-						  (XtPointer)"holiday_cancel");
+	XtAddCallback(but, XmNactivateCallback, (XtCallbackProc)
+			cancel_callback,(XtPointer)0);
+	XtAddCallback(but, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"holiday_cancel");
 
 							/*-- text --*/
 	n = 0;
@@ -179,13 +177,13 @@ void create_holiday_popup()
 	}
 	XmTextSetInsertionPosition(text, 0);
 	XtManageChild(text);
-	XtAddCallback(text, XmNhelpCallback, help_callback,
-							(XtPointer)"holiday");
+	XtAddCallback(text, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"holiday");
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 
 	have_shell = TRUE;
 }
@@ -193,19 +191,19 @@ void create_holiday_popup()
 
 /*-------------------------------------------------- callbacks --------------*/
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_holiday_popup();
 }
 
 /*ARGSUSED*/
-static void cancel_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void cancel_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	XtPopdown(shell);
 	XTDESTROYWIDGET(shell);
