@@ -311,6 +311,7 @@ static void non_interactive(
 	char		msg[1024];		/* note from command line */
 	int		n, i, j;		/* char and arg counters */
 	char		lockfile[80];		/* plan lockfile, for sighup */
+	char		*flags;			/* where to hide reminder */
 	FILE		*fp;			/* for reading lockfile */
 	PID_T		pid = 0;		/* interactive plan PID */
 
@@ -374,6 +375,37 @@ static void non_interactive(
 		  case 'u':
 			edit.entry.user = mystrdup(argv[i+1]);
 			break;
+		  case 'c':
+			edit.entry.acolor = atoi(argv[i+1]) * 60;
+			break;
+		  case 'N':
+			++edit.entry.noalarm;
+			--i;			/* No argument used for -N */
+			break;
+		  case 'h':
+			flags = argv[i+1];
+			while (*flags) {
+				switch(*flags++) {
+				  case 'm':	/* don't show in month view */
+					++edit.entry.hide_in_m;
+					break;
+				  case 'y':	/* don't show in year view */
+					++edit.entry.hide_in_y;
+					break;
+				  case 'w':	/* don't show in week view */
+					++edit.entry.hide_in_w;
+					break;
+				  case 'o':	/* don't show in year overview */
+					++edit.entry.hide_in_o;
+					break;
+				  case 'd':	/* don't show in day view */
+					++edit.entry.hide_in_d;
+					break;
+				  default:
+					usage();
+				}
+			}
+			break;
 		  default:
 			usage();
 		}
@@ -452,7 +484,7 @@ static int dumptoday(
 			continue;
 		if (ulist) {
 			char *ul = mystrdup(ulist), *u;
-			for (u=strtok(ul, ","); u && !strcmp(u, ep->user);
+			for (u=strtok(ul, ","); u && strcmp(u, ep->user);
 							     u=strtok(0, ","));
 			free(ul);
 			if (!u)
@@ -577,19 +609,22 @@ static void usage(void)
 	    "\t-b\t\tdo fork on startup\n",
 	    "\t-k\t\tignore lock file and start up in any case\n");
 	fprintf(stderr,
-	    "append usage: %s %s%s%s%s%s%s%s%s%s%s%s%s\n", progname,
+	    "append usage: %s %s%s%s%s%s%s%s%s%s%s%s%s%s%s%s\n", progname,
 	    "[mmdd]hhmm [options] [message]*\n",
 	    "\tAdd appointment at mm/dd hh:mm (default is today).\n",
 	    "\tOptions:\n",
 	    "\t-u U\t\tapply to user U instead of own appointments\n",
 	    "\t-l T\t\tappointment length is T (eg., 1:00 is one hour)\n",
 	    "\t-n\t\tappointment has no time-of-day\n",
+	    "\t-N\t\tno alarms (reminder only)\n",
 	    "\t-r N\t\trepeat every N days\n",
 	    "\t-d N\t\trepeat every day N (1..31) of the month\n",
 	    "\t-D N\t\trepeat every weekday N: 0=mon, 1=tue, ... 6=sun\n",
 	    "\t-e D\t\tend date, stop repeating on date D\n",
 	    "\t-w N\t\tearly warning is N minutes before hhmm time\n",
-	    "\t-W N\t\tlate warning is N minutes before hhmm time\n");
+	    "\t-W N\t\tlate warning is N minutes before hhmm time\n",
+	    "\t-c N\t\tcolor code for appointment\n",
+	    "\t-h [m|y|w|o|d]*\thide in month, year, week, overview or day views\n");
 	fprintf(stderr,
 	    "batch usage: %s options\n\tOptions:\n%s%s%s%s%s%s%s%s%s%s%s%s",
 	    progname,
