@@ -12,6 +12,7 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <assert.h>
 #include <time.h>
 #include <Xm/Xm.h>
@@ -20,11 +21,16 @@
 static BOOL set_day_bkg_color();
 static void draw_day_notes();
 static int day_to_pos(), pos_to_day();
-void draw_day();
 
+static void draw_day_notes	(int);
+static BOOL set_day_bkg_color	(int);
+static int day_to_pos		(int *, int *, int);
+static int pos_to_day		(int *, int, int);
 #ifdef JAPAN
-static int		mixedstrtok(), chkctype();
-static void		mixedstr_draw();
+static int chkctype		(char, int);
+static int mixedstrtok		(char *, char *);
+static void mixedstr_draw	(Window, int, int,char*, int, int, int);
+
 extern char		*localename;	/* locale name */
 extern unsigned short	(*kanji2jis)();	/* kanji2jis == e2j or sj2j */
 #endif
@@ -72,14 +78,17 @@ extern char *monthname[];
  *   M_WEEK_CAL	-	time	-	-	pop up a week calendar view
  */
 
-MOUSE locate_in_month_calendar(epp, warn, time, trigger, xp,yp,xsp,ysp, xc,yc)
-	struct entry	**epp;		/* returned entry or 0 */
-	BOOL		*warn;		/* is *epp an n-days-ahead w?*/
-	time_t		*time;		/* if *epp=0, clicked where */
-	time_t		*trigger;	/* if *epp=0, entry trigger */
-	int		*xp,  *yp;	/* if M_INSIDE, rubber box */
-	int		*xsp, *ysp;	/* position and size */
-	int		xc, yc;		/* pixel pos clicked */
+MOUSE locate_in_month_calendar(
+	struct entry	**epp,		/* returned entry or 0 */
+	BOOL		*warn,		/* is *epp an n-days-ahead w?*/
+	time_t		*time,		/* if *epp=0, clicked where */
+	time_t		*trigger,	/* if *epp=0, entry trigger */
+	int		*xp,		/* if M_INSIDE, rubber box position */
+	int		*yp,
+	int		*xsp,		/* and size */
+	int		*ysp,
+	int		xc,		/* pixel pos clicked */
+	int		yc)
 {
 	register struct config	*c = &config;
 	int		xd, yd;		/* top left of clicked day box */
@@ -154,9 +163,9 @@ MOUSE locate_in_month_calendar(epp, warn, time, trigger, xp,yp,xsp,ysp, xc,yc)
  * draw the weekday names, depending on the Sunday-first flag
  */
 
-void draw_month_year()
+void draw_month_year(void)
 {
-	print_button(mainmenu.month, monthname[curr_month]);
+	print_button(mainmenu.month, _(monthname[curr_month]));
 	print_button(mainmenu.year, "%d", curr_year+1900);
 }
 
@@ -165,8 +174,8 @@ void draw_month_year()
  * draw all day boxes into a clip region, or all if the region is null
  */
 
-void draw_calendar(region)
-	Region			region;
+void draw_calendar(
+	Region			region)
 {
 	register struct config	*c = &config;
 	Window			window;
@@ -244,13 +253,14 @@ void draw_calendar(region)
 							/* weekday names */
 	j = c->sunday_first ? 6 : 0;
 	XSetFont(display, gc, font[sm ? FONT_NOTE : FONT_STD]->fid);
-	for (i=0; i < 7; i++, j++)
+	for (i=0; i < 7; i++, j++) {
+		char *wdn = _(weekday_name[j%7]);
 		XDrawString(display, window, gc,
 			c->calbox_marg[sm] + c->calbox_arrow[sm]
 					   + c->calbox_xs[sm] * i,
 			c->calbox_marg[sm] + c->calbox_title[sm] * 3/4,
-			weekday_name[j%7], strlen(weekday_name[j%7]));
-
+			wdn, strlen(wdn));
+	}
 	day_to_pos(&x, &y, 1);				/* day boxes */
 	for (i=1-x; i < 43-x; i++)
 		draw_day(i);
@@ -267,27 +277,27 @@ void draw_calendar(region)
  * draw one day box.
  */
 
-void draw_day(day)
-	int			day;		/* 1..31 : current month */
-						/* < 1 : previous month */
-						/* > monthlen : next month */
+void draw_day(
+	int		day)		/* 1..31 : current month */
+					/* < 1 : previous month */
+					/* > monthlen : next month */
 {
-	Window			window;
-	char			buf[200];	/* julian, weeknum, holiday */
-	int			x, y;		/* position in calendar */
-	int			jul;		/* julian date of daybox */
-	int			daynum_xs;	/* width of day# in pixels */
-	int			tmp_curr_month;	/* tmp storage for curr_month*/
-	int			tmp_curr_year;	/* tmp storage for curr_year */
-	int			orig_day;	/* original value of day */
-	int			last_day;	/* last day of current month */
-	BOOL			leftedge;	/* in leftmost daybox? */
-	BOOL			weekend;	/* saturday or sunday? */
-	BOOL			today;		/* is this today's box? */
-	BOOL			othermonth;	/* not current month ? */
-	struct holiday		*hp, *shp;	/* to check for holidays */
-	char			*errmsg;	/* holiday parser error */
-	int			sm = config.smallmonth;
+	Window		window;
+	char		buf[200];	/* julian, weeknum, holiday */
+	int		x, y;		/* position in calendar */
+	int		jul;		/* julian date of daybox */
+	int		daynum_xs;	/* width of day# in pixels */
+	int		tmp_curr_month;	/* tmp storage for curr_month*/
+	int		tmp_curr_year;	/* tmp storage for curr_year */
+	int		orig_day;	/* original value of day */
+	int		last_day;	/* last day of current month */
+	BOOL		leftedge;	/* in leftmost daybox? */
+	BOOL		weekend;	/* saturday or sunday? */
+	BOOL		today;		/* is this today's box? */
+	BOOL		othermonth;	/* not current month ? */
+	struct holiday	*hp, *shp;	/* to check for holidays */
+	char		*errmsg;	/* holiday parser error */
+	int		sm = config.smallmonth;
 
 	if (!mainmenu.cal)
 		return;
@@ -426,8 +436,8 @@ void draw_day(day)
  * it's easy to find the entry under the cursor.
  */
 
-static void draw_day_notes(day)
-	int			day;		/* 1..31 */
+static void draw_day_notes(
+	int			day)		/* 1..31 */
 {
 	BOOL			today;		/* TRUE: it's today's daybox */
 	struct tm		*tm;		/* for daylight-saving tzone */
@@ -594,8 +604,8 @@ static void draw_day_notes(day)
 					font[FONT_NOTE]->max_bounds.ascent+1);
 		}
 		if (ep->notime)
-			sprintf(buf, "%s%.90s", mknotestring(ep),
-						lookup.days_warn ? "W: " : "");
+			sprintf(buf, "%s%.90s", lookup.days_warn ? "W: " : "",
+						mknotestring(ep));
 		else
 			sprintf(buf, "%s %s%.90s", mktimestring(lookup.trigger,
 								FALSE),
@@ -634,8 +644,8 @@ static void draw_day_notes(day)
 }
 
 
-static BOOL set_day_bkg_color(day)
-	int			day;		/* 1..31 */
+static BOOL set_day_bkg_color(
+	int			day)		/* 1..31 */
 {
 	struct tm		*tm;
 	BOOL			ret;
@@ -653,9 +663,10 @@ static BOOL set_day_bkg_color(day)
  * convert day numbers 1..31 to a pixel position, and vice versa.
  */
 
-static int day_to_pos(x, y, day)
-	int			*x, *y;		/* returned box, 0..6/0..5 */
-	int			day;		/* 1..31 */
+static int day_to_pos(
+	int			*x,		/* returned box, 0..6/0..5 */
+	int			*y,
+	int			day)		/* 1..31 */
 {
 	int			wkday;
 
@@ -667,9 +678,10 @@ static int day_to_pos(x, y, day)
 }
 
 
-static int pos_to_day(day, x, y)
-	int			*day;		/* returned day #, 1..31 */
-	int			x, y;		/* pixel pos in drawable */
+static int pos_to_day(
+	int			*day,		/* returned day #, 1..31 */
+	int			x,		/* pixel pos in drawable */
+	int			y)
 {
 	int			xtest, ytest;
 	int			sm = config.smallmonth;
@@ -705,9 +717,10 @@ static int pos_to_day(day, x, y)
  * NISHIJIMA, Takanori (racsho@cpdc.canon.co.jp).
  * Ogura Yoshito changed a few lines of chkctype();
  */
-static int chkctype(ch, stat)
-char ch;
-int  stat;
+
+static int chkctype(
+	char	ch,
+	int 	stat)
 {
 	switch (stat) {
 	  case CT_ASC:
@@ -728,8 +741,8 @@ int  stat;
 	}
 }
 
-unsigned short e2j(wc)
-	unsigned short wc;
+unsigned short e2j(
+	unsigned short wc)
 {
 	return (wc & 0x7F7F);
 }
@@ -742,8 +755,8 @@ unsigned short e2j(wc)
  * AUTHOR: Itaru ICHIKAWA (ichikawa@flab.fujitsu.co.jp)
  */
 
-unsigned short sj2j(wc)
-	unsigned short wc;
+unsigned short sj2j(
+	unsigned short wc)
 {
 	return (((((wc >> 8) << 1) - (((wc >> 8) > 0x9f) << 7) - 0xe1) << 8) +
 		((wc & 0x00ff) >= 0x9f ? (wc & 0x00ff) - 0x7e | 0x100
@@ -752,13 +765,13 @@ unsigned short sj2j(wc)
 }
 
 
-static int mixedstrtok(jisstr, sjstr)
-	char			*jisstr, *sjstr;
-
+static int mixedstrtok(
+	char			*jisstr,
+	char			*sjstr)
 {
 	unsigned char		*dptr = (unsigned char *)jisstr,
 				*sptr = (unsigned char *)sjstr; 
-	unsigned short		wc;		/* works for a 2-byte character */
+	unsigned short		wc;	/* works for a 2-byte character */
 	int			prev_ct = CT_ASC, stat;
 
 	if (sptr == NULL) {
@@ -799,11 +812,11 @@ STATCHG:
 }
 
 
-int mixedstrlen_in_pixels(sjstr, stp, ascfont, jfont)
-	char			*sjstr;
-	strpack			*stp;
-	int			ascfont, jfont;
-
+int mixedstrlen_in_pixels(
+	char			*sjstr,
+	strpack			*stp,
+	int			ascfont,
+        int                     jfont)
 {
 	int			jlen, plen = 0, i = 0, j = 0, k;
 	char			*sjptr = sjstr;
@@ -813,7 +826,7 @@ int mixedstrlen_in_pixels(sjstr, stp, ascfont, jfont)
 	do {
 		if (k <= 0) {
 			if (k)
-				fprintf(stderr, "String conversion error.\n");
+				fprintf(stderr,_("String conversion error.\n"));
 			stp[i].strptr = NULL;
 			break;
 		}
@@ -860,32 +873,36 @@ int mixedstrlen_in_pixels(sjstr, stp, ascfont, jfont)
 }
 
 
-static void mixedstr_draw(window, x, y, mxstr, maxpix, ascfont, jfont)
-	Window			window;
-	char			*mxstr;			/* string to draw */
-	int			x, y,			/* coordinate */
-				ascfont, jfont,		/* fonts of string */
-				maxpix;			/* Max width in pixels. */
+static void mixedstr_draw(
+			  Window window,
+			  int x,/* coordinate */
+			  int y,
+			  char *mxstr,/* string to draw */
+			  int maxpix,        /* Max width in pixels. */
+			  int ascfont,/* fonts of string */
+			  int jfont )
 {
-	int			i, len, deltax = 0;
-	char			buf[100];
+	int		i, len, deltax = 0;
+	char		buf[100];
 
 	i = mixedstrtok(buf, mxstr);
 	do {
 		if (i <= 0) {
 			if (i)
-				fprintf(stderr, "String conversion error.\n");
+				fprintf(stderr,_("String conversion error.\n"));
 			break;
 		}
 		mxstr += (len = strlen(buf));
 		if (i == 1) {
 			i = XTextWidth(font[ascfont], buf, len);
 			if (maxpix < i) {
-/*
-	It makes me happy 'truncate_string' to return length of truncated string.
-				XDrawString(display, window, gc, x+deltax, y, buf,
-					    truncate_string(buf, maxpix, ascfont);
-*/
+				/*
+				 * It makes me happy 'truncate_string'
+				 * to return length of truncated string.
+				XDrawString(display, window, gc,
+					x+deltax, y, buf,
+					truncate_string(buf, maxpix, ascfont);
+				 */
 				(void)truncate_string(buf, maxpix, ascfont);
 				XDrawString(display, window, gc, x+deltax, y,
 					    buf, strlen(buf));
