@@ -6,13 +6,11 @@
  * the proper string pointers (which point to members of the edit struct).
  *
  *	destroy_text_popup()
- *	create_text_popup(title, initial, x)
+ *	create_text_popup(title, initial, x, readonly)
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
@@ -26,7 +24,9 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void		done_callback(), delete_callback(), clear_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void delete_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void clear_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -34,6 +34,7 @@ extern struct edit	edit;		/* info about entry being edited */
 extern struct plist	*mainlist;	/* list of all schedule entries */
 
 static BOOL		have_shell;	/* message popup exists if TRUE */
+static BOOL		readonly_msg;	/* just a displayer, not editable */
 static char		**source;	/* ptr to string ptr in edit.entry */
 static char		button_x;	/* which button was pressed, SC_* */
 static Widget		shell;		/* popup menu shell */
@@ -45,11 +46,11 @@ static Widget		text;		/* text widget */
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_text_popup()
+void destroy_text_popup(void)
 {
-	char			*string;	/* contents of text widget */
+	char		*string;	/* contents of text widget */
 
-	if (have_shell && edit.editing) {
+	if (have_shell && !readonly_msg && edit.editing) {
 		if (*source)
 			free(*source);
 		string = XmTextGetString(text);
@@ -72,18 +73,21 @@ void destroy_text_popup()
 
 
 /*
- * create a message or script popup as a separate application shell.
+ * create a message or script popup as a separate application shell. The
+ * readonly flag allows displaying messages even though the appointment is
+ * read-only; otherwise it would be impossible to display.
  */
 
-void create_text_popup(title, initial, x)
-	char			*title;		/* menu title string */
-	char			**initial;	/* initial default text */
-	int			x;		/* button pressed, SC_* */
+void create_text_popup(
+	char		*title,		/* menu title string */
+	char		**initial,	/* initial default text */
+	int		x,		/* button pressed, SC_* */
+	BOOL		readonly)	/* just show, no editing */
 {
-	Widget			form, but, help;
-	Arg			args[20];
-	int			n;
-	Atom			closewindow;
+	Widget		form, but, help;
+	Arg		args[20];
+	int		n;
+	Atom		closewindow;
 
 	destroy_text_popup();
 
@@ -100,48 +104,53 @@ void create_text_popup(title, initial, x)
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("msgform", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"msg");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"msg");
 
 							/*-- buttons --*/
-	n = 0;
-	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
-	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
-	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
-	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		80);			n++;
-	XtSetArg(args[n], XmNtraversalOn,	False);			n++;
-	but = XtCreateManagedWidget("Delete", xmPushButtonWidgetClass,
+	if (!readonly) {
+	  n = 0;
+	  XtSetArg(args[n], XmNbottomAttachment,XmATTACH_FORM);		n++;
+	  XtSetArg(args[n], XmNbottomOffset,	8);			n++;
+	  XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	  XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	  XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	  XtSetArg(args[n], XmNwidth,		80);			n++;
+	  XtSetArg(args[n], XmNtraversalOn,	False);			n++;
+	  but = XtCreateManagedWidget(_("Delete"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(but, XmNactivateCallback, delete_callback, (XtPointer)0);
-	XtAddCallback(but, XmNhelpCallback,     help_callback,
-						(XtPointer)"msg_delete");
+	  XtAddCallback(but, XmNactivateCallback, (XtCallbackProc)
+			delete_callback, (XtPointer)0);
+	  XtAddCallback(but, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"msg_delete");
 
-	n = 0;
-	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
-	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
-	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
-	XtSetArg(args[n], XmNleftWidget,	but);			n++;
-	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		80);			n++;
-	XtSetArg(args[n], XmNtraversalOn,	False);			n++;
-	but = XtCreateManagedWidget("Clear", xmPushButtonWidgetClass,
+	  n = 0;
+	  XtSetArg(args[n], XmNbottomAttachment,XmATTACH_FORM);		n++;
+	  XtSetArg(args[n], XmNbottomOffset,	8);			n++;
+	  XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
+	  XtSetArg(args[n], XmNleftWidget,	but);			n++;
+	  XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	  XtSetArg(args[n], XmNwidth,		80);			n++;
+	  XtSetArg(args[n], XmNtraversalOn,	False);			n++;
+	  but = XtCreateManagedWidget(_("Clear"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(but, XmNactivateCallback, clear_callback, (XtPointer)0);
-	XtAddCallback(but, XmNhelpCallback,     help_callback,
-						(XtPointer)"msg_clear");
-
+	  XtAddCallback(but, XmNactivateCallback, (XtCallbackProc)
+			clear_callback, (XtPointer)0);
+	  XtAddCallback(but, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"msg_clear");
+	}
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	but = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	but = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(but, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(but, XmNhelpCallback,     help_callback,
-							(XtPointer)"msg_done");
+	XtAddCallback(but, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(but, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"msg_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -150,12 +159,12 @@ void create_text_popup(title, initial, x)
 	XtSetArg(args[n], XmNrightWidget,	but);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	help = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	help = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(help, XmNactivateCallback,
-					help_callback, (XtPointer)"msg");
-	XtAddCallback(help, XmNhelpCallback,
-					help_callback, (XtPointer)"msg");
+	XtAddCallback(help, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"msg");
+	XtAddCallback(help, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"msg");
 
 							/*-- text --*/
 	n = 0;
@@ -174,22 +183,24 @@ void create_text_popup(title, initial, x)
 	XtSetArg(args[n], XmNrows,		10);			n++;
 	XtSetArg(args[n], XmNscrollVertical,	True);			n++;
 	XtSetArg(args[n], XmNpendingDelete,	True);			n++;
+	XtSetArg(args[n], XmNeditable,		!readonly);		n++;
 	text = XmCreateScrolledText(form, "text", args, n);
 	if (*initial) {
 		XmTextSetString(text, *initial);
 		XmTextSetInsertionPosition(text, strlen(*initial));
 	}
 	XtManageChild(text);
-	XtAddCallback(text, XmNhelpCallback, help_callback,
-							(XtPointer)"msg_text");
+	XtAddCallback(text, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"msg_text");
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
-	have_shell = TRUE;
-	source     = initial;
-	button_x   = x;
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
+	have_shell   = TRUE;
+	source       = initial;
+	button_x     = x;
+	readonly_msg = readonly;
 }
 
 
@@ -199,20 +210,20 @@ void create_text_popup(title, initial, x)
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_text_popup();
 }
 
 
 /*ARGSUSED*/
-static void delete_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void delete_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	XmTextSetString(text, "");
 	destroy_text_popup();
@@ -220,10 +231,10 @@ static void delete_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void clear_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void clear_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	XmTextSetString(text, "");
 	XmTextSetInsertionPosition(text, 0);
