@@ -321,8 +321,11 @@ int main(
 				register struct buffer *b;
 				b = &client_list[fd].out;
 				n = write(fd, b->data+b->deq, b->enq-b->deq);
+				if (n < 0)
+					log("client %d write fail (%s)\n",
+							fd, strerror(errno));
 				b->deq += n;
-				if (b->deq == b->enq) {
+				if (b->deq == b->enq || n < 0) {
 					b->enq = b->deq = 0;
 					FD_CLR(fd, &wr0);
 				}
@@ -909,17 +912,18 @@ static int open_file(
 	sprintf(path, HOMEDIR "/" NETDIR "/%s", fname);
 	if (fp = fopen(path, "r")) {			/* open and check */
 		if (!check_file(fp, path, fd, c)) {
+			release(path);
 			fclose(fp);
 			return(-1);
 		}
 		if (access(path, W_OK))
 			ro = readonly = TRUE;
 	}
+	release(path);
 	if (ro && ! fp) {
 		error(fd, "File %.20s does not exist on server.", fname);
 		return -1;
 	}
-	release(path);
 	if (ffree != -1)				/* new file slot */
 		fid = ffree;
 	else {
