@@ -103,10 +103,9 @@ int acl_read(
 {
 	FILE		*fp;		/* open file */
 	Acl		*tail = 0;	/* previous access list entry */
-	Acl		*acl = 0;	/* current new access list entry */
-	Mode            mode = aUSER;   /* aHOST, aUSER, aGROUP */
+	Acl		*acl  = 0;	/* current new access list entry */
 	int		phase = 0;	/* 0=name, 1=mode, 2=data */
-	int		ret = TRUE;	/* return code */
+	int		ret   = TRUE;	/* return code */
 	struct hostent	*h;		/* for adding hosts to ACL */
 	struct passwd	*u;		/* for adding users to ACL */
 	struct group	*g;		/* for adding groups to ACL */
@@ -115,6 +114,7 @@ int acl_read(
 	acl_exit();
 	if (!(fp = fopen(fname, "r"))) {
 		perror(fname);
+		fprintf(stderr, "this is ok; access control disabled.\n");
 		return(FALSE);
 	}
 	while (ret && getword(fp)) {
@@ -333,7 +333,7 @@ int acl_write(
 			if (acl->mode == aHOST)
 				fprintf(fp, " %s", ip_itoa(acl->data[i]));
 			else
-				fprintf(fp, " %d", acl->data[i]);
+				fprintf(fp, " %d", (int)acl->data[i]);
 		fprintf(fp, "\n");
 	}
 	if (fname != fstderr)
@@ -408,7 +408,8 @@ void acl_verify(
 		  case aGROUP:
 			if (c->auth_fail)
 				continue;
-			for (found=FALSE, i=0; !found && i < acl->ndata; i++)
+			for (found=FALSE, i=0; !found && i < acl->ndata;
+								!found && i++)
 				for (j=0; j<NGROUPS_MAX && c->gids[j]>=0; j++)
 					if (found = acl->data[i] == c->gids[j])
 						break;
@@ -466,10 +467,9 @@ char *ident_id(
 	int		fd)		/* client ID and socket descriptor */
 {
 	register struct client *c = &client_list[fd];
-	char		hostname[256];
+	char		*hostname;
 	int		port;
 
-	struct hostent	*hent;		/* for hostname -> IP addr lookup */
 	struct sockaddr_in addr;	/* IP address */
 	int		idfd;		/* temporary socket descriptor */
 	int		i, on;		/* for setting socket options */
@@ -477,18 +477,11 @@ char *ident_id(
 
 	struct servent *serv = getservbyname("auth", "tcp");
 	port = serv ? serv->s_port : htons(113);
-	if (gethostname(hostname, sizeof(hostname)) == -1)
-		strcpy(hostname, ip_addr(&c->addr));
-	hostname[sizeof(hostname)-1] = 0;
+	hostname = ip_addr(&c->addr);
 
 	if (verbose)
 		log("client %d: authenticating, connecting to identd on "
 						"%.100s\n", fd, hostname);
-	if (!(hent = gethostbyname(hostname))) {
-		log("client %d: %.100s: unknown host, cannot authenticate\n",
-						fd, hostname);
-		return(0);
-	}
 	if ((idfd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
 		log("client %d: cannot open socket to authentication server on"
 						"%.100s\n", fd, hostname);
@@ -496,7 +489,7 @@ char *ident_id(
 	}
 	addr.sin_family = AF_INET;
 	addr.sin_port   = port;
-	memcpy(&addr.sin_addr, hent->h_addr, sizeof(hent->h_length));
+	memcpy(&addr.sin_addr, &c->addr.sin_addr, sizeof(addr.sin_addr));
 	if (connect(idfd, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
 		close(idfd);
 		log("client %d: cannot connect to authentication server on "
