@@ -10,7 +10,8 @@
  *	read_from_server(uid, rid)
  *	puts_server(fd, msg)
  *	gets_server(fd, msg, num, cont)
- *	got_network_event(fd);
+ *	got_network_event(fd)
+ *	get_netplan_filelist(fd)
  */
 
 #include <stdio.h>
@@ -19,7 +20,7 @@
 #include <time.h>
 #include <assert.h>
 #include <errno.h>
-#ifdef IBM
+#if defined(IBM) || defined (__EMX__)
 #include <sys/select.h>
 #endif
 #include <sys/types.h>
@@ -44,6 +45,7 @@ extern char		*progname;	/* argv[0] */
 extern struct config	config;		/* global configuration data */
 extern struct user	*user;		/* user list (from file_r.c) */
 extern int		nusers;		/* number of users in user list */
+extern int		maxusers;	/* max # of users in user list */
 extern struct plist	*mainlist;	/* list of all schedule entries */
 extern Widget		mainwindow;	/* popup menus hang off main window */
 static struct host	*host_list;	/* list of connected hosts */
@@ -56,7 +58,7 @@ static struct host	*host_list;	/* list of connected hosts */
  * known read_mainlist() can reconnect using attach_to_network().
  */
 
-void detach_from_network()
+void detach_from_network(void)
 {
 	int		u;
 	struct host	*hp, *next;
@@ -81,9 +83,9 @@ void detach_from_network()
  * up an error popup and shut down the link to avoid an infinite loop.
  */
 
-static void lost_connection_error(fd, error)
-	int		fd;		/* socket that died */
-	int		error;		/* errno from read or write */
+static void lost_connection_error(
+	int		fd,		/* socket that died */
+	int		error)		/* errno from read or write */
 {
 	struct host	*hp, *prev = 0;
 	char		*host = 0;
@@ -106,10 +108,10 @@ static void lost_connection_error(fd, error)
 		}
 	if (mainwindow)
 		create_error_popup(mainwindow, error,
-"Lost connection to netplan server %s.\n\n\
+_("Lost connection to netplan server %s.\n\n\
 Please start it up again, then choose\n\
 `File->Reread files' to reconnect and re-read.\n\
-You may have lost recent changes.", host ? host : "<unknown>");
+You may have lost recent changes."), host ? host : _("<unknown>"));
 	if (host)
 		free(host);
 }
@@ -122,26 +124,19 @@ You may have lost recent changes.", host ? host : "<unknown>");
  * existing locks.
  */
 
-char *attach_to_network()
+char *attach_to_network(void)
 {
 	int		u;		/* user counter */
 	struct host	*hp;		/* for checking already-known hosts */
 	char		*uhost, *p;	/* requested host name without '/'s */
-	struct hostent	*hent;		/* for hostname -> IP addr lookup */
-	struct sockaddr_in addr;	/* IP address */
 	int		fd;		/* temporary socket descriptor */
-	int		on;		/* for setting socket options */
 	char		msg[10240];	/* problem report */
 	char		buf[1024];	/* banner reply from server */
 
-	if (!config.net_port) {
-		struct servent *serv = getservbyname("netplan", "tcp");
-		config.net_port = serv ? serv->s_port : htons(PORT);
-	}
 	*msg = 0;
 	for (u=0; u < nusers; u++) {
 		if (strlen(msg) > sizeof(msg)-1024) {
-			strcat(msg, "Too many errors, aborting.\n");
+			strcat(msg, _("Too many errors, aborting.\n"));
 			break;
 		}
 		if (!user[u].fromserver || !user[u].name || !user[u].server)
@@ -157,74 +152,100 @@ char *attach_to_network()
 			user[u].host = hp;
 			continue;
 		}
-		if (!(hent = gethostbyname(uhost))) {	/* open connection */
-			sprintf(msg+strlen(msg),
-				"User file %s on host %s: unknown host\n",
-				user[u].name, uhost);
-			continue;
+		fd = connect_netplan_server(uhost, user[u].name, msg);
+		if (fd >= 0) {
+			if (!(hp = (struct host *)malloc(sizeof(*hp))))
+				fatal(_("no memory"));
+			hp->name  = mystrdup(uhost);
+			hp->fd    = fd;
+			hp->open  = TRUE;
+			hp->next  = host_list;
+			hp->x_id  = register_X_input(fd);
+			host_list = hp;
+			user[u].host = hp;
 		}
-	        if ((fd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
-			sprintf(msg+strlen(msg),
-				"User file %s on host %s: cannot open socket\n",
-				user[u].name, uhost);
-			continue;
-		}
-		addr.sin_family = AF_INET;
-		addr.sin_port   = config.net_port;
-		memcpy(&addr.sin_addr, hent->h_addr, sizeof(hent->h_length));
-		if (connect(fd, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
-			sprintf(msg+strlen(msg),
-				"User file %s on host %s: cannot connect\n",
-				user[u].name, uhost);
-			continue;
-		}
-		on = TRUE;
-		setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, &on, sizeof(on));
-		on = TRUE;
-		setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &on, sizeof(on));
-
-		if (gets_server(fd, buf, sizeof(buf), TRUE, FALSE) < 0)
-			sprintf(msg+strlen(msg),
-				"Server on host %s does not reply\n", uhost);
-		else if (*buf != '!')
-			sprintf(msg+strlen(msg),
-				"Server on host %s: protocol error\n", uhost);
-#if 0
-		else
-			fprintf(stderr, "plan: connected to host %s: %s",
-				uhost, buf+1);
-#endif
-		p = strrchr(progname, '/');
-		sprintf(buf, "=%s<uid=%d,gid=%d,pid=%d>\n",
-				p && p[1] ? p+1 : progname,
-				getuid(), getgid(), getpid());
-		puts_server(fd, buf);
-		puts_server(fd, 0);
-
-		if (!(hp = (struct host *)malloc(sizeof(*hp))))
-			fatal("no memory");
-
-		hp->name  = mystrdup(uhost);
-		hp->fd    = fd;
-		hp->open  = TRUE;
-		hp->next  = host_list;
-		hp->x_id  = register_X_input(fd);
-		host_list = hp;
-		user[u].host = hp;
-
 	}
 	return(*msg ? mystrdup(msg) : 0);
 }
 
 
+/*
+ * open a connection to a netplan server by host name. This is used by the
+ * above function, and to obtain the list of files available on a server.
+ * Return the socket fd, or -1 on failure.
+ */
+
+int connect_netplan_server(
+	char		*uhost,		/* requested server host name */
+	char		*uname,		/* user file name req'd from server */
+	char		*msg)		/* for appending error message */
+{
+	struct hostent	*hent;		/* for hostname -> IP addr lookup */
+	struct sockaddr_in addr;	/* IP address */
+	int		on;		/* for setting socket options */
+	int		fd;		/* socket descriptor */
+	char		*p;		/* for identifying plan to server */
+	char		buf[1024];	/* banner reply from server */
+
+	if (!config.net_port) {
+		struct servent *serv = getservbyname("netplan", "tcp");
+		config.net_port = serv ? serv->s_port : htons(PORT);
+	}
+	if (!(hent = gethostbyname(uhost))) {	/* open connection */
+		sprintf(msg+strlen(msg),
+			_("User file %s on host %s: unknown host\n"),
+			uname, uhost);
+		return(-1);
+	}
+	if ((fd = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
+		sprintf(msg+strlen(msg),
+			_("User file %s on host %s: cannot open socket\n"),
+			uname, uhost);
+		return(-1);
+	}
+	addr.sin_family = AF_INET;
+	addr.sin_port   = config.net_port;
+	memcpy(&addr.sin_addr, hent->h_addr, sizeof(hent->h_length));
+	if (connect(fd, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
+		sprintf(msg+strlen(msg),
+			_("User file %s on host %s: cannot connect\n"),
+			uname, uhost);
+		return(-1);
+	}
+	on = TRUE;
+	setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, &on, sizeof(on));
+	on = TRUE;
+	setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &on, sizeof(on));
+
+	if (gets_server(fd, buf, sizeof(buf), TRUE, FALSE) < 0)
+		sprintf(msg+strlen(msg),
+			_("Server on host %s does not reply\n"), uhost);
+	else if (*buf != '!')
+		sprintf(msg+strlen(msg),
+			_("Server on host %s: protocol error\n"), uhost);
+#if 0
+	else
+		fprintf(stderr, _("plan: connected to host %s: %s"),
+			uhost, buf+1);
+#endif
+	p = strrchr(progname, '/');
+	sprintf(buf, "=%s<uid=%d,gid=%d,pid=%d>\n",
+			p && p[1] ? p+1 : progname,
+			getuid(), getgid(), getpid());
+	puts_server(fd, buf);
+	puts_server(fd, 0);
+	return(fd);
+}
+
+
 /*
  * have a user name, need the file ID that connects us with this user.
  * Return -1 if there is no such connection. This is used when the user
  * moves an appointment into a different group in the edit menu.
  */
 
-int name_to_file(name)
-	char		*name;		/* name to locate */
+int name_to_file(
+	char		*name)		/* name to locate */
 {
 	struct host	*hp;		/* hos scan pointer */
 
@@ -240,30 +261,30 @@ int name_to_file(name)
  * reply. If not, pop up a meaningful error message and return FALSE.
  */
 
-static BOOL check_server_reply(ret, msg, cmd, host, fname)
-	int		ret;		/* <0: gets_server failed */
-	char		*msg;		/* message returned by server */
-	char		cmd;		/* expected command code, 0=any */
-	char		*host;		/* server host name */
-	char		*fname;		/* file name or 0 */
+static BOOL check_server_reply(
+	int		ret,		/* <0: gets_server failed */
+	char		*msg,		/* message returned by server */
+	char		cmd,		/* expected command code, 0=any */
+	char		*host,		/* server host name */
+	char		*fname)		/* file name or 0 */
 {
 	char		err[10240];	/* error message buffer */
 
 	*err = 0;
 	if (ret < 0) {
-		sprintf(err, "Server on host %s is unreachable.",
-					host ? host : "<unknown>");
+		sprintf(err, _("Server on host %s is unreachable."),
+					host ? host : _("<unknown>"));
 	} else if (cmd && *msg != cmd) {
 		sprintf(err,
-"Server host \"%s\" protocol error:\n\
+_("Server host \"%s\" protocol error:\n\
 Expected reply code `%c' but server sent `%c'.\n\
-Full reply message in error was:\n%s",
+Full reply message in error was:\n%s"),
 			host, cmd, *msg, msg);
 	}
 	if (*err) {
 		if (fname)
 			sprintf(err+strlen(err),
-				"\n(Trying to access file \"%s\".)", fname);
+				_("\n(Trying to access file \"%s\".)"), fname);
 		strcat(err, "\n");
 		create_error_popup(0, 0, "%s", err);
 		return(FALSE);
@@ -283,9 +304,9 @@ static int  host_fd;
 static BOOL write_to_net(line) char *line;
 	{ puts_server(host_fd, line); return(TRUE); }
 
-BOOL server_entry_op(entry, op)
-	struct entry	*entry;		/* entry to lock/unlock/delete */
-	char		op;		/* l=lock, u=unlock, d=del, w=write */
+BOOL server_entry_op(
+	struct entry	*entry,		/* entry to lock/unlock/delete */
+	char		op)		/* l=lock, u=unlock, d=del, w=write */
 {
 	char		buf[128];	/* command to server, reply */
 	BOOL		ret, r;		/* read from server succeeded? */
@@ -345,8 +366,8 @@ BOOL server_entry_op(entry, op)
  * entries are read. See netplan_if.h for server protocol specifications.
  */
 
-int open_and_count_rows_on_server(uid)
-	int		uid;		/* user[] index */
+int open_and_count_rows_on_server(
+	int		uid)		/* user[] index */
 {
 	char		buf[1024];	/* command to server, reply */
 	register char	*p;		/* for preparing raw reply lines */
@@ -374,7 +395,7 @@ int open_and_count_rows_on_server(uid)
 			user[uid].readonly = buf[2] == 'r';
 		else if (buf[2] == 'r')
 			create_error_popup(0, 0,
-				"Your own appointment file is read-only!");
+				_("Your own appointment file is read-only!"));
 
 		*fidp = fid = atoi(buf+3);		/* file ID */
 	}
@@ -389,10 +410,10 @@ int open_and_count_rows_on_server(uid)
 }
 
 
-void read_from_server(list, uid, rid)
-	struct plist	**list;		/* list to add to */
-	int		uid;		/* user[] index or -1 */
-	int		rid;		/* entry ID, or 0 for all */
+void read_from_server(
+	struct plist	**list,		/* list to add to */
+	int		uid,		/* user[] index or -1 */
+	int		rid)		/* entry ID, or 0 for all */
 {
 	char		buf[1024];	/* command to server, reply */
 	struct host	*host;		/* info about host and file */
@@ -419,12 +440,12 @@ void read_from_server(list, uid, rid)
 		if (!check_server_reply(ret, buf, 'r', host->name, uname))
 			return;
 		buf[1] = '@'; /* flag for parse_file_line */
-		parse_file_line(list, host, uname, FALSE, buf+1);
+		parse_file_line(list, host->name, uname, FALSE, buf+1);
 		while (ret == 0) {
 			ret = gets_server(host->fd, buf,sizeof(buf),TRUE,TRUE);
 			if (!check_server_reply(ret, buf, 0, host->name,uname))
 				return;
-			parse_file_line(list, host, uname, FALSE, buf);
+			parse_file_line(list, host->name, uname, FALSE, buf);
 		}
 	}
 }
@@ -440,10 +461,10 @@ void read_from_server(list, uid, rid)
  * whether it needs to be escaped or not.
  */
 
-static BOOL flush_server(fd, msg, num)
-	int		fd;		/* socket descriptor to send to */
-	char		*msg;		/* message string to send */
-	int		num;		/* number of bytes in *msg */
+static BOOL flush_server(
+	int		fd,		/* socket descriptor to send to */
+	char		*msg,		/* message string to send */
+	int		num)		/* number of bytes in *msg */
 {
 	register int	n;
 
@@ -459,9 +480,9 @@ static BOOL flush_server(fd, msg, num)
 	return(TRUE);
 }
 
-BOOL puts_server(fd, msg)
-	int		fd;		/* socket descriptor to send to */
-	char		*msg;		/* message string to send, 0-term */
+BOOL puts_server(
+	int		fd,		/* socket descriptor to send to */
+	char		*msg)		/* message string to send, 0-term */
 {
 	static char	buf[SBUFSZ+2];	/* message buffer plus space for \n */
 	static char	*endbuf;	/* next free byte in buffer */
@@ -516,14 +537,14 @@ BOOL puts_server(fd, msg)
  * never be two communications at once.
  */
 
-static BOOL gets_server_line();
+static BOOL gets_server_line(int, char *, int, BOOL);
 
-BOOL gets_server(fd, msg, num, wait, cont)
-	int		fd;		/* socket descriptor to send to */
-	char		*msg;		/* buffer for incoming message */
-	int		num;		/* size of msg buffer (paranoia...) */
-	BOOL		wait;		/* need reply, not just '?' and 'R' */
-	BOOL		cont;		/* expecting a continuation line? */
+BOOL gets_server(
+	int		fd,		/* socket descriptor to send to */
+	char		*msg,		/* buffer for incoming message */
+	int		num,		/* size of msg buffer (paranoia...) */
+	BOOL		wait,		/* need reply, not just '?' and 'R' */
+	BOOL		cont)		/* expecting a continuation line? */
 {
 	BOOL		ret;		/* did read work? */
 	struct host	*hp;		/* for finding host name */
@@ -534,7 +555,7 @@ BOOL gets_server(fd, msg, num, wait, cont)
 	for (hp=host_list; hp; hp=hp->next)
 		if (hp->fd == fd)
 			break;
-	host = hp ? hp->name : "<unknown>";
+	host = hp ? hp->name : _("<unknown>");
 	for (;;) {
 		*msg = 0;
 		ret = gets_server_line(fd, msg, num, wait);
@@ -548,7 +569,7 @@ BOOL gets_server(fd, msg, num, wait, cont)
 				i += strlen(msg+i);
 			}
 			create_error_popup(mainwindow, 0,
-				"Server host %s reports a problem:\n\n%s",
+				_("Server host %s reports a problem:\n\n%s"),
 				host, msg+1);
 			break;
 		  case 'R':
@@ -574,11 +595,11 @@ BOOL gets_server(fd, msg, num, wait, cont)
 }
 
 
-static BOOL gets_server_line(fd, msg, num, wait)
-	int		fd;		/* socket descriptor to send to */
-	char		*msg;		/* buffer for incoming message */
-	int		num;		/* size of msg buffer (paranoia...) */
-	BOOL		wait;		/* return 0 if no data, don't block */
+static BOOL gets_server_line(
+	int		fd,		/* socket descriptor to send to */
+	char		*msg,		/* buffer for incoming message */
+	int		num,		/* size of msg buffer (paranoia...) */
+	BOOL		wait)		/* return 0 if no data, don't block */
 {
 	static char	buf[RBUFSZ];	/* receive buffer */
 	static int	enq, deq;	/* # of valid bytes, # of read bytes */
@@ -616,3 +637,97 @@ static BOOL gets_server_line(fd, msg, num, wait)
 	*msg++ = 0;					/* null-terminate */
 	return(c == '\n' && !prev_esc);			/* unescaped newline?*/
 }
+
+
+/*
+ * read the file list from netplan server <fd>. Returns an allocated array of
+ * pointers. The caller must free every pointer of this list, and the list
+ * itself.
+ */
+
+BOOL get_netplan_filelist(
+	char		*uhost,		/* server host to request from */
+	char		***list,	/* returned list */
+	int		*num)		/* returned # of entries in list */
+{
+	int		fd;		/* socket connection to server */
+	char		buf[256];	/* returned line from server */
+	int		nalloc = 0;	/* number of lines allocated */
+	char		msg[10240];	/* problem report */
+	int		i;
+
+	*list = 0;
+	*num  = 0;
+	*msg  = 0;
+	if ((fd = connect_netplan_server(uhost, "", msg)) < 0)
+		return(FALSE);
+	strcpy(buf, "L\n");
+	if (!puts_server(fd, buf) || !puts_server(fd, 0)) {
+		close(fd);
+		return(FALSE);
+	}
+	for (;;) {
+		if (!gets_server(fd, buf, sizeof(buf), TRUE, FALSE) ||
+							buf[1] != 't') {
+			close(fd);
+			return(FALSE);
+		}
+		if (buf[2] < ' ') {
+			close(fd);
+			return(TRUE);
+		}
+		if (*num >= nalloc) {
+			int n = (nalloc += 32) * sizeof(char **);
+			*list = *list ? (char **)realloc(*list, n)
+				      : (char **)malloc(n);
+			if (!*list)
+				fatal("no memory");
+		}
+		if (*buf && buf[i = strlen(buf)-1] == '\n')
+			buf[i] = 0;
+		(*list)[(*num)++] = mystrdup(buf+2);
+	}
+}
+
+
+/*
+ * read all users from a netplan server, and add them all to the user list.
+ */
+
+void obtain_netplan_users(
+	char		*uhost)		/* server host to request from */
+{
+	char		**list;		/* returned file list */
+	int		num;		/* returned # of entries in list */
+	int		i, u;		/* user list counters */
+
+	/* if num is 0, list is not allocated so just return also - mjj */
+	if (!get_netplan_filelist(uhost, &list, &num) || num == 0)
+		return;
+	for (i=0; i < num; i++) {
+		for (u=0; u < nusers; u++)
+			if (!strcmp(user[u].name, list[i]))
+				break;
+		if (u < nusers)
+			continue;
+		if (nusers >= maxusers) {
+			u = nusers + 10;
+			user = user ? realloc(user, u * sizeof(struct user))
+				    : malloc(u * sizeof(struct user));
+			if (!user)
+				fatal(_("no memory"));
+			memset(user+maxusers, 0,
+					(u-maxusers) * sizeof(struct user));
+			maxusers = u;
+		}
+		user[nusers].name	= mystrdup(list[i]);
+		user[nusers].server	= mystrdup(uhost);
+		user[nusers].fromserver	= TRUE;
+		user[nusers].file_id	= -1;
+		user[nusers].alarm	= TRUE;
+		nusers++;
+	}
+	for (i=0; i < num; i++)
+		free(list[i]);
+	free(list);
+}
