@@ -10,10 +10,8 @@
  * Author: thomas@bitrot.in-berlin.de (Thomas Driemeyer)
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #ifdef VARARGS
 #include <varargs.h>
 #else
@@ -22,6 +20,9 @@
 #include <time.h>
 #include <Xm/Xm.h>
 #include <X11/StringDefs.h>
+#include "cal.h"
+#undef COL_RED
+#undef NCOLS
 #include "notifier.h"
 #include "version.h"
 #include "bm_noticon.h"
@@ -39,10 +40,10 @@
 #define srandom srand
 #endif
 
-static void init_colors(), readfile(), usage();
-#ifdef MIPS
-extern char *malloc(), *realloc();
-#endif
+static void readfile		(char **, FILE *);
+static void usage		(void);
+static char *string_resource	(char *, char *);
+static void init_colors		(void);
 
 Display			*display;		/* common server */
 GC			gc;			/* common graphics context */
@@ -103,9 +104,9 @@ static String fallbacks[] = {
  * initialize everything and create the main calendar window
  */
 
-int main(argc, argv)
-	int			argc;
-	char			*argv[];
+int main(
+	int			argc,
+	char			*argv[])
 {
 	Pixmap			icon;
 	int			n, i;
@@ -167,8 +168,8 @@ int main(argc, argv)
 					fflush(stdout);
 					exit(0);
 				  case 'v':
-					fprintf(stderr, "%s: %s\n",
-						progname, VERSION);
+					fprintf(stderr, "%s: %s\n", progname,
+							VERSION JAPANVERSION);
 					exit(0);
 				  case 'e':
 					timeout = atol(&argv[n][i+1]);
@@ -234,9 +235,10 @@ int main(argc, argv)
 
 #ifndef VARARGS
 /*VARARGS*/
-void fatal(char *fmt, ...)
+void fatal(
+	char		*fmt, ...)
 {
-	va_list			parm;
+	va_list		parm;
 
 	va_start(parm, fmt);
 	fprintf(stderr, "%s: ", progname);
@@ -248,9 +250,12 @@ void fatal(char *fmt, ...)
 
 #else
 /*VARARGS*/
-fatal(fmt, a, b, c, d)
-	char	*fmt;
-	int	a, b, c, d;
+void fatal(
+	char	*fmt,
+	int	a,
+	int	b,
+	int	c,
+	int	d)
 {
 	fprintf(stderr, fmt, a, b, c, d);
 	putc('\n', stderr);
@@ -265,9 +270,9 @@ fatal(fmt, a, b, c, d)
  * This routine avoids feof() because it seems to be broken on some Unix PCs.
  */
 
-static void readfile(msg, fp)
-	char			**msg;
-	FILE			*fp;
+static void readfile(
+	char			**msg,
+	FILE			*fp)
 {
 	long			size = 4098;	/* msg size, two more for \0 */
 	long			nread = 0;	/* how many read so far */
@@ -290,7 +295,7 @@ static void readfile(msg, fp)
  * usage information
  */
 
-static void usage()
+static void usage(void)
 {
 	fprintf(stderr,
 		"Usage: %s [options] [file]\nOptions:\n%s%s%s%s%s%s%s%s%s%s",
@@ -313,9 +318,9 @@ static void usage()
  * read real application resources
  */
 
-static char *string_resource(res_name, res_class_name)
-	char		*res_name;
-	char		*res_class_name;
+static char *string_resource(
+	char		*res_name,
+	char		*res_class_name)
 {
 	char		*res;
 	XtResource	res_list[1];
@@ -337,7 +342,7 @@ static char *string_resource(res_name, res_class_name)
  * determine all colors, and allocate them.
  */
 
-static void init_colors()
+static void init_colors(void)
 {
 	Screen			*screen = DefaultScreenOfDisplay(display);
 	Colormap		cmap;
