@@ -282,7 +282,7 @@ void create_multiple_popup(
 	XtSetArg(args[n], XmNmessageString,	s1);		n++;
 	XtSetArg(args[n], XmNokLabelString,	s2);		n++;
 	XtSetArg(args[n], XmNcancelLabelString,	s3);		n++;
-	XtSetArg(args[1], XmNdialogStyle,
+	XtSetArg(args[n], XmNdialogStyle,
 			  XmDIALOG_FULL_APPLICATION_MODAL);	n++;
 	dialog = XmCreateWarningDialog(mainwindow, _("Warning"), args, n);
 	XmStringFree(s1);
