@@ -370,10 +370,8 @@ static void omit_appts_callback(
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
-	if (data->set) {
-		config.pr_omit_appts ^= TRUE;
-		mainlist->modified    = TRUE;
-	}
+	config.pr_omit_appts = data->set;
+	mainlist->modified   = TRUE;
 }
 
 
@@ -383,10 +381,8 @@ static void omit_priv_callback(
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
-	if (data->set) {
-		config.pr_omit_priv ^= TRUE;
-		mainlist->modified   = TRUE;
-	}
+	config.pr_omit_priv  = data->set;
+	mainlist->modified   = TRUE;
 }
 
 
@@ -396,10 +392,8 @@ static void omit_others_callback(
 	int    				 item,
 	XmToggleButtonCallbackStruct	*data)
 {
-	if (data->set) {
-		config.pr_omit_others ^= TRUE;
-		mainlist->modified     = TRUE;
-	}
+	config.pr_omit_others  = data->set;
+	mainlist->modified     = TRUE;
 }
 
 
@@ -409,10 +403,8 @@ static void color_callback(
 	int    				 item,
 	XmToggleButtonCallbackStruct	*data)
 {
-	if (data->set) {
-		config.pr_color   ^= TRUE;
-		mainlist->modified = TRUE;
-	}
+	config.pr_color    = data->set;
+	mainlist->modified = TRUE;
 }
 
 
@@ -636,9 +628,11 @@ static int Print_Day(
 		return (-1);
 
 	daycolor = WeekDay == 6 || WeekDay == 0 ? COL_WEEKEND : COL_WEEKDAY;
+	hp  = &sm_holiday[JulDay];
+	hp2 =    &holiday[JulDay];
 	for (j=0; j < 2; j++)
 		if (!daycolor && hp->daycolor)
-			daycolor = (i ? holiday : sm_holiday)[JulDay].daycolor;
+			daycolor = (j ? holiday : sm_holiday)[JulDay].daycolor;
 	DayEnd = DayStart + 86399;
 #if 0
 	if (config.pr_color && daycolor)
@@ -650,8 +644,6 @@ static int Print_Day(
 	fprintf(fp, "%d %d %d %d %d NewDay\n",
 				Month+1, Day, Year, WeekNum+1, JulDay+1);
 
-	hp  = &sm_holiday[JulDay];
-	hp2 =    &holiday[JulDay];
 	if (hp->string && *hp->string || hp2->string && *hp2->string) {
 		fprintf(fp, "[ ");
 		for (j=0; j < 2; j++, hp=hp2) {
@@ -718,11 +710,11 @@ static int Print_Day(
 				xcolor[color].blue  / 65536.);
 		}
 		if (config.mmddyy)
-			fprintf(fp, " (%02d/%02d/%02d)\t",
-				tm->tm_mon+1, tm->tm_mday, tm->tm_year);
+			fprintf(fp, " (%d/%d/%d)\t",
+				tm->tm_mon+1, tm->tm_mday, tm->tm_year + 1900);
 		else
-			fprintf(fp, " (%d.%d.%02d)\t",
-				tm->tm_mday, tm->tm_mon+1, tm->tm_year);
+			fprintf(fp, " (%d.%d.%d)\t",
+				tm->tm_mday, tm->tm_mon+1, tm->tm_year + 1900);
 
 		if (entry->notime)
 			fprintf(fp, "()");
