@@ -264,10 +264,10 @@ extern void set_icon(			/* set icon for the application */
 	Widget		shell,
 	int		sub);		/* 0=main, 1=submenu */
 extern int strlen_in_pixels(		/* return length of string in pixels */
-	unsigned char	*string,	/* string to truncate */
+	char		*string,	/* string to truncate */
 	int		sfont);		/* FONT_* */
 extern void truncate_string(		/* truncate string to fit into n pixs*/
-	unsigned char	*string,	/* string to truncate */
+	char		*string,	/* string to truncate */
 	int		len,		/* max len in pixels */
 	int		sfont);		/* font of string */
 extern void drag_init(
