@@ -41,7 +41,7 @@
 "*colHolidayMagenta: #ff00ff",
 "*colHolidayCyan:    #008080",
 "*colHolidayWhite:   #ffffff",
-#if !defined(bsdi) && !defined(linux)
+#if !defined(bsdi) && !defined(LINUX)
 "*menubar*fontList:  -*-helvetica-bold-*-normal-*-14-*",
 "*fontList:          -*-helvetica-*-r-normal-*-14-*",
 "*helpFont:          -*-helvetica-medium-r-normal-*-14-*",
@@ -83,7 +83,7 @@
 "*sgiMode:           True",
 "*useSchemes:        True",
 #endif
-#if defined(linux)
+#if defined(LINUX)
 "*yearTitleFont:     -*-helvetica-*-r-*-*-24-*",
 "*yearMonthFont:     -*-helvetica-*-o-*-*-18-*",
 #else
@@ -136,7 +136,7 @@
 #ifdef JAPAN
 #ifndef sun
 #ifdef NEWSOS4
-"*jNoteFont:                -*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*",
+"*jNoteFont:                -*-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-*",
 "*dayform*fontList:         -*-helvetica-*-r-*-*-17-*,16x16kanji=JISX0208.1983-0",
 "*dayform*text.fontList:    8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
 "*dayform*holiday.fontList: 8x16=ISO8859-1,16x16kanji=JISX0208.1983-0",
@@ -146,7 +146,7 @@
 "*weekinfo.fontList:        -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
 "*yovinfo.fontList:         -*-helvetica-medium-r-*-*-14-*,14x14kanji=JISX0208.1983-0",
 #else
-"*jNoteFont:                 -*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*",
+"*jNoteFont:                -*-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-*",
 "*dayform*fontList:          -*-helvetica-*-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
 "*dayform*text.fontList:     -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
 "*dayform*holiday.fontList:  -*-fixed-medium-r-normal--14-*-*-*-*-*-iso8859-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
@@ -157,14 +157,14 @@
 "*yovinfo.fontList:          -*-helvetica-medium-r-*-*-14-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0208.1983-*;-*-fixed-medium-r-normal--14-*-*-*-*-*-jisx0201.1976-*:",
 #endif
 #else
-"*jNoteFont:                -sun-*-14-*-jisx0208.1983-0",
-"*dayform*fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
+"*jNoteFont:                -*-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-*",
+"*dayform*fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
 "*dayform*text.fontList:    -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
 "*dayform*holiday.fontList: -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
 "*text.fontList:            -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
 "*keyform*XmText.fontList:  -misc-fixed-medium-r-*-14-*-iso8859-1;-misc-fixed-medium-*-14-*-jisx0208.1983-0;-misc-fixed-medium-r-*-14-*-jisx0201.1976-0:",
-"*dayinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
-"*weekinfo.fontList:        -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
-"*yovinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-sun-*-14-*-jisx0208.1983-0;-sun-*-14-*-jisx0201.1976-0:",
+"*dayinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
+"*weekinfo.fontList:        -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
+"*yovinfo.fontList:         -*-helvetica-*-r-*-14-*-iso8859-1;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0201.1976-0;-misc-fixed-medium-r-normal--16-*-*-*-*-*-jisx0208.1983-0:",
 #endif
 #endif
