@@ -234,12 +234,15 @@ void guess_tzone(void)
 		 * platforms. If you have corrections or extensions for other
 		 * platforms, implement it here and tell me (thomas@bitrot.de).
 		 */
-#if defined(SVR4) || defined(SOLARIS2) || defined(linux) || defined(sgi)
+#if defined(SVR4) || defined(SOLARIS2) || defined(linux) || defined(sgi) || defined(OSF)
 		time_t now = time(0);
 		struct tm *tm = localtime(&now);
 		time_t h = tm->tm_hour;
 		struct tm *gmt = gmtime(&now);
-		zone = (gmt->tm_hour - h) * 3600;
+		zone = gmt->tm_hour - h;
+		if (zone < -12)		/* Truxton Fulton <trux@truxton.com> */
+			zone += 24;
+		zone *= 3600;
 #else
 #if defined(bsdi) || defined(SUN) || defined(SVR4) || defined(convex)
 		time_t now;
