@@ -5,19 +5,18 @@
  * button. For editing and input into the Text button, see useredit.c.
  *
  *	all_files_served()		all files read from server?
+ *	can_edit_appts()		don't edit appts if user menu is up
  *	destroy_user_popup()		remove user popup
  *	create_user_popup()		create user popup
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <pwd.h>
 #include <Xm/Xm.h>
 #include <Xm/Form.h>
@@ -30,16 +29,26 @@
 #include <Xm/ScrolledW.h>
 #include <Xm/Text.h>
 #include <Xm/Protocols.h>
+#include "config.h"
 #include "cal.h"
 
 enum Columns { C_EN_MONTH=0, C_EN_WEEK, C_EN_DAY, C_EN_YROV, C_EN_ALARM,
 		C_GROUP, C_NAME, C_EN_SRV, C_PATH, C_SERVER, NCOLUMNS,
 		COLPOPUP };
 
-static Widget call_popup_callback();
-static void create_user_rows(), edit_user_button(), got_user_text(),
-	    draw_row(), delete_callback(), sort_callback(),
-	    cancel_callback(), done_callback(), list_callback(), got_text();
+static char *default_server	(char *, int, int);
+static void edit_user_button	(BOOL, int, int);
+static void got_user_text	(int, int, char *);
+static void copyuser		(struct user **, int *, struct user *, int);
+static void delete_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void sort_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void browse_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void cancel_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void got_text		(Widget, int, XmToggleButtonCallbackStruct *);
+static Widget call_popup_callback(Widget, XtPointer, XEvent *, Boolean *);
+
 #ifdef MIPS
 extern struct passwd *getpwnam();
 #endif
@@ -80,7 +89,7 @@ static Widget	(*utable)[NCOLUMNS+2];	/* all widgets in user list table */
  * Sync or only-owner-can-write have no function and can be grayed out.
  */
 
-BOOL all_files_served()
+BOOL all_files_served(void)
 {
 	int u;
 
@@ -97,12 +106,12 @@ BOOL all_files_served()
  * be lost. Also put up an error popup and bring the usermenu to the front.
  */
 
-BOOL can_edit_appts()
+BOOL can_edit_appts(void)
 {
 	if (have_shell) {
 		create_error_popup(shell, 0,
-			"Please finish specifying the file list and the\n"
-			"network connections before editing appointments.");
+			_("Please finish specifying the file list and the\n"\
+			  "network connections before editing appointments."));
 		return(FALSE);
 	}
 	return(TRUE);
@@ -116,9 +125,11 @@ BOOL can_edit_appts()
  * Cancel is pressed. The sizes are also copied but are not otherwise checked.
  */
 
-static void copyuser(tar, ntar, src, nsrc)
-	register struct user	**tar, *src;	/* lists to copy */
-	int			*ntar, nsrc;	/* list sizes to copy */
+static void copyuser(
+	register struct user	**tar,		/* lists to copy */
+	int			*ntar,		/* list sizes to copy */
+	register struct user	*src,
+	int			nsrc)
 {
 	register struct user	*u;		/* target scan pointer */
 	register int		i;		/* target counter */
@@ -141,7 +152,7 @@ static void copyuser(tar, ntar, src, nsrc)
 	*tar = 0;
 	if (src) {
 		if (!(u = *tar = malloc(nsrc * sizeof(struct user))))
-			fatal("no memory");
+			fatal(_("no memory"));
 		for (i=0; i < nsrc; i++, u++, src++) {
 			*u = *src;
 			u->name   = mystrdup(u->name);
@@ -161,7 +172,7 @@ static void copyuser(tar, ntar, src, nsrc)
  * do the attach and offer to copy the file to the server first.
  */
 
-static BOOL accept_new_list()
+static BOOL accept_new_list(void)
 {
 	register struct entry	*ep;
 	register struct user	*up;
@@ -186,7 +197,7 @@ static BOOL accept_new_list()
 		ep = mainlist->entry;
 		for (i=mainlist->nentries-1; i >= 0; i--, ep++)
 			nlocal += !ep->user && !u ||
-				  !strcmp(ep->user, up->name);
+				   ep->user && !strcmp(ep->user, up->name);
 		if (!nlocal)
 			continue;
 		if (!nremote) {
@@ -198,12 +209,12 @@ static BOOL accept_new_list()
 					ep->file = up->file_id;
 					if (!server_entry_op(ep, 'w'))
 						create_error_popup(0, 0,
-								"write error");
+							_("write error"));
 				}
 			create_error_popup(mainwindow, 0,
-				"File %s on server %s did not\nexist. "
-				"Created one and initialized with\n"
-				"currently loaded appointments.",
+				_("File %s on server %s did not\nexist. "\
+				  "Created one and initialized with\n"\
+				  "currently loaded appointments."),
 				up->name, up->server);
 			continue;
 
@@ -214,23 +225,22 @@ static BOOL accept_new_list()
 			unlink(target);
 			if (!copyfile(source, target)) {
 				create_error_popup(shell, 0,
-					"Failed to back up %s,\n"
-					"cannot write to %s",
-					source, target);
+					_("Failed to back up %s,\ncannot "\
+					  "write to %s"), source, target);
 				return(FALSE);
 			}
 			create_error_popup(mainwindow, 0,
-				"You have %d appointments here and\n"
-				"%d on server %s. Saved %s\n"
-				"to %s and discarded old\n"
-				"appointments in %s.",
+				_("You have %d appointments here and\n"\
+				  "%d on server %s. Saved %s\n"\
+				  "to %s and discarded old\n"\
+				  "appointments in %s."),
 				nlocal, nremote, up->server,
 				source, target, source);
 		} else if (nlocal != nremote)
 			create_error_popup(mainwindow, 0,
-				"File %s has %d appointments in %s\n"
-				"and %d on server %s. Switching to "
-				"server and ignoring\nfile %s.",
+				_("File %s has %d appointments in %s\n"\
+				  "and %d on server %s. Switching to "\
+				  "server and ignoring\nfile %s."),
 				up->name, nlocal, up->path,
 				nremote, up->server, up->path);
 	}
@@ -245,12 +255,13 @@ static BOOL accept_new_list()
 }
 
 
-void destroy_user_popup(accept)
-	BOOL		accept;		/* true=Done, false=Cancel */
+void destroy_user_popup(
+	BOOL		accept)		/* true=Done, false=Cancel */
 {
 	if (!have_shell)
 		return;
 	edit_user_button(FALSE, 0, 0);
+	destroy_serv_popup();
 	if (accept) {
 		if (!accept_new_list())
 			return;
@@ -270,7 +281,7 @@ void destroy_user_popup(accept)
  * create a user popup as a separate application shell.
  */
 
-void create_user_popup()
+void create_user_popup(void)
 {
 	Widget			form, scroll, w;
 	Arg			args[15];
@@ -286,7 +297,7 @@ void create_user_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmUNMAP);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("File List",
+	shell = XtCreatePopupShell(_("File List"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -295,7 +306,8 @@ void create_user_popup()
 	set_icon(shell, 1);
 	form = XtCreateWidget("userform", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"user");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"user");
 
 							/*-- buttons --*/
 	n = 0;
@@ -305,11 +317,12 @@ void create_user_popup()
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
 	XtSetArg(args[n], XmNsensitive,		False);			n++;
-	delete = w = XtCreateManagedWidget("Delete", xmPushButtonWidgetClass,
-			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, delete_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback,   (XtPointer)
-								"user_delete");
+	delete = w = XtCreateManagedWidget(_("Delete"),
+			xmPushButtonWidgetClass, form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			delete_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback,   (XtPointer) "user_delete");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -317,22 +330,37 @@ void create_user_popup()
 	XtSetArg(args[n], XmNleftWidget,	w);			n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Sort", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Sort"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, sort_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"user_sort");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			sort_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "user_sort");
+	n = 0;
+	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNleftWidget,	w);			n++;
+	XtSetArg(args[n], XmNleftOffset,	8);			n++;
+	XtSetArg(args[n], XmNwidth,		80);			n++;
+	w = XtCreateManagedWidget(_("Browse"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			browse_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "user_browse");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"user_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "user_done");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -340,12 +368,12 @@ void create_user_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, help_callback, (XtPointer)
-								"user");
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"user");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"user");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"user");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -353,11 +381,12 @@ void create_user_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Cancel", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Cancel"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, cancel_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"user_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			cancel_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer) "user_done");
 
 							/*-- infotext -- */
 	n = 0;
@@ -388,8 +417,8 @@ void create_user_popup()
 	XtSetArg(args[n], XmNscrollingPolicy,	XmAUTOMATIC);		n++;
 	scroll = XtCreateWidget("uscroll", xmScrolledWindowWidgetClass,
 			form, args, n);
-	XtAddCallback(scroll, XmNhelpCallback, help_callback, (XtPointer)
-								"user");
+	XtAddCallback(scroll, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"user");
 
 	n = 0;
 	ulist = XtCreateManagedWidget("ulist", xmBulletinBoardWidgetClass,
@@ -402,8 +431,8 @@ void create_user_popup()
 	XtPopup(shell, XtGrabNone);
 
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 	have_shell = TRUE;
 	for (n=0; n < nusers; n++)
 		user[n].prev_fromserver = user[n].fromserver;
@@ -418,7 +447,6 @@ void create_user_popup()
  * widget row for the title at the top. All the text buttons are
  * label widgets. For performance reasons, they are overlaid by a text
  * widget when pressed.
- * No text is printed into the buttons yet, this is done later by draw_users().
  */
 
 static short cell_x    [NCOLUMNS];
@@ -431,7 +459,7 @@ static char *cell_help [NCOLUMNS] = { "user_enable", "user_enable",
 				      "user_enable", "user_color", "user_name",
 				      "user_home", "user_home", "user_home" };
 
-static void create_user_rows()
+void create_user_rows(void)
 {
 	Widget			w, *urow;
 	int			nrows = nusers+5 - nusers%5;
@@ -458,7 +486,7 @@ static void create_user_rows()
 	n = (nrows+1) * (NCOLUMNS+2) * sizeof(Widget *);
 	if (utable && !(utable = (Widget (*)[])realloc(utable, n)) ||
 	   !utable && !(utable = (Widget (*)[])malloc(n)))
-		fatal("no memory");
+		fatal(_("no memory"));
 							/* build list */
 	XtUnmanageChild(ulist);
 	for (y=have_nrows; y <= nrows; y++) {
@@ -510,7 +538,7 @@ static void create_user_rows()
 			shadow = FALSE;
 			class  = xmLabelWidgetClass;
 			align  = XmALIGNMENT_CENTER;
-			name   = cell_name[x];
+			name   = _(cell_name[x]);
 		}
 		XtSetArg(args[n], XmNx,			cell_x[x]+xo);  n++;
 		XtSetArg(args[n], XmNwidth,		cell_xs[x]-xo);	n++;
@@ -552,15 +580,17 @@ static void create_user_rows()
 		} else
 #endif
 		if (y)
-			XtAddCallback(urow[x], callbk, list_callback,
-			   			(XtPointer)(x + y * NCOLUMNS));
-		XtAddCallback(urow[x], XmNhelpCallback, help_callback,
-						(XtPointer)cell_help[x]);
+			XtAddCallback(urow[x], callbk,
+					(XtCallbackProc)list_callback,
+			   		(XtPointer)(x + y * NCOLUMNS));
+		XtAddCallback(urow[x], XmNhelpCallback,
+					(XtCallbackProc)help_callback,
+					(XtPointer)cell_help[x]);
 	    }
 	    XtManageChild(urow[NCOLUMNS]);
 	}
 	for (y=have_nrows; y <= nrows; y++)
-		draw_row(y);
+		draw_user_row(y);
 	have_nrows = nrows;
 	XtManageChild(ulist);
 }
@@ -571,10 +601,10 @@ static void create_user_rows()
  * return a default host name for row y (1=own)
  */
 
-static char *default_server(buf, bufsz, y)
-	char		*buf;		/* name buffer, static wastes space */
-	int		bufsz;		/* size of buffer */
-	int		y;		/* for which row, 1=own */
+static char *default_server(
+	char		*buf,		/* name buffer, static wastes space */
+	int		bufsz,		/* size of buffer */
+	int		y)		/* for which row, 1=own */
 {
 	return(y == 1 ? gethostname(buf, bufsz)	? "localhost"
 						: buf
@@ -590,10 +620,10 @@ static char *default_server(buf, bufsz, y)
  * button is un-edited.
  */
 
-static void edit_user_button(doedit, x, y)
-	BOOL			doedit;		/* TRUE=edit, FALSE=unedit */
-	int			x;		/* column, 0..NCOLUMNS-1* */
-	int			y;		/* row, y=0: title */
+static void edit_user_button(
+	BOOL			doedit,		/* TRUE=edit, FALSE=unedit */
+	int			x,		/* column, 0..NCOLUMNS-1* */
+	int			y)		/* row, y=0: title */
 {
 	register struct user	*u;
 	Arg			args[15];
@@ -627,7 +657,7 @@ static void edit_user_button(doedit, x, y)
 			user[yedit-1].suspend_w =
 			user[yedit-1].suspend_o =
 			user[yedit-1].suspend_d = 0;
-		draw_row(yedit);
+		draw_user_row(yedit);
 		create_user_rows();
 	}
 	textwidget = 0;
@@ -649,10 +679,10 @@ static void edit_user_button(doedit, x, y)
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	textwidget = XtCreateManagedWidget("text", xmTextWidgetClass,
 						ulist, args, n);
-	XtAddCallback(textwidget, XmNactivateCallback, got_text,
-						(XtPointer)(x + y * NCOLUMNS));
-	XtAddCallback(textwidget, XmNhelpCallback, help_callback,
-						(XtPointer)cell_help[x]);
+	XtAddCallback(textwidget, XmNactivateCallback, (XtCallbackProc)
+			got_text, (XtPointer)(x + y * NCOLUMNS));
+	XtAddCallback(textwidget, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)cell_help[x]);
 	XmProcessTraversal(textwidget, XmTRAVERSE_CURRENT);
 
 	text =  y > nusers    ? ""	  :
@@ -670,10 +700,10 @@ static void edit_user_button(doedit, x, y)
  * Check & store.
  */
 
-static void got_user_text(x, y, string)
-	int			x;		/* column, 0..NCOLUMNS-1* */
-	int			y;		/* row, y=0: title */
-	char			*string;	/* text entered by user */
+static void got_user_text(
+	int			x,		/* column, 0..NCOLUMNS-1* */
+	int			y,		/* row, y=0: title */
+	char			*string)	/* text entered by user */
 {
 	struct passwd		*pw;		/* for searching home dirs */
 	register struct user	*u;
@@ -691,12 +721,12 @@ static void got_user_text(x, y, string)
 	for (i=0; i < nusers; i++) {
 		if (x == C_NAME && i != y && !strcmp(string, user[i].name)) {
 			create_error_popup(shell, 0,
-				"Name is not unique, rejected");
+				_("Name is not unique, rejected"));
 			return;
 		}
 		if (x == C_PATH && i != y && !strcmp(string, user[i].path)) {
 			create_error_popup(shell, 0,
-				"Path is not unique, rejected");
+				_("Path is not unique, rejected"));
 			return;
 		}
 	}
@@ -704,7 +734,7 @@ static void got_user_text(x, y, string)
 		int n = ++nusers * sizeof(struct user);
 		if (user && !(user = (struct user *)realloc(user, n)) ||
 		   !user && !(user = (struct user *)malloc(n)))
-			fatal("no memory");
+			fatal(_("no memory"));
 		y = nusers-1;
 		u = user + y;
 		memset(u, 0, sizeof(struct user));
@@ -729,8 +759,8 @@ static void got_user_text(x, y, string)
 		u->path = mystrdup(string);
 		u->fromserver = FALSE;
 		if (*u->path && access(u->path, F_OK))
-			print_button(info, "%s: %s", u->path,
-				errno==ENOENT ? "new file" : "cannot access");
+			print_button(info, "%s: %s", u->path, errno==ENOENT ?
+					_("new file") : _("cannot access"));
 		break;
 
 	  case C_SERVER:
@@ -745,7 +775,7 @@ static void got_user_text(x, y, string)
 			u->path = mystrdup(pw->pw_dir);
 		else {
 			sprintf(buf, "%s/%s", LIB, u->name);
-			print_button(info, "no user \"%s\"", u->name);
+			print_button(info, _("no user \"%s\""), u->name);
 			u->path = mystrdup(buf);
 		}
 	}
@@ -760,13 +790,12 @@ static void got_user_text(x, y, string)
  * If y is > nusers, the row is blanked.
  */
 
-static void draw_row(y)
-	int			y;
+void draw_user_row(
+	int			y)
 {
 	Widget			*urow = utable[y];
 	Arg			args[3];
 	register struct user	*u = &user[y-1];
-	int			col;
 
 	if (y < 1)
 		return;
@@ -788,7 +817,7 @@ static void draw_row(y)
 		XtSetArg(args[0], XmNsensitive, u->fromserver);
 		XtSetValues(urow[C_SERVER],    args, 1);
 		if (y == 1) {
-			print_button(urow[C_GROUP], "own");
+			print_button(urow[C_GROUP], _("own"));
 		} else {
 #ifdef XmCSimpleOptionMenu
 			XtSetArg(args[0], XmNbackground,  color[COL_CALBACK]);
@@ -797,10 +826,9 @@ static void draw_row(y)
 			XtSetValues(urow[C_GROUP], args, 2);
 #endif
 		}
-		print_button(urow[C_NAME],   "%s", u->name ? u->name:"?");
-		print_button(urow[C_PATH],   "%s", u->path ? u->path:"?");
-		print_button(urow[C_SERVER], "%s", u->server ?
-								u->server:"?");
+		print_button(urow[C_NAME],   "%s", u->name   ? u->name : "?");
+		print_button(urow[C_PATH],   "%s", u->path   ? u->path : "?");
+		print_button(urow[C_SERVER], "%s", u->server ? u->server:"?");
 	} else {
 		XtSetArg(args[0], XmNset, 0);			/* blank row */
 		XtSetValues (urow[C_EN_MONTH], args, 1);
@@ -828,16 +856,16 @@ static void draw_row(y)
  */
 
 /*ARGSUSED*/
-static void delete_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void delete_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	int				n;
 	Arg				args;
 
 	if (ycurr == 1)
-		print_button(info, "Cannot delete own file");
+		print_button(info, _("Cannot delete own file"));
 
 	else if (ycurr && ycurr <= nusers) {
 		edit_user_button(FALSE, 0, 0);
@@ -845,9 +873,9 @@ static void delete_callback(widget, item, data)
 			user[n] = user[n+1];
 		n = --nusers * sizeof(struct user);
 		if (n && !(user = (struct user *)realloc(user, n)))
-			fatal("no memory");
+			fatal(_("no memory"));
 		for (n=1; n <= have_nrows; n++)
-			draw_row(n);
+			draw_user_row(n);
 	}
 	if (ycurr <= 1) {
 		XtSetArg(args, XmNsensitive, 0);
@@ -870,10 +898,10 @@ static int compare(u, v) register CONST void *u, *v; {
 	:        ((struct user *)u)->color -  ((struct user *)v)->color); }
 
 /*ARGSUSED*/
-static void sort_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void sort_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	Arg				args;
 	int				n;
@@ -884,26 +912,37 @@ static void sort_callback(widget, item, data)
 		XtSetValues(delete, &args, 1);
 		qsort(user+1, nusers-1, sizeof(struct user), compare);
 		for (n=1; n <= nusers; n++)
-			draw_row(n);
+			draw_user_row(n);
 	}
 }
 
 
 /*ARGSUSED*/
-static void cancel_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void browse_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
+{
+	edit_user_button(FALSE, 0, 0);
+	create_serv_popup();
+}
+
+
+/*ARGSUSED*/
+static void cancel_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_user_popup(FALSE);
 }
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_user_popup(TRUE);
 }
@@ -917,11 +956,11 @@ static void done_callback(widget, item, data)
  */
 
 #ifdef XmCSimpleOptionMenu
-static Widget call_popup_callback(widget, y, event, cont)
-	Widget		widget;
-	XtPointer	y;
-        XEvent		*event;
-	Boolean		*cont;
+static Widget call_popup_callback(
+	Widget		widget,
+	XtPointer	y,
+        XEvent		*event,
+	Boolean		*cont)
 {
 	Widget popup = utable[(long)y][COLPOPUP];
 	event->xbutton.x += 19;
@@ -929,7 +968,7 @@ static Widget call_popup_callback(widget, y, event, cont)
 	XmMenuPosition(popup, (XButtonPressedEvent *)event);
 	XtManageChild(popup);
 	if (event->xbutton.button != 3)
-		print_button(info, "Use right mouse button to change color");
+		print_button(info, _("Use right mouse button to change color"));
 	return(0);
 }
 #endif
@@ -944,10 +983,10 @@ static Widget call_popup_callback(widget, y, event, cont)
  */
 
 /*ARGSUSED*/
-static void list_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	int				x = (item & 65535) % NCOLUMNS;
 	int				y = (item & 65535) / NCOLUMNS;
@@ -956,7 +995,7 @@ static void list_callback(widget, item, data)
 
 	if (y > nusers) {					/* new entry */
 		if (x != C_NAME) {
-			print_button(info, "Enter a name first");
+			print_button(info, _("Enter a name first"));
 			return;
 		}
 		ycurr = 0;
@@ -990,7 +1029,7 @@ static void list_callback(widget, item, data)
 
 		  case C_EN_SRV:
 			u->fromserver = data->set;
-			draw_row(y);
+			draw_user_row(y);
 			break;
 
 		  case C_GROUP:
@@ -1001,12 +1040,13 @@ static void list_callback(widget, item, data)
 					chk_pixmap : col_pixmap)[u->color&7]);
 				XtSetValues(utable[y][x], &arg, 1);
 			} else
-				print_button(info, "Cannot change own group");
+				print_button(info,
+						_("Cannot change own group"));
 			break;
 
 		  case C_PATH:
 			if (y == 1) {
-				print_button(info, "Cannot change own path");
+				print_button(info,_("Cannot change own path"));
 				return;
 			}
 		  case C_NAME:
@@ -1025,13 +1065,10 @@ static void list_callback(widget, item, data)
  */
 
 /*ARGSUSED*/
-static void got_text(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void got_text(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	int				x = item % NCOLUMNS;
-	int				y = item / NCOLUMNS;
-
 	edit_user_button(FALSE, 0, 0);
 }
