@@ -21,7 +21,10 @@
  */
  
 #include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
 #include <string.h>
+#include <time.h>
 #include <errno.h>
 #include <sys/types.h>
 #ifdef VARARGS
@@ -35,13 +38,9 @@
 #include <sys/fcntl.h>
 #endif
 #include <pwd.h>
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #if !defined(NOLOCK) && defined(LOCKF) || defined(linux)
 #include <sys/file.h>
 #endif
-#include <unistd.h>
 #if !defined(NOLOCK) && defined(LOCKF)
 #include <sys/file.h>
 #endif
@@ -49,13 +48,12 @@
 #include <sys/lockf.h>
 #endif
 #include <sys/signal.h>
-#include <unistd.h>
+#include <sys/stat.h>
 #include <Xm/Xm.h>
 #include "config.h"
-#include "proto.h"
+#include "cal.h"
 
 #ifdef MIPS
-extern char *getenv();
 extern struct passwd *getpwnam();
 #endif
 
@@ -69,8 +67,8 @@ char			lockpath[256];	/* lockfile path */
  * for the database files, and the holiday file (see holiday.c).
  */
 
-char *resolve_tilde(path)
-	char		*path;			/* path with ~ */
+char *resolve_tilde(
+	char		*path)			/* path with ~ */
 {
 	struct passwd	*pw;			/* for searching home dirs */
 	static char	pathbuf[512];		/* path with ~ expanded */
@@ -92,7 +90,7 @@ char *resolve_tilde(path)
 			home = pw->pw_dir;
 	}
 	if (!home) {
-		fprintf(stderr, "%s: can't evaluate ~%s in %s, using .\n",
+		fprintf(stderr, _("%s: can't evaluate ~%s in %s, using .\n"),
 						progname, pathbuf, path);
 		home = ".";
 	}
@@ -112,10 +110,10 @@ char *resolve_tilde(path)
 #define PATH 0
 #endif
 
-BOOL find_file(buf, name, exec)
-	char			*buf;		/* buffer for returned path */
-	char			*name;		/* file name to locate */
-	BOOL			exec;		/* must be executable? */
+BOOL find_file(
+	char			*buf,		/* buffer for returned path */
+	char			*name,		/* file name to locate */
+	BOOL			exec)		/* must be executable? */
 {
 	int			method;		/* search path counter */
 	char			*path;		/* $PATH or DEFAULTPATH */
@@ -170,27 +168,31 @@ BOOL find_file(buf, name, exec)
  * TRUE, try to kill it. Otherwise, return FALSE.
  */
 
-BOOL startup_lock(pathtmp, force)
-	char			*pathtmp;	/* LOCK_PATH or PLAN_PATH */
-	BOOL			force;		/* kill competitor */
+BOOL startup_lock(
+	char			*pathtmp,	/* PLANDLOCK or PLANLOCK */
+	BOOL			force)		/* kill competitor */
 {
 	char			buf[2048];	/* lockfile contents */
 	int			lockfd;		/* lock/pid file */
 	PID_T			pid;		/* pid in lockfile */
 	int			retry = 5;	/* try to kill daemon 5 times*/
 
-	sprintf(lockpath, pathtmp, (int)getuid());
+	sprintf(buf, pathtmp, (int)getuid());
+	strncpy(lockpath, resolve_tilde(buf), sizeof(lockpath)-1);
+	lockpath[sizeof(lockpath)-1] = 0;
 	while ((lockfd = open(lockpath, O_WRONLY|O_EXCL|O_CREAT, 0644)) < 0) {
 		if ((lockfd = open(lockpath, O_RDONLY)) < 0) {
 			int err = errno;
-			fprintf(stderr, "%s: cannot open lockfile ", progname);
+			fprintf(stderr, _("%s: cannot open lockfile "),
+								progname);
 			errno = err;
 			perror(lockpath);
 			_exit(1);
 		}
 		if (read(lockfd, buf, 10) < 5) {
 			int err = errno;
-			fprintf(stderr, "%s: cannot read lockfile ", progname);
+			fprintf(stderr, _("%s: cannot read lockfile "),
+								progname);
 			errno = err;
 			perror(lockpath);
 			_exit(1);
@@ -200,13 +202,14 @@ BOOL startup_lock(pathtmp, force)
 		close(lockfd);
 		if (!retry--)
 			fprintf(stderr,
-			  "%s: failed to kill process %d owning lockfile %s\n",
+			_("%s: failed to kill process %d owning lockfile %s\n"),
 						progname, pid, lockpath);
 #		ifndef NOKILL0
 		if (kill(pid, 0) && errno == ESRCH) {
 			if (unlink(lockpath) && errno != ENOENT) {
 				int err = errno;
-				fprintf(stderr, "%s: cannot unlink lockfile ",
+				fprintf(stderr,
+					_("%s: cannot unlink lockfile "),
 								progname);
 				errno = err;
 				perror(lockpath);
@@ -221,11 +224,11 @@ BOOL startup_lock(pathtmp, force)
 			(void)kill(pid, retry == 4 ? SIGINT : SIGTERM);
 		sleep(1);
 	}
-	sprintf(buf, "%5d      (pid of lockfile for %s, for user %d)\n",
+	sprintf(buf, _("%5d      (pid of lockfile for %s, for user %d)\n"),
 				(int)getpid(), progname, (int)getuid());
 	if (write(lockfd, buf, strlen(buf)) != strlen(buf)) {
 		int err = errno;
-		fprintf(stderr, "%s: cannot write lockfile ", progname);
+		fprintf(stderr, _("%s: cannot write lockfile "), progname);
 		errno = err;
 		perror(lockpath);
 		_exit(1);
@@ -237,11 +240,11 @@ BOOL startup_lock(pathtmp, force)
 /*
  * Create new lock file when it has been deleted (after cleanup of /tmp)
  */
-BOOL refresh_lock(pathtmp)
-	char			*pathtmp;	/* LOCK_PATH or PLAN_PATH */
+BOOL refresh_lock(
+	char		*pathtmp)	/* PLANDLOCK or PLANLOCK */
 {
-	char			buf[80];	/* lockfile contents */
-	int			lockfd;		/* lock/pid file */
+	char		buf[80];	/* lockfile contents */
+	int		lockfd;		/* lock/pid file */
 
 	sprintf(lockpath, pathtmp, (int)getuid());
 	if ((lockfd = open(lockpath, O_RDONLY)) >= 0) {
@@ -251,16 +254,16 @@ BOOL refresh_lock(pathtmp)
 	lockfd = creat(lockpath,0644);
 	if (lockfd < 0) {
 		int err = errno;
-		fprintf(stderr, "%s: cannot create lockfile ", progname);
+		fprintf(stderr, _("%s: cannot create lockfile "), progname);
 		errno = err;
 		perror(lockpath);
 		_exit(1);
 	}
-	sprintf(buf, "%5d      (pid of lockfile for %s, for user %d)\n",
+	sprintf(buf, _("%5d      (pid of lockfile for %s, for user %d)\n"),
 				(int)getpid(), progname, (int)getuid());
 	if (write(lockfd, buf, strlen(buf)) != strlen(buf)) {
 		int err = errno;
-		fprintf(stderr, "%s: cannot write lockfile ", progname);
+		fprintf(stderr, _("%s: cannot write lockfile "), progname);
 		errno = err;
 		perror(lockpath);
 		_exit(1);
@@ -278,20 +281,23 @@ BOOL refresh_lock(pathtmp)
  * help at all. As a side effect, the file is rewound.
  */
 
+#ifndef NOLOCK
 static BOOL got_alarm;
 static void (*old_alarm)();
+
 /*ARGSUSED*/
-static void alarmhand(sig)
-	int sig;
+static void alarmhand(
+	int sig)
 {
 	got_alarm = TRUE;
 	signal(SIGALRM, old_alarm);
 }
+#endif
 
 
-void lockfile(fp, lock)
-	FILE		*fp;		/* file to lock */
-	BOOL		lock;		/* TRUE=lock, FALSE=unlock */
+void lockfile(
+	FILE		*fp,		/* file to lock */
+	BOOL		lock)		/* TRUE=lock, FALSE=unlock */
 {
 #ifndef NOLOCK
 	if (lock) {
@@ -307,7 +313,7 @@ void lockfile(fp, lock)
 #endif
 			perror(progname);
 			fprintf(stderr,
-"%s: failed to lock database after 3 seconds, accessing anyway\n", progname);
+_("%s: failed to lock database after 3 seconds, accessing anyway\n"), progname);
 		}
 		alarm(0);
 	} else {
@@ -332,9 +338,10 @@ void lockfile(fp, lock)
 
 #ifndef VARARGS
 /*VARARGS*/
-void fatal(char *fmt, ...)
+void fatal(
+	char		*fmt, ...)
 {
-	va_list			parm;
+	va_list		parm;
 
 	va_start(parm, fmt);
 	fprintf(stderr, "%s: ", progname);
@@ -346,9 +353,12 @@ void fatal(char *fmt, ...)
 
 #else
 /*VARARGS*/
-void fatal(fmt, a, b, c, d)
-	char	*fmt;
-	int	a, b, c, d;
+void fatal(
+	char	*fmt,
+	int	a,
+	int	b,
+	int	c,
+	int	d)
 {
 	fprintf(stderr, fmt, a, b, c, d);
 	putc('\n', stderr);
@@ -361,8 +371,8 @@ void fatal(fmt, a, b, c, d)
  * Ultrix doesn't have strdup, so we'll need to define one locally.
  */
 
-char *mystrdup(s)
-	register char *s;
+char *mystrdup(
+	register char *s)
 {
 	register char *p = NULL;
 
@@ -398,8 +408,6 @@ int mystrcasecmp(
 
 
 #ifdef PLANGROK
-#include "grok.h"
-#include "form.h"
 
 /*
  * convert ascii code to and from a string representation. This is used for
@@ -407,8 +415,8 @@ int mystrcasecmp(
  * support (the real name is xmbase-grok; you need version 1.4 or up).
  */
 
-char *to_octal(n)
-	int		n;		/* ascii to convert to string */
+char *to_octal(
+	int		n)		/* ascii to convert to string */
 {
 	static char	buf[8];
 
@@ -419,9 +427,9 @@ char *to_octal(n)
 	return(buf);
 }
 
-char to_ascii(str, def)
-	char		*str;		/* string to convert to ascii */
-	int		def;		/* default if string is empty */
+char to_ascii(
+	char		*str,		/* string to convert to ascii */
+	int		def)		/* default if string is empty */
 {
 	int		n;
 	char		*p = str;
@@ -447,9 +455,9 @@ char to_ascii(str, def)
  * some systems use mybzero (BSD), others memset (SysV), I'll roll my own...
  */
 
-void mybzero(p, n)
-	void		*p;
-	register int	n;
+void mybzero(
+	void		*p,
+	register int	n)
 {
 	register char	*q = p;
 	while (n--) *q++ = 0;
@@ -460,6 +468,6 @@ void mybzero(p, n)
  * dummies for grok, called by g_*.c.
  */
 
-void print_info_line() {}
+void print_info_line(void) {}
 
 #endif
