@@ -24,7 +24,7 @@ extern int		curr_year;	/* year being displayed, since 1900 */
 time_t			curr_week;	/* week being displayed, time in sec */
 struct week		week;		/* info on week view */
 
-static BOOL add_week_entry();
+static BOOL add_week_entry(int, time_t, BOOL, struct entry *, int);
 
 
 /*
@@ -34,9 +34,9 @@ static BOOL add_week_entry();
  * of reasons NOT to show an entry...
  */
 
-void build_week(omit_priv, omit_all)
-	BOOL		omit_priv;	/* ignore private (padlocked) entries*/
-	BOOL		omit_all;	/* ignore all ent (not very useful) */
+void build_week(
+	BOOL		omit_priv,	/* ignore private (padlocked) entries*/
+	BOOL		omit_all)	/* ignore all ent (not very useful) */
 {
 	struct config	*c = &config;
 	time_t		date;		/* midnight of calculated day */
@@ -57,7 +57,7 @@ void build_week(omit_priv, omit_all)
 	curr_week = date = curr_week - curr_week % 86400;
 	if (!(week.tree   = malloc(NDAYS * sizeof(struct weeknode *))) ||
 	    !(week.nlines = malloc(NDAYS * sizeof(int))))
-		fatal("no memory for week view");
+		fatal(_("no memory for week view"));
 	memset((void *)week.tree,   0, NDAYS * sizeof(struct weeknode *));
 	memset((void *)week.nlines, 0, NDAYS * sizeof(int));
 
@@ -133,12 +133,12 @@ void build_week(omit_priv, omit_all)
 		end += (node->textlen+6) * 3600/config.week_hourwidth;	   \
 }
 
-static BOOL add_week_entry(wday, time, warn, new, u)
-	int		wday;			/* day counter, 0..NDAYS-1 */
-	time_t		time;			/* appropriate trigger time */
-	BOOL		warn;			/* it's a n-days-ahead warng */
-	struct entry	*new;			/* entry to insert */
-	int		u;			/* owner user, 0=own */
+static BOOL add_week_entry(
+	int		wday,			/* day counter, 0..NDAYS-1 */
+	time_t		time,			/* appropriate trigger time */
+	BOOL		warn,			/* it's a n-days-ahead warng */
+	struct entry	*new,			/* entry to insert */
+	int		u)			/* owner user, 0=own */
 {
 	struct weeknode	*node;			/* new week struct */
 	struct weeknode	*vert;			/* for finding free line */
@@ -251,7 +251,7 @@ static BOOL add_week_entry(wday, time, warn, new, u)
  * destroy the week trees for all days.
  */
 
-void destroy_week()
+void destroy_week(void)
 {
 	int		wday;			/* day counter */
 	struct weeknode	*vert, *nextvert;	/* line pointer */
