@@ -174,9 +174,9 @@ void set_icon(
 
 void print_icon_name(void)
 {
-	time_t			tod;		/* current time-of-day */
-	char			buf[64];	/* icon label string */
-	struct tm		*tm;		/* time to m/d/y conv */
+	time_t		tod;		/* current time-of-day */
+	char		buf[64];	/* icon label string */
+	struct tm	*tm;		/* time to m/d/y conv */
 
 	if (config.showicondate) {
 		tod = get_time();
@@ -201,10 +201,10 @@ void print_icon_name(void)
  */
 
 int strlen_in_pixels(
-	register unsigned char	*string,	/* string to truncate */
-	int			sfont)		/* FONT_* */
+	register char	*string,	/* string to truncate */
+	int		sfont)		/* FONT_* */
 {
-	register int		len;		/* length in pixels */
+	register int	len;		/* length in pixels */
 
 	for (len=0; *string; string++)
 		len += CHARWIDTH(sfont, *string);
@@ -218,9 +218,9 @@ int strlen_in_pixels(
  */
 
 void truncate_string(
-	register unsigned char	*string,	/* string to truncate */
-	register int		len,		/* max len in pixels */
-	int			sfont)		/* font of string */
+	register char	*string,	/* string to truncate */
+	register int	len,		/* max len in pixels */
+	int		sfont)		/* font of string */
 {
 	while (*string) {
 		len -= font[sfont]->per_char
