@@ -26,7 +26,7 @@ struct week		yov;		/* info on yov view */
 int			yov_nstrips;	/* number of strips (max nusers+1) */
 static unsigned short	ignore_id;	/* identifies current run */
 
-static BOOL add_yov_entry();
+static BOOL add_yov_entry(int, time_t, BOOL, struct entry *);
 
 
 /*
@@ -44,8 +44,8 @@ static BOOL add_yov_entry();
  * box containing entries from a single user.
  */
 
-void build_yov(omit_priv)
-	BOOL		omit_priv;	/* ignore private (padlocked) entries*/
+void build_yov(
+	BOOL		omit_priv)	/* ignore private (padlocked) entries*/
 {
 	struct config	*c = &config;
 	time_t		date;		/* 0:00 on January 1 of displ'd year */
@@ -80,7 +80,7 @@ void build_yov(omit_priv)
 	curr_yov = date = curr_yov - curr_yov % 86400;
 	if (!(yov.tree   = malloc(nusers * sizeof(struct weeknode *))) ||
 	    !(yov.nlines = malloc(nusers * sizeof(int))))
-		fatal("no memory for year overview");
+		fatal(_("no memory for year overview"));
 	ndays = time_to_tm(date)->tm_year & 3 ? 365 : 366;
 
 	for (u=0; u < nusers; u++)
@@ -171,11 +171,11 @@ void build_yov(omit_priv)
 		end += (node->textlen + daysz + 5) / daysz;		\
 }
 
-static BOOL add_yov_entry(strip, time, warn, new)
-	int		strip;			/* strip (user) number */
-	time_t		time;			/* appropriate trigger time */
-	BOOL		warn;			/* it's a n-days-ahead warng */
-	struct entry	*new;			/* entry to insert */
+static BOOL add_yov_entry(
+	int		strip,			/* strip (user) number */
+	time_t		time,			/* appropriate trigger time */
+	BOOL		warn,			/* it's a n-days-ahead warng */
+	struct entry	*new)			/* entry to insert */
 {
 	struct weeknode	*node;			/* new yov struct */
 	struct weeknode	*vert;			/* for finding free line */
