@@ -6,10 +6,8 @@
  *					window.
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <varargs.h>
 #include <Xm/Xm.h>
@@ -30,10 +28,14 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-extern MOUSE locate_in_yov_calendar();
-static void done_callback(), edit_callback(), sync_callback();
-static void next_callback(), other_callback();
-static void zoom_callback(), disp_callback(), single_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void edit_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void sync_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void next_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void other_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void zoom_callback	(Widget, int, XmDrawingAreaCallbackStruct  *);
+static void disp_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void single_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Pixel		color[NCOLS];	/* colors: COL_* */
@@ -60,7 +62,7 @@ static int sl2nm[7]  = {1, 2, 3, 4, 6, 8, 12};
  * destroy the yov menu. Remove it from the screen, and destroy its widgets.
  */
 
-void destroy_yov_menu()
+void destroy_yov_menu(void)
 {
 	if (shell) {
 		if (!parent_form)
@@ -70,6 +72,8 @@ void destroy_yov_menu()
 		shell = 0;
 		yov.canvas = 0;
 		drag_destroy('o');
+		if (mainlist->modified)
+			write_mainlist();
 	}
 }
 
@@ -80,14 +84,13 @@ void destroy_yov_menu()
 
 static char *disptext[4] = { "Default", "All", "Own only", "%s" };
 
-void create_yov_menu(parent)
-	Widget		parent;
+void create_yov_menu(
+	Widget		parent)
 {
 	Arg		args[15];
 	int		n, i;
-	Widget		form, below, radio, v, w;
+	Widget		form, below, v, w;
 	Atom		closewindow;
-	Dimension	xs, ys;
 	char		text[256];
 	struct tm	tm;
 
@@ -102,12 +105,13 @@ void create_yov_menu(parent)
 	build_yov(FALSE);
 
 	form = create_view_form(&shell, parent_form = parent, 'o',
-				yov.canvas_xs, yov.canvas_ys, "Year Overview");
+			yov.canvas_xs, yov.canvas_ys, _("Year Overview"));
 	if (!form) {
 		draw_yov_calendar(NULL);
 		return;
 	}
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"yov");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov");
 
 						/*---------- button form --*/
 							/*-- next/prev --*/
@@ -116,21 +120,27 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		50);			n++;
-	v = XtCreateManagedWidget("Prev", xmPushButtonWidgetClass, form,args,n);
-	XtAddCallback(v, XmNactivateCallback, next_callback, (XtPointer)-1);
-	XtAddCallback(v, XmNhelpCallback, help_callback,(XtPointer)"yov_prev");
+	XtSetArg(args[n], XmNwidth,		60);			n++;
+	v = XtCreateManagedWidget(_("Prev"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(v, XmNactivateCallback, (XtCallbackProc)
+			next_callback, (XtPointer)-1);
+	XtAddCallback(v, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_prev");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	v);			n++;
-	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		50);			n++;
-	v = XtCreateManagedWidget("Next", xmPushButtonWidgetClass, form,args,n);
-	XtAddCallback(v, XmNactivateCallback,next_callback, (XtPointer)1);
-	XtAddCallback(v, XmNhelpCallback, help_callback,(XtPointer)"yov_next");
+	XtSetArg(args[n], XmNleftOffset,	0);			n++;
+	XtSetArg(args[n], XmNwidth,		60);			n++;
+	v = XtCreateManagedWidget(_("Next"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(v, XmNactivateCallback, (XtCallbackProc)
+			next_callback, (XtPointer)1);
+	XtAddCallback(v, XmNhelpCallback, (XtCallbackProc)
+			help_callback,(XtPointer)"yov_next"); 
 
 							/*-- sy,ed,hlp,done -*/
 	n = 0;
@@ -138,44 +148,55 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass, form,args,n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"yov_done");
+	XtSetArg(args[n], XmNwidth,		72);			n++;
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback,(XtPointer)"yov_done"); 
+	n = 0;
+	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
+	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNrightWidget,	w);			n++;
+	XtSetArg(args[n], XmNrightOffset,	0);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov");
+	XtAddCallback(w, XmNhelpCallback,  (XtCallbackProc)
+			help_callback, (XtPointer)"yov");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
-	XtSetArg(args[n], XmNrightOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass, form,args,n);
-	XtAddCallback(w, XmNactivateCallback,help_callback, (XtPointer)"yov");
-	XtAddCallback(w, XmNhelpCallback,    help_callback, (XtPointer)"yov");
+	XtSetArg(args[n], XmNrightOffset,	0);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
+	w = XtCreateManagedWidget(_("Edit"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			edit_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback,(XtPointer)"yov_edit");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
-	XtSetArg(args[n], XmNrightOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
-	w = XtCreateManagedWidget("Edit", xmPushButtonWidgetClass, form,args,n);
-	XtAddCallback(w, XmNactivateCallback, edit_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"yov_edit");
-
-	n = 0;
-	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
-	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
-	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_WIDGET);	n++;
-	XtSetArg(args[n], XmNrightWidget,	w);			n++;
-	XtSetArg(args[n], XmNrightOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
+	XtSetArg(args[n], XmNrightOffset,	0);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
 	XtSetArg(args[n], XmNsensitive,		!all_files_served());	n++;
-	w = XtCreateManagedWidget("Sync", xmPushButtonWidgetClass, form,args,n);
-	XtAddCallback(w, XmNactivateCallback, sync_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"yov_sync");
+	w = XtCreateManagedWidget(_("Sync"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			sync_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_sync");
 	below = w;
 							/*-- zoom slider --*/
 	n = 0;
@@ -185,8 +206,10 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	v);			n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	v = XtCreateManagedWidget("Zoom in", xmLabelWidgetClass, form, args,n);
-	XtAddCallback(v, XmNhelpCallback, help_callback,(XtPointer)"yov_zoom");
+	v = XtCreateManagedWidget(_("Zoom in"), xmLabelWidgetClass,
+			form, args, n);
+	XtAddCallback(v, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_zoom");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -194,8 +217,9 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	16);			n++;
-	w = XtCreateManagedWidget("out", xmLabelWidgetClass, form,args,n);
-	XtAddCallback(v, XmNhelpCallback, help_callback,(XtPointer)"yov_zoom");
+	w = XtCreateManagedWidget("out", xmLabelWidgetClass, form, args, n);
+	XtAddCallback(v, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_zoom");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -212,8 +236,10 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNvalue,	nm2sl[config.yov_nmonths]);	n++;
 	w = XmCreateScale(form, "zoom", args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"yov_zoom");
-	XtAddCallback(w, XmNvalueChangedCallback, zoom_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_zoom");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			zoom_callback, (XtPointer)0);
 	XtManageChild(w);
 
 						/*---------- infotext form --*/
@@ -241,13 +267,15 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNtopOffset,		10);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	w = XtCreateManagedWidget("Display:", xmLabelWidgetClass, form, args,n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"yov_disp");
+	w = XtCreateManagedWidget(_("Display:"), xmLabelWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_disp");
 
 	for (i=0; i < 4; i++) {
-	  sprintf(text, disptext[i],
+	  sprintf(text, i < 3 ? _(disptext[i]) : "%s",
 			 config.yov_user < nusers ? user[config.yov_user].name
-						  : "None");
+						  : _("None"));
 	  n = 0;
 	  XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	  XtSetArg(args[n], XmNtopOffset,	10);			n++;
@@ -260,10 +288,10 @@ void create_yov_menu(parent)
 	  XtSetArg(args[n], XmNset,		i==config.yov_display);	n++;
 	  w = w_disp[i] = XtCreateManagedWidget(text,
 				xmToggleButtonWidgetClass, form, args, n);
-	  XtAddCallback(w, XmNvalueChangedCallback, disp_callback,
-							(XtPointer)i);
-	  XtAddCallback(w, XmNhelpCallback, help_callback,
-							(XtPointer)"yov_disp");
+	  XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+	  		disp_callback, (XtPointer)i);
+	  XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+	  		help_callback, (XtPointer)"yov_disp");
 	}
 
 	n = 0;
@@ -273,9 +301,12 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNleftWidget,	w);			n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		64);			n++;
-	w = XtCreateManagedWidget("Other", xmPushButtonWidgetClass,form,args,n);
-	XtAddCallback(w, XmNactivateCallback, other_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,(XtPointer)"yov_disp");
+	w = XtCreateManagedWidget(_("Other"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			other_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"yov_disp");
 	below = w;
 							/*-- single-day --*/
 	n = 0;
@@ -285,10 +316,12 @@ void create_yov_menu(parent)
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNset,		config.yov_single);	n++;
-	w = XtCreateManagedWidget("Show single-day appointments",
+	w = XtCreateManagedWidget(_("Show single-day appointments"),
 			xmToggleButtonWidgetClass, form, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,single_callback,(XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,help_callback,(XtPointer)"day_single");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			single_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day_single");
 
 						/*---------- year overview --*/
 	n = 0;
@@ -322,7 +355,7 @@ void create_yov_menu(parent)
 	if (!parent) {
 		XtPopup(shell, XtGrabNone);
 		closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-		XmAddWMProtocolCallback(shell, closewindow,
+		XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
 					done_callback, (XtPointer)shell);
 	}
 }
@@ -335,10 +368,10 @@ void create_yov_menu(parent)
  */
 
 /*ARGSUSED*/
-static void next_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void next_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct tm			*tm;
 
@@ -351,10 +384,10 @@ static void next_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (parent_form)
 		create_view('m');
@@ -364,10 +397,10 @@ static void done_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void edit_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void edit_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct tm *tm = time_to_tm(curr_yov);
 	create_list_popup(mainlist, curr_yov,
@@ -377,10 +410,10 @@ static void edit_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void sync_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void sync_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (!can_edit_appts())
 		return;
@@ -396,10 +429,10 @@ static void sync_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void zoom_callback(w, data, info)
-	Widget				w;
-	XtPointer			data;
-	XmDrawingAreaCallbackStruct	*info;
+static void zoom_callback(
+	Widget				w,
+	int				data,
+	XmDrawingAreaCallbackStruct	*info)
 {
 	XmScaleGetValue(w, &config.yov_nmonths);
 	config.yov_nmonths = sl2nm[config.yov_nmonths];
@@ -414,10 +447,10 @@ static void zoom_callback(w, data, info)
  */
 
 /*ARGSUSED*/
-static void single_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void single_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	config.yov_single = data->set;
 	mainlist->modified = TRUE;
@@ -427,10 +460,10 @@ static void single_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void disp_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void disp_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	Arg				args;
 	int				i;
@@ -446,25 +479,25 @@ static void disp_callback(widget, item, data)
 }
 
 
-static void callback(newuser)
-	int		newuser;
+static void callback(
+	int		newuser)
 {
 	if (newuser < 0)
 		disp_callback(0, 2, 0);
 	else {
 		config.yov_user = newuser;
 		print_button(w_disp[3], "%s",
-			newuser < nusers ? user[newuser].name : "None");
+			newuser < nusers ? user[newuser].name : _("None"));
 		disp_callback(0, 3, 0);
 	}
 }
 
 
 /*ARGSUSED*/
-static void other_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void other_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	create_user_sel_popup(widget, config.yov_user, callback);
+	create_user_sel_popup(widget, config.yov_user, (BOOL (*)())callback);
 }
